@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.41 $
+//$Revision: 1.48 $
 #include <hk_datasource.h>
 
 #include "hk_kdeboolean.h"
@@ -29,7 +29,7 @@ hk_dsboolean(form)
 #endif
     QObject::connect(this,SIGNAL(clicked()),this,SLOT(slot_data_changed()));
     p_widget_specific_row_change=true;
-    setEnabled(false);
+    //setEnabled(false);
 
     QColor qcolor=paletteBackgroundColor();
     hk_colour colour(qcolor.red(),qcolor.green(),qcolor.red());
@@ -37,7 +37,7 @@ hk_dsboolean(form)
     qcolor=palette().active().text();
     colour.set_colour(qcolor.red(),qcolor.green(),qcolor.red());
     set_foregroundcolour(colour,false,true);
-    
+
 }
 
 
@@ -54,7 +54,7 @@ void hk_kdeboolean::keyPressEvent( QKeyEvent * e )
 #endif
 
 //   p_while_keyaction=true;
-    hk_key nk=hk_key(e->key(),e->state(),(e->text().isNull()?"":e->text().local8Bit().data()));
+    hk_key nk=hk_key(e->key(),e->state(),(u2l(e->text().isNull()?"":e->text().utf8().data())));
     hk_key* k=NULL;
     if (p_gridcolumn)
       {
@@ -64,7 +64,7 @@ void hk_kdeboolean::keyPressEvent( QKeyEvent * e )
       }
       else
       {
-      
+
        set_key(nk);
        action_on_key();
        k=key();
@@ -74,11 +74,11 @@ void hk_kdeboolean::keyPressEvent( QKeyEvent * e )
       e->ignore();
       //p_while_keyaction=false;
       return;
-    
+
     }
-    
-    
-    
+
+
+
    if (e->key()==Key_Return)
     {
         if (e->state()&ControlButton)
@@ -87,18 +87,18 @@ void hk_kdeboolean::keyPressEvent( QKeyEvent * e )
             focusNextPrevChild(true);
 
     }
-    else   
+    else
     if (e->key()==Key_Escape)
        {
          if (column() && column()->has_changed()) column()->reset_changed_data();
 	 else
-	 if (datasource() && datasource()->has_changed()) 
+	 if (datasource() && datasource()->has_changed())
 	 {
 	    datasource()->reset_changed_data();
 	    datasource()->store_changed_data();
-	 }   
+	 }
 	 widget_specific_row_change();
-	   
+
        }
     else
     {
@@ -124,16 +124,16 @@ bool hk_kdeboolean::widget_specific_row_change(void)
 	   setNoChange();
 	else
 	setChecked(c->changed_data_asbool());
-	
+
 	}
 	else
 	{
-	
+
 	if (c->is_nullvalue())
 	   setNoChange();
 	else
 	setChecked(c->asbool());
-	
+
 	}
     }
 
@@ -164,10 +164,11 @@ void hk_kdeboolean::slot_data_changed(void)
 	      case Off:column()->set_asbool(false);break;
 	      case NoChange:column()->set_asnullvalue();break;
 	    }
-	    
-        }
-    }
 
+        }
+action_on_valuechanged();
+    }
+    else if (!column()) action_on_valuechanged();
 }
 
 
@@ -182,23 +183,23 @@ void hk_kdeboolean::widget_specific_enable_disable()
         hkdebug("kdeboolean::if ((datasource()!=NULL)&&(column()!=NULL))");
 #endif
 
-        if (datasource()->is_enabled()>0)
+        if (datasource()->is_enabled())
         {
-            setEnabled(true);
-	    if (column()) 
+            setEnabled(is_enabled());
+	    if (column())
 	    {
 	      setTristate(!column()->is_notnull());
-	    
+
 	    }
             widget_specific_row_change();
         }
-        else setEnabled(false);
+        else setEnabled(is_enabled());
     }
     else
     {
-        if (p_presentation ) setEnabled(p_presentation->mode()==hk_presentation::viewmode);
+        if (p_presentation ) setEnabled(p_presentation->mode()==hk_presentation::viewmode && is_enabled());
 	else
-	setEnabled(true);
+	setEnabled(is_enabled());
 	if (datasource()&&!datasource()->is_enabled()) setEnabled(false);
         setChecked(false);
     }
@@ -268,14 +269,14 @@ void    hk_kdeboolean::widget_specific_label_changed(void)
 #ifdef HK_DEBUG
     hkdebug("hk_kdeboolean::widget_specific_label_changed");
 #endif
-    if (label().size()>0)setText(QString::fromLocal8Bit (label().c_str()));
+    if (label().size()>0)setText(QString::fromUtf8 (l2u(label()).c_str()));
     else setText(i18n("label"));
 }
 
 
 void hk_kdeboolean::widget_specific_font_changed(void)
 {
-    setFont(QFont(QString::fromLocal8Bit (hk_dsboolean::font().fontname().c_str()),hk_dsboolean::font().fontsize()));
+    setFont(QFont(QString::fromUtf8 (l2u(hk_dsboolean::font().fontname()).c_str()),hk_dsboolean::font().fontsize()));
 }
 
 
@@ -342,7 +343,7 @@ void    hk_kdeboolean::widget_specific_foregroundcolour_changed(const hk_colour&
 
 void  hk_kdeboolean::widget_specific_tooltip_changed(void)
 {
- QToolTip::add(this,QString::fromLocal8Bit (tooltip().c_str()));
+ QToolTip::add(this,QString::fromUtf8 (l2u(tooltip()).c_str()));
 }
 
 
@@ -361,3 +362,67 @@ void hk_kdeboolean::focusOutEvent ( QFocusEvent * e)
 
 }
 
+void hk_kdeboolean::show_widget(void)
+{
+  show();
+}
+
+void hk_kdeboolean::hide_widget(void)
+{
+  hide();
+}
+
+void hk_kdeboolean::close_widget(void)
+{
+  close();
+}
+
+void hk_kdeboolean::set_value(const hk_string&v)
+{
+ hk_column* c=column();
+ hk_dsboolean::set_value(v);
+ if (!c)setChecked(string2upper(v)!="FALSE");
+
+}
+
+hk_string hk_kdeboolean::value(void)
+{
+  if (!column()) return isChecked()?"TRUE":"FALSE";
+  else return hk_dsboolean::value();
+}
+
+bool	hk_kdeboolean::presentationmode_changed(void)
+{
+if (!p_presentation)
+  {
+    return hk_dsboolean::presentationmode_changed();
+  }
+bool result=hk_dsboolean::presentationmode_changed();
+if (p_presentation->mode()==hk_presentation::designmode)
+   {
+    setEnabled(false);
+        blockSignals(true);
+        setChecked(false);
+        blockSignals(false);
+   }
+ else
+ {
+   setEnabled(is_enabled());
+   if (!datasource()||!column())
+    {
+        blockSignals(true);
+        //setText(false);
+        blockSignals(false);
+
+    }
+ }
+return result;
+
+}
+
+
+void hk_kdeboolean::widget_specific_enabled_changed(void)
+{
+  setEnabled(is_enabled());
+}
+
