@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_classes library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -54,6 +54,7 @@ hk_button(form)
     setDefault(true);
 
     QObject::connect(this,SIGNAL(clicked()),this,SLOT(button_clicked()));
+    QObject::connect(this,SIGNAL(stateChanged(int)),this,SLOT(toggle_state_changed(int)));
 }
 
 
@@ -80,17 +81,18 @@ bool hk_kdebutton::widget_specific_open_form(void)
 #ifdef HK_DEBUG
     hkdebug("hk_kdebutton::widget_specific_open_form");
 #endif
+cerr <<"hk_kdebutton::widget_specific_open_form"<<endl;
     hk_kdeform* w=find_existing_form();
     hk_kdeformpartwidget* f=find_existing_formpart();
 
 
-if (p_presentation && p_presentation->name()!=object()) 
+if (p_presentation && p_presentation->name()!=object())
  {
-    
-    
+
+
     if (w==NULL && f==NULL)                                  // not open yet
     {
-     hk_kdesimpleform* s=NULL; 
+     hk_kdesimpleform* s=NULL;
      if (p_presentation!=NULL)
         s=((hk_kdesimpleform*)p_presentation->database()->new_formvisible());
      if (s)
@@ -108,9 +110,19 @@ if (p_presentation && p_presentation->name()!=object())
 	    s->datasource()->set_internalfilter(c);
             s->datasource()->set_use_internalfilter(true);
 	    }
-	    
+
         }
         s->set_viewmode();
+        
+        
+        hk_form* fo=dynamic_cast<hk_form*>(p_presentation);
+        if (fo)
+        {
+           if (s)cerr <<s->hk_form::name()<<" fo->set_caller_form: "<<fo->name()<<endl;
+           if (s && s->formpartwidget()) s->formpartwidget()->set_caller_form(fo->name());
+        }
+ else cerr <<"hk_kdebutton: fo ==NULL "<<endl;
+
 	//s->enable_datasources(true);
       }
     }
@@ -118,14 +130,14 @@ if (p_presentation && p_presentation->name()!=object())
     {
       if (w)w->hide();
     }
-   
+
    if (w||f)
    {
       hk_kdesimpleform* s=NULL;
       if (w) s=w->simpleform();
-      else 
+      else
        s=f->simpleform();
-          
+
 	s->load_form(object());
         s->set_designmode();
         hk_string c=parsed_condition(s);
@@ -136,15 +148,15 @@ if (p_presentation && p_presentation->name()!=object())
 	    s->datasource()->set_internalfilter(c);
             s->datasource()->set_use_internalfilter(true);
 	    }
-	    
+
         }
         s->set_viewmode();
    }
 }   // end p_presentation->name()!=object()
-   
-   
+
+ 
    if (w)
-       { 
+       {
 	if (show_maximized())w->showMaximized();
         else w->show();
        }
@@ -152,26 +164,26 @@ if (p_presentation && p_presentation->name()!=object())
    {
     if (f)
     {
-    
+
       KMdiChildView* view= dynamic_cast<KMdiChildView*>(f->parent());
       if (view)
         {
 	 view->activate();
-         return true; 
-	} 
-	
+         return true;
+	}
+
 	else
 	{
 	if (show_maximized())f->showMaximized();
         else f->show();
-	
+
 	}
     }
-    
-    
+
+
 
    }
-       
+
     return true;
 }
 
@@ -198,27 +210,27 @@ bool hk_kdebutton::widget_specific_close_form(void)
 		}
 
      }
-      
+
       }
       hk_form* f=dynamic_cast<hk_form*>(p_presentation);
-      
+
       if (f)
       {
         while (f->masterform())
 	 f=f->masterform();
-        
+
 	if (((hk_kdesimpleform*)(f))->formpartwidget())
 	 {
 	    ((hk_kdesimpleform*)(f))->formpartwidget()->close();
-	 
+
 	  return true;
 	 }
 	 else ((hk_kdesimpleform*)(f))->close();
-      
+
       }
-      
-      
-      
+
+
+
       if (w)
       {
        w->close();
@@ -252,7 +264,9 @@ void    hk_kdebutton::widget_specific_label_changed(void)
 #ifdef HK_DEBUG
     hkdebug("hk_kdebutton::widget_specific_label_changed");
 #endif
-    setText(QString::fromLocal8Bit (label().c_str()));
+    cerr <<"widget_specific_label_changed:"<<label()<<endl;
+    setText(QString::fromUtf8 (l2u(label()).c_str()));
+    show_icon();
 }
 
 
@@ -298,7 +312,7 @@ void hk_kdebutton::widget_specific_font_changed(void)
 #ifdef HK_DEBUG
     hkdebug("hk_kdebutton::widget_specific_font_changed");
 #endif
-    setFont(QFont(QString::fromLocal8Bit (hk_button::font().fontname().c_str())
+    setFont(QFont(QString::fromUtf8 (l2u(hk_button::font().fontname()).c_str())
                   ,hk_button::font().fontsize(),hk_button::font().bold()?QFont::Bold:QFont::Normal,
 		   hk_button::font().italic()));
 }
@@ -368,7 +382,7 @@ hk_kdereportpartwidget* hk_kdebutton::find_existing_reportpart(void)
     {
         QWidget* sf=dynamic_cast<QWidget*>
             (p_presentation->database()->existing_report(object()));
-	    
+
         while (sf!=NULL && w==NULL)
         {
             sf=sf->parentWidget();
@@ -440,13 +454,13 @@ bool    hk_kdebutton::widget_specific_preview_report(void)
     hk_kdereportpartwidget* f=find_existing_reportpart();
     if (w||f)
     {
-       
+
       KMdiChildView* view= NULL;
       if (w) view=dynamic_cast<KMdiChildView*>(w->parent());
       if (f) view=dynamic_cast<KMdiChildView*>(f->parent());
       if (view)
         {
-	
+
 	 view->activate();
         if (w)w->set_designmode();
         if (f)f->set_designmode();
@@ -463,16 +477,16 @@ bool    hk_kdebutton::widget_specific_preview_report(void)
 	    f->simplereport()->datasource()->set_internalfilter(c);
             f->simplereport()->datasource()->set_use_internalfilter(true);
 	    }
-	    
+
         }
         if (w)w->set_viewmode();
 	if (f)f->set_viewmode();
-         return true; 
+         return true;
 	}
-	else return false; 
-	
+	else return false;
+
     }
-    
+
     if (!w&&!f)                                  // not open yet
     {
         hk_kdesimplereport* r=((hk_kdesimplereport*)p_presentation->database()->new_reportvisible());
@@ -481,7 +495,7 @@ bool    hk_kdebutton::widget_specific_preview_report(void)
               show_warningmessage("r==NULL!");
 	      return false;
 	}
-	
+
         if (p_presentation!=NULL)r->set_database(p_presentation->database());
         else r->set_database(database());
         r->load_report(object());
@@ -492,42 +506,48 @@ bool    hk_kdebutton::widget_specific_preview_report(void)
             r->datasource()->set_use_internalfilter(true);
         }
         r->set_viewmode();
+        hk_form* fo=dynamic_cast<hk_form*>(p_presentation);
+        if (fo)
+        {
+           if (r)cerr <<r->hk_report::name()<<" fo->set_caller_form: "<<fo->name()<<endl;
+           if (r && r->reportpartwidget()) r->reportpartwidget()->set_caller_form(fo->name());
+        }
     }
     else
     {
         if (w)w->hide();
     }
-        
+
    if (w)
-   {	
+   {
 	if (show_maximized())w->showMaximized();
         else w->show();
-    
-   } 
-	
+
+   }
+
    else
    {
     if (f)
     {
-    
+
       KMdiChildView* view= dynamic_cast<KMdiChildView*>(f->parent());
       if (view)
         {
 	 view->activate();
-         return true; 
-	} 
-	
+         return true;
+	}
+
 	else
 	{
 	if (show_maximized())f->showMaximized();
         else f->show();
-	
+
 	}
     }
     }
-	
-    
-    
+
+
+
     return true;
 }
 
@@ -574,7 +594,7 @@ void  hk_kdebutton::mouseDoubleClickEvent(QMouseEvent* event)
 
 void  hk_kdebutton::widget_specific_tooltip_changed(void)
 {
- QToolTip::add(this,QString::fromLocal8Bit (tooltip().c_str()));
+ QToolTip::add(this,QString::fromUtf8 (l2u(tooltip()).c_str()));
 }
 
 
@@ -594,3 +614,90 @@ void hk_kdebutton::focusOutEvent ( QFocusEvent * e)
 }
 
 
+void hk_kdebutton::show_widget(void)
+{
+  show();
+}
+
+void hk_kdebutton::hide_widget(void)
+{
+  hide();
+}
+
+void hk_kdebutton::close_widget(void)
+{
+  close();
+}
+
+bool hk_kdebutton::load_icon(const hk_string& filename,bool registerchange)
+{  cerr<<"load_icon"<<endl;
+  bool result=hk_button::load_icon(filename,registerchange);
+  if (result)
+  {
+   show_icon();
+  }
+  return result;
+
+}
+
+void hk_kdebutton::show_icon()
+{cerr <<"show_icon"<<endl;
+if (!hk_button::icon()->data) return;
+   QPixmap p_pixmap;
+   if (p_pixmap.loadFromData((const uchar*)hk_button::icon()->data,(uint)hk_button::icon()->length))
+       setIconSet(p_pixmap);
+   else
+     {
+       hk_string d;
+       data2hex(hk_button::icon(),d);
+       cerr <<d<<endl;
+     }
+
+}
+
+
+void hk_kdebutton::widget_specific_enabled_changed(void)
+{
+  setEnabled(is_enabled());
+}
+
+bool hk_kdebutton::presentationmode_changed()
+{
+if (!p_presentation)
+  {
+    setEnabled(is_enabled());
+    return hk_button::presentationmode_changed();
+  }
+bool result=hk_button::presentationmode_changed();
+   setEnabled(is_enabled());
+   if (is_togglebutton())set_is_pushed(is_pushed(),false,false);
+  return  result;
+}
+
+
+void hk_kdebutton::set_is_togglebutton(bool t,bool registerchange,bool forcesetting)
+{
+ if (!t)set_is_pushed(false,registerchange,forcesetting);
+ setToggleButton(t);
+ hk_button::set_is_togglebutton(t,registerchange,forcesetting);
+}
+
+void hk_kdebutton::set_is_pushed(bool p,bool registerchange,bool forcesetting)
+{
+ hk_button::set_is_pushed(p,registerchange,forcesetting);
+ blockSignals(true);
+ setState(p?On:Off);
+ blockSignals(false);
+
+}
+
+
+void hk_kdebutton::toggle_state_changed(int state)
+{
+ set_is_pushed(state==On);
+}
+
+
+
+
+
