@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.65 $
+//$Revision: 1.71 $
 #include <hk_datasource.h>
 #include "hk_kdecombobox.h"
 #include <hk_kdecombobox.moc>
@@ -71,8 +71,16 @@ hk_kdecombobox::hk_kdecombobox(QWidget* wid,hk_form* form):QComboBox(wid),hk_dsc
     colour.set_colour(qcolor.red(),qcolor.green(),qcolor.red());
     set_foregroundcolour(colour,false,true);
 
-    connect(this,SIGNAL(activated(int)),this,SLOT(slot_data_changed(int)));
+    //connect(this,SIGNAL(activated(int)),this,SLOT(slot_data_changed(int)));
+    //connect(this,SIGNAL(textChanged( const QString& )),this,SLOT(slot_text_changed()));
+    if (mode()==combo)
+    {
     connect(this,SIGNAL(textChanged( const QString& )),this,SLOT(slot_text_changed()));
+    }
+    else
+    {
+    connect(this,SIGNAL(activated(int)),this,SLOT(slot_data_changed(int)));
+    }
     widget_specific_font_changed();
     setLineEdit( new qlineedit(this));
 
@@ -94,6 +102,8 @@ void hk_kdecombobox::slot_data_changed(int index)
     hkdebug("kdecombobox::slot_data_changed");
 #endif
     set_selecteditemdata(index);
+    if (p_presentation &&p_presentation->mode()==hk_presentation::viewmode)
+       action_on_select();
 
 }
 
@@ -149,7 +159,7 @@ void hk_kdecombobox::widget_specific_enable_disable()
         if (datasource()->is_enabled()>0)
         {
 
-            setEnabled(true);
+            setEnabled(is_enabled());
             setAutoCompletion(true);
 
         }
@@ -157,9 +167,9 @@ void hk_kdecombobox::widget_specific_enable_disable()
     }
     else
     {
-        if (p_presentation ) setEnabled(p_presentation->mode()==hk_presentation::viewmode);
+        if (p_presentation ) setEnabled(p_presentation->mode()==hk_presentation::viewmode && is_enabled());
 	else
-	setEnabled(true);
+	setEnabled(is_enabled());
 	if (datasource()&&!datasource()->is_enabled()) setEnabled(false);
     }
     setFocusPolicy(StrongFocus);
@@ -196,7 +206,7 @@ void hk_kdecombobox::set_currentlistitem(void)
 #ifdef HK_DEBUG
     hkdebug("kdecombobox::set_currentlistitem");
 #endif
-    
+
     if (datasource()==NULL) return;
     if (column()==NULL) return;
     if (mode()==combo_noedit)
@@ -204,8 +214,8 @@ void hk_kdecombobox::set_currentlistitem(void)
       unsigned int p=0;
       if (use_textlist())
       {
-         QString t=QString::fromLocal8Bit(
-	            column()->asstring_at(datasource()->row_position(),true).c_str()); 
+         QString t=QString::fromUtf8(l2u(
+	            column()->asstring_at(datasource()->row_position(),true)).c_str());
 	 int c=0;
 	 while (c<count())
 	  {
@@ -218,16 +228,16 @@ void hk_kdecombobox::set_currentlistitem(void)
 	  }
       }
       else
-      { 
+      {
       if (listcolumn()) p=listcolumn()->find(column()->asstring_at(datasource()->row_position(),true),true);
       if (p>datasource()->max_rows())
         p=0;
       }
       setCurrentItem(p);
-      
+
     }
     else
-    setEditText(QString::fromLocal8Bit (value_at(datasource()->row_position()).c_str()));
+    setEditText(QString::fromUtf8 (l2u(value_at(datasource()->row_position())).c_str()));
 }
 
 
@@ -239,11 +249,15 @@ void hk_kdecombobox::set_selecteditemdata(int index)
     if (mode()==selector)
     {
         selector_row_changed(index);
+        action_on_valuechanged();
         return;
     }
 
-    if (column()==NULL) return;
-
+    if (column()==NULL)
+    {
+    action_on_valuechanged();
+     return;
+    }
     blockSignals(true);
     if (lineEdit()!=NULL) lineEdit()->blockSignals(true);
 
@@ -253,13 +267,13 @@ void hk_kdecombobox::set_selecteditemdata(int index)
         hkdebug("kdecombobox::set_selecteditemdata listcolumn==NULL");
 #endif
         p_whiledatachange=true;
-	column()->set_asstring(currentText().local8Bit().data(),true,true);
+	column()->set_asstring(u2l(currentText().utf8().data()),true,true);
 	p_whiledatachange=false;
         blockSignals(false);
         if (lineEdit()!=NULL) lineEdit()->blockSignals(false);
         return;
     }
-    unsigned int r=viewcolumn()->find(text(index).local8Bit().data(),true);
+    unsigned int r=viewcolumn()->find(u2l(text(index).utf8().data()),true);
     if (r<listdatasource()->max_rows())
     {
 #ifdef HK_DEBUG
@@ -271,11 +285,12 @@ void hk_kdecombobox::set_selecteditemdata(int index)
 	p_whiledatachange=false;
     }
 /*    clear();
-    for (unsigned int k=0;k<listdatasource()->max_rows();k++) insertItem(QString::fromLocal8Bit (viewcolumn()->asstring_at(k,true).c_str()));
+    for (unsigned int k=0;k<listdatasource()->max_rows();k++) insertItem(QString::fromUtf8 (l2u(viewcolumn()->asstring_at(k,true)).c_str()));
 
-    setEditText(QString::fromLocal8Bit (viewcolumn()->asstring_at(r,true).c_str()));*/
+    setEditText(QString::fromUtf8 (l2u(viewcolumn()->asstring_at(r,true)).c_str()));*/
     blockSignals(false);
     if (lineEdit()!=NULL) lineEdit()->blockSignals(false);
+    action_on_valuechanged();
 }
 
 
@@ -301,7 +316,7 @@ void hk_kdecombobox::resizeEvent ( QResizeEvent * event )
 void hk_kdecombobox::keyPressEvent(QKeyEvent * e)
 {
    //p_while_keyaction=true;
-    hk_key nk=hk_key(e->key(),e->state(),(e->text().isNull()?"":e->text().local8Bit().data()));
+    hk_key nk=hk_key(e->key(),e->state(),(e->text().isNull()?"":u2l(e->text().utf8().data())));
     hk_key* k=NULL;
     if (p_gridcolumn)
       {
@@ -311,7 +326,7 @@ void hk_kdecombobox::keyPressEvent(QKeyEvent * e)
       }
       else
       {
-      
+
        set_key(nk);
       action_on_key();
        k=key();
@@ -321,23 +336,23 @@ void hk_kdecombobox::keyPressEvent(QKeyEvent * e)
       e->ignore();
       //p_while_keyaction=false;
       return;
-    
+
     }
-    
-    
-    
+
+
+
     QComboBox::keyPressEvent(e);
     if (e->key()==Key_Escape)
        {
          if (column() && column()->has_changed()) column()->reset_changed_data();
 	 else
-	 if (datasource() && datasource()->has_changed()) 
+	 if (datasource() && datasource()->has_changed())
 	 {
 	    datasource()->reset_changed_data();
 	    datasource()->store_changed_data();
-	 }   
+	 }
 	 widget_specific_row_change();
-	   
+
        }
 
 /*  if (!e->isAccepted())
@@ -376,12 +391,12 @@ void    hk_kdecombobox::widget_specific_insert_mode(void)
 {
     blockSignals(true);
     unsigned int r=0;
-    
-    hk_string d;    
-    
-        if (datasource()==NULL|| column()==NULL) 
+
+    hk_string d;
+
+        if (datasource()==NULL|| column()==NULL)
 	  {
-	     
+
 	  }
     else
     if((listcolumn()==NULL)||(listdatasource()==NULL)||(viewcolumn()==NULL))
@@ -404,19 +419,19 @@ void    hk_kdecombobox::widget_specific_insert_mode(void)
         else
             d= viewcolumn()->asstring_at(r,true);
     }
-       if (mode()==combo_noedit) 
-       {  
-         setCurrentItem(r);	    
-	} 
+       if (mode()==combo_noedit)
+       {
+         setCurrentItem(r);
+	}
+
+   }
+
+
+    setEditText(QString::fromUtf8 (l2u(d).c_str()));
+
+
 
-   } 
-    
-    
-    setEditText(QString::fromLocal8Bit (d.c_str()));
 
-    
-    
-    
     blockSignals(false);
 }
 
@@ -431,7 +446,7 @@ void hk_kdecombobox::load_listitems(void)
     blockSignals(true);
     clear();
     blockSignals(false);
-  if (use_textlist()) 
+  if (use_textlist())
    load_listitems_from_textlist();
   else
    load_listitems_from_column();
@@ -448,7 +463,7 @@ void  hk_kdecombobox::load_listitems_from_textlist(void)
     list<hk_string>::iterator it=tl->begin();
     while (it!=tl->end())
     {
-     insertItem(QString::fromLocal8Bit ((*it).c_str()));
+     insertItem(QString::fromUtf8 (l2u((*it)).c_str()));
      ++it;
     }
     blockSignals(false);
@@ -460,7 +475,7 @@ void  hk_kdecombobox::load_listitems_from_column(void)
 #ifdef HK_DEBUG
     hkdebug("kdecombobox::load_listitems_from_column");
 #endif
-    
+
     blockSignals(true);
     if  (listdatasource()==NULL)
     {
@@ -474,12 +489,12 @@ void  hk_kdecombobox::load_listitems_from_column(void)
     }
     listdatasource()->disable();
     listdatasource()->enable();
-    unsigned int r=listdatasource()->max_rows(); 
+    unsigned int r=listdatasource()->max_rows();
     if (viewcolumn()!=NULL)
     {
         for (unsigned int k=0;k<r;k++)
         {
-            insertItem(QString::fromLocal8Bit (viewcolumn()->asstring_at(k,true).c_str()));
+            insertItem(QString::fromUtf8 (l2u(viewcolumn()->asstring_at(k,true)).c_str()));
         }
     }
     set_currentlistitem();
@@ -529,15 +544,19 @@ void    hk_kdecombobox::widget_specific_mode_change(void)
 #ifdef HK_DEBUG
     hkdebug("kdecombobox::widget_specific_mode_change");
 #endif
+    disconnect(this,SIGNAL(activated(int)),this,SLOT(slot_data_changed(int)));
+    disconnect(this,SIGNAL(textChanged( const QString& )),this,SLOT(slot_text_changed()));
     if (mode()==combo)
     {
         setEditable(true);
+    connect(this,SIGNAL(textChanged( const QString& )),this,SLOT(slot_text_changed()));
 
     }
     else
     {
 
         setEditable(false);
+    connect(this,SIGNAL(activated(int)),this,SLOT(slot_data_changed(int)));
 
     }
 
@@ -567,7 +586,7 @@ void    hk_kdecombobox::after_store_changed_data(void)
 
 void hk_kdecombobox::widget_specific_font_changed(void)
 {
-    setFont(QFont(QString::fromLocal8Bit (hk_dscombobox::font().fontname().c_str())
+    setFont(QFont(QString::fromUtf8 (l2u(hk_dscombobox::font().fontname()).c_str())
                   ,hk_dscombobox::font().fontsize(),hk_dscombobox::font().bold()?QFont::Bold:QFont::Normal,
 		   hk_dscombobox::font().italic()));
 }
@@ -616,21 +635,22 @@ void  hk_kdecombobox::mouseDoubleClickEvent(QMouseEvent* event)
 
 void hk_kdecombobox::set_value(const hk_string&v)
 {
-    setEditText(QString::fromLocal8Bit (v.c_str()));
-
+    setEditText(QString::fromUtf8 (l2u(v).c_str()));
+    hk_kdecombobox::set_value(v);
 }
 
 
 hk_string hk_kdecombobox::value(void)
 {
-  return currentText().local8Bit().data();
+  return u2l(currentText().utf8().data());
 }
 
 
-void	hk_kdecombobox::presentationmode_changed(void)
+bool	hk_kdecombobox::presentationmode_changed(void)
 {
-hk_dscombobox::presentationmode_changed();
-if (!p_presentation) return;
+bool r=hk_dscombobox::presentationmode_changed();
+if (!r) return false;
+if (!p_presentation) return true;
 if (p_presentation->mode()==hk_presentation::designmode)
    {
     setEnabled(false);
@@ -640,17 +660,17 @@ if (p_presentation->mode()==hk_presentation::designmode)
    }
  else
  {
-   setEnabled(true);
+   setEnabled(is_enabled());
    if (use_textlist()&&!column())
       load_listitems();
  }
-
+return true;
 }
 
 
 void  hk_kdecombobox::widget_specific_tooltip_changed(void)
 {
- QToolTip::add(this,QString::fromLocal8Bit (tooltip().c_str()));
+ QToolTip::add(this,QString::fromUtf8 (l2u(tooltip()).c_str()));
 }
 
 
@@ -669,3 +689,24 @@ void hk_kdecombobox::focusOutEvent ( QFocusEvent * e)
 
 }
 
+
+void hk_kdecombobox::show_widget(void)
+{
+  show();
+}
+
+void hk_kdecombobox::hide_widget(void)
+{
+  hide();
+}
+
+void hk_kdecombobox::close_widget(void)
+{
+  close();
+}
+
+
+void hk_kdecombobox::widget_specific_enabled_changed(void)
+{
+  setEnabled(is_enabled());
+}
