@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -16,7 +16,7 @@
 /**
  *
  *@short KDE Widget to edit/display data in a combobox.
- *@version $Revision: 1.28 $
+ *@version $Revision: 1.31 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *Just set the datasource and the column (defined in the parent class @ref hk_dsdatavisible).
@@ -27,7 +27,7 @@
  */
 
  class hk_kdecomboboxprivate;
- 
+
 class hk_kdecombobox :public QComboBox,public hk_dscombobox
 {
     Q_OBJECT
@@ -37,10 +37,13 @@ friend class qlineedit;
         virtual ~hk_kdecombobox(void);
 	virtual void set_value(const hk_string&);
 	virtual hk_string value(void);
+virtual void show_widget(void);
+virtual void hide_widget(void);
+virtual void close_widget(void);
 
     protected:
      virtual void focusInEvent ( QFocusEvent * );
-     virtual void focusOutEvent ( QFocusEvent * ); 
+     virtual void focusOutEvent ( QFocusEvent * );
      virtual void    widget_specific_tooltip_changed(void);
         virtual bool    datasource_enable(void);
         virtual bool    datasource_disable(void);
@@ -50,10 +53,11 @@ friend class qlineedit;
         virtual void    widget_specific_insert_mode(void);
         virtual void    widget_specific_row_deleted(void);
         virtual void    widget_specific_row_added(void);
+	virtual void widget_specific_enabled_changed(void);
         virtual void    widget_specific_mode_change(void);
         virtual void    after_store_changed_data(void);
         virtual void    widget_specific_font_changed(void);
-	virtual void	presentationmode_changed(void);
+	virtual bool	presentationmode_changed(void);
 
         virtual void resizeEvent (QResizeEvent *);
         virtual void keyPressEvent(QKeyEvent *);
