@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -11,7 +11,7 @@
 
 #ifndef HK_KDECSVexportDIALOG_H
 #define HK_KDECSVexportDIALOG_H
-
+#include "hk_kdecsvexportdialogbase.h"
 #include <qvariant.h>
 #include <qdialog.h>
 #include <hk_dsvisible.h>
@@ -27,13 +27,14 @@ class QLabel;
 class QLineEdit;
 class QPushButton;
 class QToolButton;
+class QProgressDialog;
 /**
  *
  *@short KDE frontend dialog to export data in CSV format
- *@version $Revision: 1.14 $
+ *@version $Revision: 1.17 $
  *@author Horst Knorr (hk_classes@knoda.org)
  */
-class hk_kdecsvexportdialog : public QDialog  ,public hk_reportcsv
+class hk_kdecsvexportdialog : public hk_kdecsvexportdialogbase  ,public hk_reportcsv
 {
     Q_OBJECT
 
@@ -41,38 +42,29 @@ class hk_kdecsvexportdialog : public QDialog  ,public hk_reportcsv
         hk_kdecsvexportdialog(const QString& table, QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
         ~hk_kdecsvexportdialog();
 
-        QLabel* TextLabel1;
-        QLineEdit* filefield;
-        QToolButton* filebutton;
-        QComboBox* tablelist;
-        QLabel* TextLabel3;
-        QCheckBox* firstrow;
-        QLabel* TextLabel1_3;
-        QLineEdit* textdelimiterfield;
-        QLabel* TextLabel1_2;
-        QLabel* TextLabel2;
-        QComboBox* columnseparatorfield;
-        QPushButton* buttonOk;
-        QPushButton* buttonCancel;
-        QPushButton* buttonHelp;
 
         void set_usetablelist(void);
         void set_usequerylist(void);
         void set_useviewlist(void);
         void set_database(hk_database* d);
+  public slots:
+      virtual void help_clicked();
+    virtual void listtype_changed();
+    virtual void morebutton_clicked();
+    
     protected slots:
         virtual void filebutton_clicked();
         virtual void buttons_enabled();
         virtual void ok_clicked(void);
+        void printing_cancelled(void);
 
     protected:
-        QHBoxLayout* hk_kdecsvexportdialogLayout;
-        QVBoxLayout* Layout12;
-        QHBoxLayout* Layout10;
-        QGridLayout* Layout11;
-        QVBoxLayout* Layout5;
+virtual void keyPressEvent ( QKeyEvent * e );
+ static  bool set_progress(long int,long int,const hk_string&);
     private:
 //  hk_exportcsv* p_export;
+        static bool p_cancelimport;
+static        QProgressDialog* p_progressdialog;
         void set_datasourcelist(void);
         QString      p_file;
         QString   p_tablename;
