@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,14 +8,16 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.35 $
-
+//$Revision: 1.45 $
+#include <assert.h>
 #include "hk_kdedbdesigner.h"
 #include "hk_kdeformdatasourcedialog.h"
 #include "hk_kderelationdialog.h"
+#include "hk_kdeaddtabledialog.h"
 #include <hk_presentation.h>
 #include <hk_datasource.h>
 #include <hk_dsdatavisible.h>
+#include <hk_referentialintegrity.h>
 #include <list>
 #include <qscrollview.h>
 #include <qlistbox.h>
@@ -40,9 +42,10 @@
 #include <kiconloader.h>
 #include <kapplication.h>
 #include <kconfig.h>
+#include <kaccelmanager.h>
 
-const int designwidth=2000;
-const int designheight=2000;
+const int designwidth=3000;
+const int designheight=3000;
 
 class hk_kdescrollview: public QScrollView
 {
@@ -110,6 +113,9 @@ kdedatasourcelabel::kdedatasourcelabel(hk_kdedatasourceframe* w):QLabel(w)
  setPaletteForegroundColor(palette().inactive().text());
  p_datasourceframe=w;
   setSizePolicy(QSizePolicy::Preferred,QSizePolicy::Fixed);
+#if KDE_VERSION_MAJOR >=3 && KDE_VERSION_MINOR >=4
+  KAcceleratorManager::setNoAccel(this);
+#endif
 }
 
 
@@ -118,17 +124,18 @@ void kdedatasourcelabel::mouseMoveEvent(QMouseEvent* event)
 
 if (p_drag && event->state()==Qt::LeftButton)
   {
-   int xdiff=event->globalPos().x()-p_startx;
-   int ydiff=event->globalPos().y()-p_starty;
+   QPoint localPos=event->globalPos();
+   int xdiff=localPos.x()-p_startx;
+   int ydiff=localPos.y()-p_starty;
    if ((abs(xdiff)>2) || (abs(ydiff)>2))
      {
- 	QPoint newPos=parentWidget()->pos()+QPoint(xdiff,ydiff);
+ 	QPoint newPos=p_datasourceframe->designer()->scrollview()->viewportToContents(parentWidget()->pos())+QPoint(xdiff,ydiff);
 	if (newPos.x()<0)
 	{
 	  p_offsetx+=newPos.x();
 	  newPos.setX(0);
 	}
-	else 
+	else
 	if (p_offsetx<0)
 	 {
 	   p_offsetx+=newPos.x();
@@ -156,8 +163,8 @@ if (p_drag && event->state()==Qt::LeftButton)
 		else newPos.setY(0);
 	  }
 	p_datasourceframe->designer()->scrollview()->moveChild(parentWidget(),newPos.x(),newPos.y());
-	p_startx=event->globalPos().x();
-	p_starty=event->globalPos().y();
+	p_startx=localPos.x();
+	p_starty=localPos.y();
     }
 
    }
@@ -214,9 +221,9 @@ void hk_kdefieldlist::clearFocus(void)
 		QListBox::clearFocus();
 	}
 
-	
 
-	
+
+
 
 
 void hk_kdefieldlist::mouseDoubleClickEvent(QMouseEvent* event)
@@ -230,7 +237,7 @@ if (item)
 if (p_datasourceframe->designer()->presentation()->presentationtype()!=hk_presentation::qbe)
    p_datasourceframe->edit();
 if (!field.isEmpty())
-   emit signal_field_doubleclicked(p_datasourceframe->datasource()->presentationnumber(),field.local8Bit().data());
+   emit signal_field_doubleclicked(p_datasourceframe->datasource()->presentationnumber(),u2l(field.utf8().data()));
 }
 
 
@@ -270,7 +277,9 @@ void hk_kdefieldlist::mouseReleaseEvent(QMouseEvent*)
 
 void hk_kdefieldlist::dragEnterEvent(QDragEnterEvent* event)
 {
-    event->accept(event->provides("application/x-hk_kdedbdesigner")&&event->source()!=this );
+    event->accept(event->provides("application/x-hk_kdedbdesigner")&&
+    (p_datasourceframe->designer()->presentation()->presentationtype()==hk_presentation::referentialintegrity
+     ||(p_datasourceframe->designer()->presentation()->presentationtype()!=hk_presentation::referentialintegrity &&event->source()!=this )));
 
 }
 
@@ -304,15 +313,20 @@ void hk_kdefieldlist::dropEvent(QDropEvent* event)
    						p_datasourceframe->designer()->get_dsframe(masterds),
          p_datasourceframe,p_datasourceframe->designer());
 
-	((QComboTableItem*)(d->grid->item(0,0)))->setCurrentItem(d->masterindex(QString::fromLocal8Bit(mastertxt.c_str())));
+	((QComboTableItem*)(d->grid->item(0,0)))->setCurrentItem(d->masterindex(QString::fromUtf8(l2u(mastertxt).c_str())));
 	if(itemAt(event->pos()))((QComboTableItem*)(d->grid->item(0,1)))->setCurrentItem(d->slaveindex(itemAt(event->pos())->text()));
 /*	if (((QComboTableItem*)(d->grid->item(0,0)))->currentItem()>0
 	    && ((QComboTableItem*)(d->grid->item(0,1)))->currentItem()>0
 	   ) d->add_row();*/d->slot_data_changed(0,0);
-	   
+
 
      if (d->exec()==QDialog::Accepted)
        {
+        if(p_datasourceframe->designer()->presentation()->presentationtype()==hk_presentation::referentialintegrity)
+        {
+        p_datasourceframe->designer()->set_all_relations();
+        }
+        else
           p_datasourceframe->designer()->add_relation(masterds,p_datasourceframe->datasource());
 
        }
@@ -370,7 +384,7 @@ hk_kdedatasourceframe::hk_kdedatasourceframe(hk_kdedbdesigner* designer,QWidget*
 	p_listbox=new hk_kdefieldlist(this);
 	p_header=new kdedatasourcelabel(this);
         p_listbox->installEventFilter(this);
-	p_header->installEventFilter(this); 
+	p_header->installEventFilter(this);
 	installEventFilter(this);
 	p_layout->addWidget(p_header,0,0);
 	p_layout->addWidget(p_listbox,1,0);
@@ -382,7 +396,7 @@ hk_kdedatasourceframe::hk_kdedatasourceframe(hk_kdedbdesigner* designer,QWidget*
 	p_layout->addWidget(mv,1,1);
 	mv=new  hk_kdemovewidget(hk_kdemovewidget::diagonal,this);
 	p_layout->addWidget(mv,2,1);
-	
+
 	p_positionupdate=true;
 	set_fields();
 	if (ds)
@@ -392,7 +406,7 @@ hk_kdedatasourceframe::hk_kdedatasourceframe(hk_kdedbdesigner* designer,QWidget*
 	else 	setGeometry(20,20,150,150);
 	p_designer->scrollview()->moveChild(this,QWidget::x(),QWidget::y());
 	p_positionupdate=false;
-	  
+
 
 }
 
@@ -408,7 +422,7 @@ bool hk_kdedatasourceframe::eventFilter(QObject* object,QEvent* e)
 		p_designer->presentation()->unique_datasourcename(datasource()->presentationnumber()))
 		,true))
        {
-       		designer()->delete_datasource(this); 
+       		designer()->delete_datasource(this);
        //event->accept();
        return true;
        }
@@ -419,12 +433,12 @@ return QFrame::eventFilter(object,e);
 
 
 void hk_kdedatasourceframe::set_fields(void)
-	{
+{
 	  if (!datasource())
 	   {
 	    cerr <<"hk_kdedatasourceframe::set_fields, NO DATASOURCE SET !!!"<<endl;
 	    return;
-	   } 
+	   }
 	  list<hk_string>* cols=datasource()->columnnames();
 	  if (!cols) return;
 	  if (p_designer->presentation()->presentationtype()==hk_presentation::qbe)
@@ -432,11 +446,11 @@ void hk_kdedatasourceframe::set_fields(void)
 	  list<hk_string>::iterator it=cols->begin();
 	  while (it!=cols->end())
 	  {
-	  	p_listbox->insertItem(QString::fromLocal8Bit((*it).c_str()));
+	  	p_listbox->insertItem(QString::fromUtf8(l2u((*it)).c_str()));
 		++it;
 	  }
 	  set_header();
-	}
+}
 
 
 
@@ -447,9 +461,9 @@ void hk_kdedatasourceframe::set_header(void)
 	 QString headertext;
 	 switch(p_designer->presentation()->presentationtype())
 	 {
-	  case hk_presentation::qbe 	:headertext=QString::fromLocal8Bit(p_designer->presentation()->unique_shortdatasourcename(datasource()->presentationnumber()).c_str());
+	  case hk_presentation::qbe 	:headertext=QString::fromUtf8(l2u(p_designer->presentation()->unique_shortdatasourcename(datasource()->presentationnumber())).c_str());
 	  				break;
-	  default : headertext=QString::fromLocal8Bit(p_designer->presentation()->unique_datasourcename(datasource()->presentationnumber()).c_str());
+	  default : headertext=QString::fromUtf8(l2u(p_designer->presentation()->unique_datasourcename(datasource()->presentationnumber())).c_str());
 	 }
 	 p_header->setText(headertext);
 	 int w=QFrame::width();
@@ -678,6 +692,43 @@ return NULL;
 }
 
 
+hk_kdedbrelation* hk_kdedbdesigner::get_relation(hk_datasource* ds)
+{
+  if (!ds) return NULL; cerr<<"get_relation:"<<ds->name()<<endl;
+  list<hk_kdedbrelation*>::iterator it=p_private->p_relationlist.begin();
+while (it!=p_private->p_relationlist.end())
+  	{
+	   if ((*it)->masterdatasource()->datasource()==ds|| (*it)->slavedatasource()->datasource()==ds)
+	   	{cerr <<"gefundene Relation"<<endl;
+		  return (*it);
+		}
+	   ++it;
+	}
+return NULL;
+
+}
+
+
+referentialclass* hk_kdedbdesigner::get_referentialintegrity(hk_datasource* master,hk_datasource* slave)
+{
+  if (!master ||!slave) return NULL;
+list <referentialclass>* rl= slave->referenceslist();
+list <referentialclass>::iterator rit=rl->begin();
+ while (rit!=rl->end())
+ {
+     if ((*rit).p_masterdatasource==master->name())
+     {
+       referentialclass* r=new referentialclass;
+       *r=*rit;
+       return r;
+      }
+   ++rit;
+ }
+return NULL;
+}
+
+
+
 
 
 
@@ -724,28 +775,79 @@ void hk_kdedbdesigner::set_datasources()
  {
     hk_kdedatasourceframe* f=add_dsframe((*it));
     if (!firstframe) firstframe=f;
-    
+
   ++it;
   }
+   set_all_relations();
 
+   p_private->p_presentation->set_block_has_changed(bf);
+   new_focus(firstframe);
+}
+
+
+void hk_kdedbdesigner::set_all_relations(void)
+{
+  list<hk_kdedbrelation*>::iterator relit=p_private->p_relationlist.begin();
+  while (relit!=p_private->p_relationlist.end())
+  {
+  hk_kdedbrelation* i=(*relit);
+  ++relit;
+  delete i;
+  }
+  p_private->p_relationlist.clear();
 
   list<hk_kdedatasourceframe*>::iterator sit=p_private->p_windowlist.begin();
   while (sit!=p_private->p_windowlist.end())
   	{
-	   hk_datasource* ds=(*sit)->datasource();
+	 hk_datasource* ds=(*sit)->datasource();
+         if(p_private->p_presentation->presentationtype()==hk_presentation::referentialintegrity)
+         {
+          list <referentialclass>* rl= ds->referenceslist();
+
+          list <referentialclass>::iterator rit=rl->begin();
+          while (rit!=rl->end())
+          {
+                add_referentialintegrity((*rit),(*sit));
+            ++rit;
+          }
+         }
+         else
+         {
 	   if (ds && ds->depending_on())
 	   {
+
                 add_relation(get_dsframe(ds->depending_on()),(*sit));
 	   }
+	 }
 	++sit;
 	}
 
 raise_datasources();
-   p_private->p_presentation->set_block_has_changed(bf);
-   new_focus(firstframe);
+
 }
 
 
+hk_datasource* hk_kdedbdesigner::already_added_table(const hk_string&t)
+{
+list<hk_datasource*>*l=p_private->p_presentation->datasources();
+list<hk_datasource*>::iterator it=l->begin();
+while (it!=l->end())
+{
+ hk_datasource* d=(*it);
+ if (d->type()==hk_datasource::ds_table && d->name()==t) return d;
+++it;
+}
+
+return NULL;
+}
+
+
+
+
+
+
+
+
 hk_kdedatasourceframe* hk_kdedbdesigner::add_dsframe(hk_datasource* ds)
 {
  if (!ds) return NULL;
@@ -763,15 +865,14 @@ hk_kdedbrelation* hk_kdedbdesigner::add_relation(hk_kdedatasourceframe* master,
 {
   if (!master||!slave) return NULL;
   if (slave&&slave->datasource()&&slave->datasource()->depending_on())
-    {  
+    {
        hk_kdedbrelation* r=get_relation(slave->datasource()->depending_on(),slave->datasource());
        if (r) delete_relation(r);
-    
+
     }
-  
-  
-  
-  hk_kdedbrelation* relation=new hk_kdedbrelation(p_private->p_scrollview->viewport());
+
+
+  hk_kdedbrelation* relation=new hk_kdedbrelation(p_private->p_scrollview->viewport(),p_private->p_presentation && p_private->p_presentation->presentationtype()==hk_presentation::referentialintegrity);
   p_private->p_scrollview->addChild(relation);
   relation->setAutoMask(true);
   relation->set_datasources(master,slave);
@@ -790,12 +891,43 @@ emit signal_definition_has_changed();
 
 hk_kdedbrelation* hk_kdedbdesigner::add_relation(hk_datasource* master, hk_datasource* slave)
 {
-  
+
   return add_relation(get_dsframe(master),get_dsframe(slave));
 }
 
 
 
+hk_kdedbrelation* hk_kdedbdesigner::add_referentialintegrity(referentialclass ref, hk_kdedatasourceframe* ds)
+{
+  hk_kdedatasourceframe* ms=get_dsframe(already_added_table(ref.p_masterdatasource));
+  if (!ds ||!ms) return NULL;
+
+
+  hk_kdedbrelation* relation=new hk_kdedbrelation(p_private->p_scrollview->viewport(),p_private->p_presentation && p_private->p_presentation->presentationtype()==hk_presentation::referentialintegrity);
+  p_private->p_scrollview->addChild(relation);
+  relation->setAutoMask(true);
+  relation->set_referentialintegrity(ref,ms,ds);
+  relation->setGeometry(10,50,100,70);
+  p_private->p_relationlist.insert(p_private->p_relationlist.end(),relation);
+  connect(relation,SIGNAL(signal_relation_clicked(hk_kdedbrelation*)),this,SLOT(relation_clicked(hk_kdedbrelation*)));
+  relation->show();
+  relation->raise();
+  relation->lower();
+  ds->set_header();
+emit signal_definition_has_changed();
+
+ return relation;
+
+}
+
+
+
+
+
+
+
+
+
 void hk_kdedbdesigner::raise_datasources(void)
 {
   list<hk_kdedatasourceframe*>::iterator sit=p_private->p_windowlist.begin();
@@ -813,23 +945,25 @@ void hk_kdedbdesigner::raise_datasources(void)
 void hk_kdedbdesigner::delete_datasource(hk_kdedatasourceframe* f)
 {
  if (!f) return;
-  p_private->p_windowlist.remove(f);
   if (f->datasource())
   {
   	//cerr<<"delete_datasource datasource!=NULL"<<endl;
   	list<hk_datasource*>* l=f->datasource()->dependinglist();
   	list<hk_datasource*>::iterator it=l->begin();
 	hk_kdedbrelation* rel=NULL;
-  	while (it!=l->end())
+  	/*while (it!=l->end())
    	{
    	 rel=get_relation(f->datasource(),(*it));
    	 if (rel) delete_relation(rel);
    	 ++it;
-    	}
-   rel=get_relation(f->datasource()->depending_on(),f->datasource());
-   if (rel) delete_relation(rel);
+    	}*/
+   while((rel=get_relation(f->datasource())))
+   {  cerr <<"REL: aus get_relation:"<<rel<<endl;
+      if (rel) remove_relation(rel);
+   }
   }
   else cerr <<"leere Datasource!!!"<<endl;
+  p_private->p_windowlist.remove(f);
   f->deleteLater();
   delete f->datasource();
 emit signal_definition_has_changed();
@@ -839,15 +973,23 @@ emit signal_definition_has_changed();
 
 void hk_kdedbdesigner::delete_relation(hk_kdedbrelation* r)
 {
+  if (presentation()->presentationtype()==hk_presentation::referentialintegrity)
+  {
+     r->slavedatasource()->datasource()->drop_reference(r->referentialname());
+  }
+  remove_relation(r);
+emit signal_definition_has_changed();
+}
 
+void hk_kdedbdesigner::remove_relation(hk_kdedbrelation* r)
+{
   p_private->p_relationlist.remove(r);
   r->slavedatasource()->datasource()->set_depending_on_presentationdatasource(-1);
   r->slavedatasource()->datasource()->clear_depending_fields();
   r->slavedatasource()->set_header();
   r->deleteLater();
-emit signal_definition_has_changed();
-}
 
+}
 
 
 void hk_kdedbdesigner::relation_clicked(hk_kdedbrelation* cr)
@@ -869,8 +1011,25 @@ while (it!=p_private->p_relationlist.end())
 
 void hk_kdedbdesigner::add_datasource(void)
 {
+assert(presentation()!=NULL);
+    if (!presentation())
+    {
+     show_warningmessage("No presentation set!");
+     return;
+    }
+    hk_kdeaddtabledialog* addtabledialog=new hk_kdeaddtabledialog(
+		this,
+		presentation()->presentationtype()!=hk_presentation::qbe,this
+		);
+    addtabledialog->exec();
+     if (addtabledialog->datasource_added())
+         emit signal_definition_has_changed();
+    delete addtabledialog;
+    return;
+
+/*
     hk_kdeformdatasourcedialog* d = new hk_kdeformdatasourcedialog(presentation(),this,0,true);
-    
+
     hk_kdeformdatasourcedialog::enum_displaytype dp=hk_kdeformdatasourcedialog::d_form;
     if (presentation()->presentationtype()!=hk_presentation::form)
        dp=(presentation()->presentationtype()==hk_presentation::report?
@@ -902,7 +1061,7 @@ void hk_kdedbdesigner::add_datasource(void)
 	}
 
     delete d;
-if (changed)emit signal_definition_has_changed();
+*/
 }
 
 
@@ -942,12 +1101,16 @@ emit signal_field_doubleclicked(t,c);
   const  int  arrowlength=5;
   const  int  arrowheight=5;
 
-hk_kdedbrelation::hk_kdedbrelation(QWidget* parent):QWidget(parent),hk_class()
+hk_kdedbrelation::hk_kdedbrelation(QWidget* parent,bool is_integrity):QWidget(parent),hk_class()
 {
 p_tox=p_toy=p_fromx=p_fromy=0;
 p_is_focused=false;
 setMouseTracking(true);
 setFocusPolicy(StrongFocus);
+p_is_referentialintegrity=is_integrity;
+if (is_integrity)setPaletteForegroundColor(blue);
+p_deletecascade=false;
+p_updatecascade=false;
 }
 
 hk_kdedbrelation::~hk_kdedbrelation()
@@ -962,15 +1125,22 @@ void hk_kdedbrelation::paint_relation(QPainter* paint)
    paint->drawLine(0,0,0,height());
    paint->drawLine(width()-1,0,width()-1,height());
 */
+    QPen p=paint->pen();
    if (p_is_focused)
    {
-    QPen p=paint->pen();
     p.setWidth(2);
     paint->setPen(p);
    }
    paint->drawLine(p_fromx+hlength,p_fromy+1,p_tox-hlength,p_toy+arrowheight); //diagonal
 
-    paint->drawLine(p_fromx,p_fromy+1,p_fromx+hlength,p_fromy+1);//master horizontal
+
+   int pw=p.width();
+   p.setWidth(pw*2+3);
+   paint->setPen(p);
+   paint->drawLine(p_fromx,p_fromy+1,p_fromx+hlength,p_fromy+1);//master horizontal
+   p.setWidth(pw);
+   paint->setPen(p);
+
    paint->drawLine(p_tox-hlength,p_toy+arrowheight,  p_tox ,p_toy+arrowheight);//slave horizontal
    if (p_is_focused)
    {
@@ -995,6 +1165,10 @@ void hk_kdedbrelation::paintEvent(QPaintEvent*)
   paint_relation(&paint);
 }
 
+hk_string hk_kdedbrelation::referentialname()const
+{
+  return p_refname;
+}
 
 void hk_kdedbrelation::updateMask(void)
 {
@@ -1032,19 +1206,63 @@ if (!master||!slave) return;
 }
 
 
-
-QString hk_kdedbrelation::tooltipfields(void)
+void hk_kdedbrelation::set_referentialintegrity(referentialclass c,hk_kdedatasourceframe* master,hk_kdedatasourceframe* slave)
 {
+if (!master||!slave) return;
+
+
+ p_masterdatasource=master;
+ p_slavedatasource=slave;
+ p_refname=c.p_name;
+ p_deletecascade=c.p_deletecascade;
+ p_updatecascade=c.p_updatecascade;
+  QToolTip::add(this,tooltipfields(&c));
+ connect(p_masterdatasource,SIGNAL(signal_moved()),this,SLOT(datasource_moved()));
+ connect(p_slavedatasource,SIGNAL(signal_moved()),this,SLOT(datasource_moved()));
+ datasource_moved();
+}
+
+
+bool hk_kdedbrelation::updatecascade(void) const
+{
+  return p_updatecascade;
+}
+
+bool hk_kdedbrelation::deletecascade(void) const
+{
+  return p_deletecascade;
+}
+
+QString hk_kdedbrelation::tooltipfields(referentialclass* c)
+{
+   QString result;
+   if (c)
+   {
+     list<dependingclass>::iterator it= c->p_fields.begin();
+     while (it!= c->p_fields.end())
+     {
+       if (!result.isEmpty()) result+="\n";
+       result+=	QString::fromUtf8(l2u((*it).masterfield).c_str())
+       		+"\t = " + QString::fromUtf8(l2u((*it).dependingfield).c_str());
+      ++it;
+     }
+       if (!result.isEmpty()) result+="\n________________\n";
+       result+=i18n("On update:") +(c->p_updatecascade?i18n("Cascade"):i18n("Restrict"))+"\n";
+       result+=i18n("On delete:") +(c->p_deletecascade?i18n("Cascade"):i18n("Restrict"));
+
+    return result;
+   }
+
+
    list<hk_string>* masterlist=p_slavedatasource->datasource()->depending_on_masterfields();
    list<hk_string>* slavelist=p_slavedatasource->datasource()->depending_on_thisfields();
    list<hk_string>::iterator masterit= masterlist->begin();
    list<hk_string>::iterator slaveit= slavelist->begin();
-   QString result;
    while (masterit!=masterlist->end())
    {
        if (!result.isEmpty()) result+="\n";
-       result+=	QString::fromLocal8Bit((*masterit).c_str())
-       		+"\t = " + QString::fromLocal8Bit((*slaveit).c_str());
+       result+=	QString::fromUtf8(l2u((*masterit)).c_str())
+       		+"\t = " + QString::fromUtf8(l2u((*slaveit)).c_str());
      ++masterit;
      ++slaveit;
    }
@@ -1161,7 +1379,7 @@ void hk_kdedbrelation::mouseDoubleClickEvent(QMouseEvent*)
 
 void hk_kdedbrelation::slot_relation_clicked(hk_kdedbrelation* cr)
 {  //cerr<<"hk_kdedbrelation::slot_relation_clicked" <<endl;
-   if (cr==this ) 
+   if (cr==this )
         {if (!p_is_focused) setFocus();}
      else
        p_is_focused=false;
@@ -1210,6 +1428,7 @@ if (res==id[1])
 else
 if (res==id[2])
 	{
+	p_masterdatasource->designer()->delete_relation(this);
 	}
 
 delete context;
@@ -1252,8 +1471,8 @@ p_private=new hk_kdedbdesignerwindowprivate;
    p_private->p_closeaction=new KAction(i18n("&Close"),"fileclose",0,this,SLOT(close()),actionCollection(),"closedesigner");
    setCentralWidget(designer());
    createGUI(p_private->p_part);
-     
-     
+
+
   KConfig* c=kapp->config();
   QRect rect(0,0,500,300);
   c->setGroup("DatabaseDesigner");
@@ -1281,7 +1500,11 @@ void hk_kdedbdesignerwindow::closeEvent(QCloseEvent* e)
 KConfig* c=kapp->config();
   c->setGroup("DatabaseDesigner");
   c->writeEntry("Geometry",geometry());
-
+if (designer()->presentation()&&
+    designer()->presentation()->presentationtype()==hk_presentation::referentialintegrity)
+    {
+    ((hk_referentialintegrity*)(designer()->presentation()))->save_referentialintegrity();
+    }
 emit signal_closed();
 KParts::MainWindow::closeEvent(e);
 }
@@ -1316,7 +1539,7 @@ hk_kdemovewidget::hk_kdemovewidget(enum_orientation orientation,QWidget*parent,c
 {
    p_drag=false;
    p_startx=p_starty=p_offsetx=p_offsety=0;
-   
+
    p_orientation=orientation;
    QSize s=QSize(mvfixed,mvfixed);
    setMinimumSize(s);
@@ -1327,7 +1550,7 @@ hk_kdemovewidget::hk_kdemovewidget(enum_orientation orientation,QWidget*parent,c
    		setSizePolicy(QSizePolicy::Preferred,QSizePolicy::Fixed);
    		setCursor(Qt::SizeVerCursor);
 		break;
-     
+
      case vertical:
    		setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Preferred);
    		setCursor(Qt::SizeHorCursor);
@@ -1336,7 +1559,7 @@ hk_kdemovewidget::hk_kdemovewidget(enum_orientation orientation,QWidget*parent,c
    		setSizePolicy(QSizePolicy::Preferred,QSizePolicy::Preferred);
    		setCursor(Qt::SizeFDiagCursor);
 		break;
-        
+
    }
 //setBackgroundColor(red);
 }
