@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -16,6 +16,7 @@
 #include <qframe.h>
 #include <kparts/mainwindow.h>
 #include <hk_dbvisible.h>
+#include <hk_referentialintegrity.h>
 #include <hk_dsdatavisible.h>
 
 
@@ -38,11 +39,15 @@ void set_presentation(hk_presentation*);
 hk_presentation* presentation(void);
 QScrollView* scrollview(void) const;
 hk_kdedatasourceframe* get_dsframe(hk_datasource*);
+hk_kdedbrelation* get_relation(hk_datasource* ds);
 hk_kdedbrelation* get_relation(hk_datasource* master,hk_datasource* slave);
 hk_kdedbrelation* get_relation(hk_kdedatasourceframe* master,hk_kdedatasourceframe* slave);
+referentialclass* get_referentialintegrity(hk_datasource* master,hk_datasource* slave);
 hk_kdedbrelation* add_relation(hk_kdedatasourceframe* master,hk_kdedatasourceframe* slave);
 hk_kdedbrelation* add_relation(hk_datasource* master,hk_datasource* slave);
+hk_kdedbrelation* add_referentialintegrity(referentialclass ref, hk_kdedatasourceframe* ds);
 hk_kdedatasourceframe* add_dsframe(hk_datasource*);
+  void set_all_relations(void);
 
 signals:
 void signal_definition_has_changed(void);
@@ -61,6 +66,10 @@ void slot_field_doubleclicked(int, const hk_string&);
 
 private:
   void raise_datasources(void);
+  hk_datasource* already_added_table(const hk_string&t);
+void remove_relation(hk_kdedbrelation*);
+
+
 hk_kdedbdesignerprivate* p_private;
 };
 
@@ -160,14 +169,18 @@ class hk_kdedbrelation:public QWidget,public hk_class
 {
 Q_OBJECT
 public:
-hk_kdedbrelation(QWidget* parent);
+hk_kdedbrelation(QWidget* parent,bool is_referentialinegrity);
 ~hk_kdedbrelation();
 void setAutoMask(bool);
 void set_datasources(hk_kdedatasourceframe* master,hk_kdedatasourceframe* slave);
+void set_referentialintegrity(referentialclass c,hk_kdedatasourceframe* master,hk_kdedatasourceframe* slave);
 hk_kdedatasourceframe* masterdatasource(void) const;
 hk_kdedatasourceframe* slavedatasource(void) const;
 void setFocus(void);
 void set_focus(void);
+hk_string referentialname()const;
+bool updatecascade()const;
+bool deletecascade()const;
 signals:
 void signal_relation_clicked(hk_kdedbrelation*);
 
@@ -181,7 +194,7 @@ void paint_relation(QPainter*);
 void paintEvent(QPaintEvent*);
 void keyPressEvent(QKeyEvent*);
 void updateMask(void);
-QString tooltipfields(void);
+QString tooltipfields(referentialclass* c=NULL);
 virtual void mouseMoveEvent(QMouseEvent*);
 virtual void mousePressEvent(QMouseEvent*);
 virtual void mouseDoubleClickEvent(QMouseEvent*);
@@ -196,6 +209,10 @@ hk_kdedatasourceframe* p_masterdatasource;
 hk_kdedatasourceframe* p_slavedatasource;
 int p_fromx,p_fromy,p_tox,p_toy;
 bool p_is_focused;
+bool p_is_referentialintegrity;
+hk_string p_refname;
+bool p_deletecascade;
+bool p_updatecascade;
 };
 
 
