@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,13 +8,14 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.22 $
+//$Revision: 1.26 $
 #include "hk_kdedblistview.h"
 #include <klocale.h>
 #include <kapplication.h>
 #include <kstandarddirs.h>
 #include <kglobalsettings.h>
 #include <kiconloader.h>
+#include <kconfig.h>
 #include <qprogressdialog.h>
 #include <qpushbutton.h>
 #include <qradiobutton.h>
@@ -35,7 +36,7 @@ QProgressDialog* hk_kdedblistview::p_progressdialog=NULL;
 
 
 
- 
+
 hk_dbviewerdrag::hk_dbviewerdrag(objecttype type,const QString& object,hk_database* db,QWidget* dragsource)
    :QStoredDrag("application/x-hk_filecopy",dragsource)
 {
@@ -44,9 +45,9 @@ hk_dbviewerdrag::hk_dbviewerdrag(objecttype type,const QString& object,hk_databa
 bool hk_dbviewerdrag::canDecode(const QMimeSource* s)
     {
     const char* f;
-    for (int i=0; (f=s->format(i)); i++) 
-    {   
-	if ( 0==qstrnicmp(f,"application/x-hk_filecopy",25) ) 
+    for (int i=0; (f=s->format(i)); i++)
+    {
+	if ( 0==qstrnicmp(f,"application/x-hk_filecopy",25) )
 	{
 	    return true;
 	}
@@ -66,7 +67,7 @@ const char* hk_dbviewerdrag::format(int i) const
 void hk_dbviewerdrag::create_draginfo(objecttype type,const QString& object,hk_database* db)
 {
     hk_string mystring="<NAME>";
-    mystring+=object.local8Bit().data();
+    mystring+=u2l(object.utf8().data());
     mystring+="</NAME>\n<TYPE>";
     switch (type)
     {
@@ -90,7 +91,7 @@ void hk_dbviewerdrag::create_draginfo(objecttype type,const QString& object,hk_d
 
 
 
-// hk_dbviewerdrag END 
+// hk_dbviewerdrag END
 
 
 
@@ -151,6 +152,7 @@ hk_kdeschemadialog::~hk_kdeschemadialog()
 
 
 
+bool hk_kdedblistview::p_use_singleclick=false;//if false double click starts an item
 
 
 class hk_kdedblistviewprivate
@@ -176,10 +178,9 @@ KListViewItem* p_formitem;
 KListViewItem* p_reportitem;
 hk_kdeschemadialog* p_schemadialog;
 hk_kdedblistview::enum_showmode p_showmode;
-void clearList(KListViewItem*);      
+void clearList(KListViewItem*);
 bool p_dragging;
 objecttype otype;
-
 QPoint p_dragstartposition;
                                                   //decoded drag&dropvalues
 hk_string xname,xtype,xdirectory,xserver,xhost,xtcp,xuser,xdbname;
@@ -213,7 +214,9 @@ KListView(parent,name), hk_dbvisible()
   connect(this, SIGNAL(dropped(QDropEvent*,QListViewItem*)),this,SLOT(slot_drop(QDropEvent*)));
   setAcceptDrops(true);
   setDragEnabled(true);
-
+  KConfig* c=kapp->config();
+  c->setGroup("Preferences");
+  p_use_singleclick=c->readBoolEntry("UseSingleclick",false);
 
 }
 
@@ -236,16 +239,20 @@ void hk_kdedblistview::init_listview()
   setSortColumn(-1);
   p_private->p_databaseitem=new KListViewItem(this,i18n("<No database>"));
   p_private->p_databaseitem->setPixmap(0,loader->loadIcon("contents",KIcon::Small));
-  
+
   p_private->p_reportitem=new KListViewItem(p_private->p_databaseitem,i18n("Reports"));
   p_private->p_reportitem->setPixmap(0,loader->loadIcon("fileprint",KIcon::Small));
-  
+
   p_private->p_formitem=new KListViewItem(p_private->p_databaseitem,i18n("Forms"));
   p_private->p_formitem->setPixmap(0,loader->loadIcon("openterm",KIcon::Small));
 
+  if (database() && database()->connection()->server_supports(hk_connection::SUPPORTS_SQL))
+   {
   p_private->p_queryitem=new KListViewItem(p_private->p_databaseitem,i18n("Queries"));
   p_private->p_queryitem->setPixmap(0,loader->loadIcon("filefind",KIcon::Small));
-  
+   }
+   else
+   p_private->p_queryitem=NULL;
   if (p_private->p_showmode==hk_kdedblistview::sm_all)
   {
   if (database() && database()->connection()->server_supports(hk_connection::SUPPORTS_VIEWS))
@@ -259,8 +266,8 @@ void hk_kdedblistview::init_listview()
    }
   p_private->p_tableitem=new KListViewItem(p_private->p_databaseitem,i18n("Tables"));
   p_private->p_tableitem->setPixmap(0,loader->loadIcon("view_text",KIcon::Small));
-  
-  } 
+
+  }
   else p_private->p_tableitem=NULL;
   p_private->p_databaseitem->setOpen(true);
 }
@@ -280,7 +287,7 @@ objecttype hk_kdedblistview::current_objecttype()
             else
             if (is_formitem(currentItem())) return ot_form;
                 else return ot_report;
- 
+
 }
 
 
@@ -289,9 +296,9 @@ void hk_kdedblistview::set_database(hk_database* db)
 {
   hk_dbvisible::set_database(db);
   if (db) init_listview();
-  
+
   set_databasename();
-  
+
 
 
 }
@@ -301,8 +308,8 @@ void hk_kdedblistview::set_database(hk_database* db)
 
 void hk_kdedblistview::set_databasename(void)
 {
-if (p_database && p_database->name().size()>0) 
-    p_private->p_databaseitem->setText(0,QString::fromLocal8Bit(p_database->name().c_str()));
+if (p_database && p_database->name().size()>0)
+    p_private->p_databaseitem->setText(0,QString::fromUtf8(l2u(p_database->name()).c_str()));
     else
     p_private->p_databaseitem->setText(0,i18n("<No database>"));
 set_tables();
@@ -314,7 +321,7 @@ set_reports();
 
 void hk_kdedblistview::set_tables(void)
 {
-  
+
   if (!p_database||p_private->p_showmode!=hk_kdedblistview::sm_all) return;
   p_private->clearList(p_private->p_tableitem);
   vector<hk_string>* tb=p_database->tablelist();
@@ -322,7 +329,7 @@ void hk_kdedblistview::set_tables(void)
   if (tb!=NULL)
   {
       for(it=tb->rbegin();it!=tb->rend();it++)
-       new KListViewItem(p_private->p_tableitem,QString::fromLocal8Bit((*it).c_str()));
+       new KListViewItem(p_private->p_tableitem,QString::fromUtf8(l2u((*it)).c_str()));
   }
   p_private->p_tableitem->sortChildItems(0,true);
 }
@@ -330,7 +337,7 @@ void hk_kdedblistview::set_tables(void)
 
 void hk_kdedblistview::set_views(void)
 {
-  
+
   if (!p_database||p_private->p_showmode!=hk_kdedblistview::sm_all) return;
   if (!p_private->p_viewitem) return;
   p_private->clearList(p_private->p_viewitem);
@@ -339,7 +346,7 @@ void hk_kdedblistview::set_views(void)
   if (tb!=NULL)
   {
       for(it=tb->rbegin();it!=tb->rend();it++)
-       new KListViewItem(p_private->p_viewitem,QString::fromLocal8Bit((*it).c_str()));
+       new KListViewItem(p_private->p_viewitem,QString::fromUtf8(l2u((*it)).c_str()));
   }
   p_private->p_viewitem->sortChildItems(0,true);
 }
@@ -347,11 +354,12 @@ void hk_kdedblistview::set_views(void)
 
 void hk_kdedblistview::set_queries(void)
 {
+  if (!p_private->p_queryitem) return;
   QString text=i18n("Queries");
-  if (p_database&& 
+  if (p_database&&
       ((p_database->loadmode(ft_query)==hk_database::central && p_private->p_showmode==sm_all)
       ||(p_private->p_showmode==sm_central)
-      )  
+      )
      )
      text+=i18n(" (Central)");
   p_private->p_queryitem->setText(0,text);
@@ -365,13 +373,13 @@ void hk_kdedblistview::set_queries(void)
     case hk_kdedblistview::sm_local: tb=p_database->local_filelist(ft_query);break;
     default: tb=p_database->querylist();
   }
-  
-  
+
+
   vector<hk_string>::reverse_iterator it;
   if (tb!=NULL)
   {
       for(it=tb->rbegin();it!=tb->rend();it++)
-       new KListViewItem(p_private->p_queryitem,QString::fromLocal8Bit((*it).c_str()));
+       new KListViewItem(p_private->p_queryitem,QString::fromUtf8(l2u((*it)).c_str()));
   }
   p_private->p_queryitem->sortChildItems(0,true);
 }
@@ -382,10 +390,10 @@ void hk_kdedblistview::set_queries(void)
 void hk_kdedblistview::set_forms(void)
 {
   QString text=i18n("Forms");
-  if (p_database&& 
+  if (p_database&&
       ((p_database->loadmode(ft_form)==hk_database::central && p_private->p_showmode==sm_all)
       ||(p_private->p_showmode==sm_central)
-      )  
+      )
      )
      text+=i18n(" (Central)");
   p_private->p_formitem->setText(0,text);
@@ -405,11 +413,11 @@ void hk_kdedblistview::set_forms(void)
       it=tb->rbegin();
       while(it!=tb->rend())
        {
-        new KListViewItem(p_private->p_formitem,QString::fromLocal8Bit((*it).c_str()));
+        new KListViewItem(p_private->p_formitem,QString::fromUtf8(l2u((*it)).c_str()));
         it++;
        }
   }
-  p_private->p_queryitem->sortChildItems(0,true);
+  if (p_private->p_queryitem)p_private->p_queryitem->sortChildItems(0,true);
 }
 
 
@@ -417,10 +425,10 @@ void hk_kdedblistview::set_forms(void)
 void hk_kdedblistview::set_reports(void)
 {
   QString text=i18n("Reports");
-  if (p_database&& 
+  if (p_database&&
       ((p_database->loadmode(ft_report)==hk_database::central && p_private->p_showmode==sm_all)
       ||(p_private->p_showmode==sm_central)
-      )  
+      )
      )
      text+=i18n(" (Central)");
   p_private->p_reportitem->setText(0,text);
@@ -438,54 +446,75 @@ void hk_kdedblistview::set_reports(void)
   if (tb!=NULL)
   {
       for(it=tb->rbegin();it!=tb->rend();it++)
-       new KListViewItem(p_private->p_reportitem,QString::fromLocal8Bit((*it).c_str()));
+       new KListViewItem(p_private->p_reportitem,QString::fromUtf8(l2u((*it)).c_str()));
   }
- p_private->p_queryitem->sortChildItems(0,true);
+ if (p_private->p_queryitem)p_private->p_queryitem->sortChildItems(0,true);
 }
 
 
 void hk_kdedblistview::item_clicked(QListViewItem* item)
 {
-  if (!item) return;
-      
+  if (p_use_singleclick) item_selected(item);
+
 }
 
 void hk_kdedblistview::item_doubleclicked(QListViewItem* item)
+{
+  if (!p_use_singleclick) item_selected(item);
+}
+
+void hk_kdedblistview::set_use_singleclick(bool u)
+{
+p_use_singleclick=u;
+  KConfig* c=kapp->config();
+  c->setGroup("Preferences");
+  c->writeEntry("UseSingleclick",p_use_singleclick);
+}
+
+bool hk_kdedblistview::use_singleclick(void)
+{
+  return p_use_singleclick;
+}
+
+
+
+
+void hk_kdedblistview::item_selected(QListViewItem* item)
 {
   if (!item) return;
-  if (item->parent()==p_private->p_tableitem) 
+  if (item->parent()==p_private->p_tableitem)
       emit signal_viewmode_table(item->text(0));
   else
-  if (item->parent()==p_private->p_queryitem) 
+  if (p_private->p_queryitem && item->parent()==p_private->p_queryitem)
       emit signal_viewmode_query(item->text(0));
   else
-  if (p_private->p_viewitem && item->parent()==p_private->p_viewitem) 
+  if (p_private->p_viewitem && item->parent()==p_private->p_viewitem)
       emit signal_viewmode_view(item->text(0));
 else
-  if (item->parent()==p_private->p_formitem) 
+  if (item->parent()==p_private->p_formitem)
       emit signal_viewmode_form(item->text(0));
 else
-  if (item->parent()==p_private->p_reportitem) 
+  if (item->parent()==p_private->p_reportitem)
       emit signal_viewmode_report(item->text(0));
 else
-  if (item==p_private->p_tableitem&& !runtime_only() &&p_database&& p_database->name().size()>0) 
+  if (item==p_private->p_tableitem&& !runtime_only() &&p_database&& p_database->name().size()>0)
       emit signal_new_table();
   else
-  if (item==p_private->p_queryitem&& !runtime_only()&&p_database&& p_database->name().size()>0) 
+  if (item==p_private->p_queryitem&& !runtime_only()&&p_database&& p_database->name().size()>0)
       emit signal_new_query();
 else
-  if (item==p_private->p_viewitem&& !runtime_only()&&p_database&& p_database->name().size()>0) 
+  if (item==p_private->p_viewitem&& !runtime_only()&&p_database&& p_database->name().size()>0)
       emit signal_new_view();
 else
-  if (item==p_private->p_formitem&& !runtime_only()&&p_database&& p_database->name().size()>0) 
+  if (item==p_private->p_formitem&& !runtime_only()&&p_database&& p_database->name().size()>0)
       emit signal_new_form();
 else
-  if (item==p_private->p_reportitem&& !runtime_only()&&p_database&& p_database->name().size()>0) 
+  if (item==p_private->p_reportitem&& !runtime_only()&&p_database&& p_database->name().size()>0)
       emit signal_new_report();
 else
-  if (item==p_private->p_databaseitem&& !runtime_only()&&p_database) 
+  if (item==p_private->p_databaseitem&& !runtime_only()&&p_database)
       emit signal_new_database();
-      
+
 }
 
 
@@ -502,7 +531,7 @@ bool hk_kdedblistview::is_tableitem(QListViewItem*item,bool includingheader)
 
 bool hk_kdedblistview::is_queryitem(QListViewItem*item,bool includingheader)
 {
-  if (!item) return false;
+  if (!item||!p_private->p_queryitem) return false;
   if (includingheader && item==p_private->p_queryitem) return true;
   if (item->parent()==p_private->p_queryitem) return true;
   return false;
@@ -546,10 +575,72 @@ bool hk_kdedblistview::is_headeritem(QListViewItem* item)
 	  item==p_private->p_queryitem ||
 	  item==p_private->p_viewitem ||
 	  item==p_private->p_formitem ||
-	  item==p_private->p_reportitem 
+	  item==p_private->p_reportitem
 	 );
 }
 
+bool hk_kdedblistview::is_tableheader(QListViewItem* item)
+{
+   return item==p_private->p_tableitem;
+}
+
+bool hk_kdedblistview::is_queryheader(QListViewItem* item)
+{
+   return item==p_private->p_queryitem;
+}
+
+bool hk_kdedblistview::is_viewheader(QListViewItem* item)
+{
+   return item==p_private->p_viewitem;
+}
+
+bool hk_kdedblistview::is_formheader(QListViewItem* item)
+{
+   return item==p_private->p_formitem;
+}
+
+bool hk_kdedblistview::is_reportheader(QListViewItem* item)
+{
+   return item==p_private->p_reportitem;
+}
+
+
+
+
+
+
+bool hk_kdedblistview::is_tableheader(void)
+{
+   return is_tableheader(currentItem());
+}
+
+bool hk_kdedblistview::is_queryheader(void)
+{
+   return is_queryheader(currentItem());
+}
+
+bool hk_kdedblistview::is_viewheader(void)
+{
+   return is_viewheader(currentItem());
+}
+
+bool hk_kdedblistview::is_formheader(void)
+{
+   return is_formheader(currentItem());
+}
+
+bool hk_kdedblistview::is_reportheader(void)
+{
+   return is_reportheader(currentItem());
+}
+
+
+
+
+
+
+
+
 bool hk_kdedblistview::is_tableitem(bool includeheader)
 {
 return is_tableitem(currentItem(),includeheader);
@@ -597,7 +688,7 @@ return is_headeritem(currentItem());
 
 
 void hk_kdedblistview::new_clicked()
-{ 
+{
     if (is_tableitem(currentItem(),true)) emit signal_new_table();
     else
     if (is_queryitem(currentItem(),true)) emit signal_new_query();
@@ -609,7 +700,7 @@ void hk_kdedblistview::new_clicked()
     if (is_databaseitem(currentItem())) emit signal_new_database();
     else
     if (is_viewitem(currentItem(),true)) emit signal_new_view();
-    
+
 
 }
 
@@ -641,7 +732,7 @@ void hk_kdedblistview::delete_clicked()
     if (is_reportitem(currentItem(),true)) emit signal_delete_report(currentItem()->text(0));
     else
     if (is_databaseitem(currentItem())) emit signal_delete_database(currentItem()->text(0));
-    
+
 
 }
 
@@ -685,8 +776,8 @@ bool hk_kdedblistview::acceptDrag(QDropEvent* event) const
 {
      bool cancreate=true;
    hk_string xtype;
-    if (!event) return false; 
-    if (!event->encodedData("application/x-hk_filecopy") ) 
+    if (!event) return false;
+    if (!event->encodedData("application/x-hk_filecopy") )
       {
          cerr <<"event->encodedData ==NULL!!!"<<endl;
 	 return false;
@@ -707,7 +798,7 @@ bool hk_kdedblistview::acceptDrag(QDropEvent* event) const
 
 void hk_kdedblistview::slot_drop(QDropEvent* event)
 {
-    if(decode_action(event)) 
+    if(decode_action(event))
        {
        execute_action();
        event->accept();
@@ -814,10 +905,10 @@ bool hk_kdedblistview::copy_presentationfile(void)
     }
     hk_database* db=newcon->new_database(p_private->xdbname);
     hk_string input=db->load(p_private->xname,(filetype)p_private->otype);
-    
+
       database()->save(input,p_private->xname,(filetype)p_private->otype,true,true);
-    
-   return true;    
+
+   return true;
 }
 
 
@@ -864,7 +955,7 @@ bool hk_kdedblistview::copy_table(void)
 
 
 bool hk_kdedblistview::copy_view(void)
-{ 
+{
     if (!database()) return false;
     hk_connection* con=find_connection();
     hk_connection* newcon=database()->connection()->drivermanager()->new_connection(p_private->xserver);
@@ -874,7 +965,7 @@ bool hk_kdedblistview::copy_view(void)
     if (con) newcon->set_password(con->password());
     newcon->connect();
     if (!newcon->is_connected())
-    {   
+    {
         delete newcon;
         return false;
     }
@@ -908,7 +999,7 @@ bool hk_kdedblistview::set_progress(long int position,long int total,const hk_st
     if (p_progressdialog)
     {
 
-        p_progressdialog->setCaption(QString::fromLocal8Bit(txt.c_str()));
+        p_progressdialog->setCaption(QString::fromUtf8(l2u(txt).c_str()));
         p_progressdialog->setTotalSteps(total);
         p_progressdialog->setProgress(position);
         qApp->processEvents();
@@ -961,7 +1052,7 @@ hk_connection* hk_kdedblistview::find_connection(void)
 
 
 QDragObject* hk_kdedblistview::dragObject()
-{ 
+{
     return new hk_dbviewerdrag(current_objecttype(),currentItem()->text(0),database(),this);
 }
 
@@ -976,7 +1067,7 @@ void hk_kdedblistview::paste(void)
 {
   if(decode_action(QApplication::clipboard()->data(QClipboard::Clipboard))
     ) execute_action();
-  
+
 }
 void hk_kdedblistview::reload_lists()
 {
@@ -984,7 +1075,7 @@ void hk_kdedblistview::reload_lists()
    list_changes(lt_query);
    list_changes(lt_form);
    list_changes(lt_report);
-   
+
 }
 
 
