@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,16 +8,18 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.16 $
+//$Revision: 1.27 $
 
 #include "hk_kdeformpartwidget.h"
 #include "hk_kdetoolbar.h"
 #include "hk_kdesimpleform.h"
 #include "hk_kderowselector.h"
+#include "hk_kdesimplegrid.h"
 #include "../hk_kdegridpart/hk_kdegridpart.h"
 #include "../hk_kdeformpart/hk_kdeformpart.h"
 #include "hk_kdeformfocus.h"
 #include "hk_kdetaborder.h"
+#include "hk_kdeproperty.h"
 
 #include <qbuttongroup.h>
 #include <qlabel.h>
@@ -134,15 +136,18 @@ hk_kdeformpartwidget::hk_kdeformpartwidget( hk_kdeformpart* formpart,QWidget* pa
     p_selectoraction=new KRadioAction("Selector",loader->loadIcon("rowselector22x22",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"selector");
     p_buttonaction=new KRadioAction("Button",loader->loadIcon("button",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"button");
     p_subformaction=new KRadioAction("Subform","openterm",0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"subform");
+    p_imageaction=new KRadioAction("Image",loader->loadIcon("image",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"image");
+    p_tabwidgetaction=new KRadioAction("Tabwidget","",0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"tabwidget");
+    p_dateaction=new KRadioAction("date","kontact_date",0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"date");
     p_bulkaction=new KActionMenu(i18n("Set to all"),0,formpart->actionCollection(),"bulk");
     p_bulkfontaction=new KAction(i18n("Font"),0,0,this,SLOT(bulkfont_clicked()),formpart->actionCollection(),"bulkfont");
     p_bulkforegroundcolouraction=new KAction(i18n("Foregroundcolour"),0,0,this,SLOT(bulkforegroundcolour_clicked()),formpart->actionCollection(),"bulkforeground");
     p_bulkbackgroundcolouraction=new KAction(i18n("Backgroundcolour"),0,0,this,SLOT(bulkbackgroundcolour_clicked()),formpart->actionCollection(),"bulkbackground");
-    
+
     p_taborderaction=new KAction(i18n("Tab order"),"bottom",0,this,SLOT(taborder_clicked()),formpart->actionCollection(),"taborder");
-    
-    
-    
+
+
+
     p_bulkaction->insert(p_bulkfontaction);
     p_bulkaction->insert(p_bulkforegroundcolouraction);
     p_bulkaction->insert(p_bulkbackgroundcolouraction);
@@ -157,6 +162,9 @@ hk_kdeformpartwidget::hk_kdeformpartwidget( hk_kdeformpart* formpart,QWidget* pa
     p_selectoraction->setExclusiveGroup("design");
     p_buttonaction->setExclusiveGroup("design");
     p_subformaction->setExclusiveGroup("design");
+    p_imageaction->setExclusiveGroup("design");
+    p_tabwidgetaction->setExclusiveGroup("design");
+    p_dateaction->setExclusiveGroup("design");
 
     p_pointeraction->setToolTip( i18n( "select" ) );
     p_labelaction->setToolTip( i18n( "textlabel" ));
@@ -172,8 +180,8 @@ hk_kdeformpartwidget::hk_kdeformpartwidget( hk_kdeformpart* formpart,QWidget* pa
     connect( p_form, SIGNAL( field_created() ), this, SLOT( field_created() ) );
     connect( p_form, SIGNAL( signal_focuswidget_changed() ), this, SLOT( slot_focuswidget_changed() ) );
 
-    
-    
+
+
     p_deleteaction=new KAction(i18n("&Delete"),Key_Delete,p_form,SLOT(delete_widgets()),formpart->actionCollection(),"deleteclicked");
     p_copyaction=new KAction(i18n("&Copy"),CTRL+Key_C,p_form,SLOT(copy()),formpart->actionCollection(),"copy");
     p_pasteaction=new KAction(i18n("&Paste"),CTRL+Key_V,p_form,SLOT(paste()),formpart->actionCollection(),"paste");
@@ -205,14 +213,15 @@ hk_kdeformpartwidget::hk_kdeformpartwidget( hk_kdeformpart* formpart,QWidget* pa
     p_alignaction->insert(p_alignbottomaction);
     p_dbdesigneraction=new KAction(i18n("Database designer"),loader->loadIcon("dbdesigner",KIcon::User),0,p_form,SLOT(dbdesignaction()),formpart->actionCollection(),"dbdesigner");
 
-    
-    
-    
-    
-    
-    
-    
-    
+    p_withlabelaction=new KToggleAction(i18n("with label"),"attach",0,this,SLOT(withlabelbutton_clicked()),formpart->actionCollection(),"withlabel");
+
+    p_definegridcolumnaction=new KAction(i18n("Define columns"),0,0,this,SLOT(show_gridcolumndialog()),formpart->actionCollection(),"gridcolumndialog");
+    p_definegridcolumnaction->setEnabled(false);
+
+
+
+
+
     toolbar = new hk_kdetoolbar( this, "toolbar" );
     p_filterdefinitionaction=new KAction(i18n("Filterdefinition"),loader->loadIcon("filter",KIcon::User),0,toolbar,SLOT(filterdefinebutton_clicked()),formpart->actionCollection(),"filterdefinition");
     p_filterexecaction=new KToggleAction(i18n("Filterexecution"),loader->loadIcon("filterexec",KIcon::User),0,toolbar,SLOT(filterexecbutton_clicked()),formpart->actionCollection(),"filterexec");
@@ -226,7 +235,7 @@ hk_kdeformpartwidget::hk_kdeformpartwidget( hk_kdeformpart* formpart,QWidget* pa
     connect(p_form,SIGNAL(signal_has_changed()),this,SLOT(slot_has_changed()));
     connect (QApplication::clipboard(), SIGNAL(dataChanged()),this, SLOT(clipboard_changed()));
 p_form->reset_has_changed();
-    
+
 }
 
 
@@ -238,6 +247,8 @@ hk_kdeformpartwidget::~hk_kdeformpartwidget()
 #ifdef HK_DEBUG
     hkdebug("hk_kdeformpartwidget::~hk_kdeformpartwidget");
 #endif
+   cerr <<p_form->hk_form::name()<<" callerform:"<<caller_form()<<endl;
+     emit signal_raise_form(caller_form());
     delete p_rowselector;
 }
 
@@ -258,7 +269,7 @@ void    hk_kdeformpartwidget::set_mode(hk_presentation::enum_mode s)
     hkdebug("hk_kdeformpartwidget::set_mode(s)");
 #endif
 
-    p_form->set_mode(s);
+    if (!p_form->set_mode(s))return;
     if (mode()==hk_presentation::viewmode)
     {
         p_copyaction->setEnabled(true);
@@ -266,6 +277,9 @@ void    hk_kdeformpartwidget::set_mode(hk_presentation::enum_mode s)
         p_pasteaction->setEnabled(true);
         p_deleteaction->setEnabled(false);
 	p_dbdesigneraction->setEnabled(false);
+    	p_imageaction->setEnabled(false);
+    	p_tabwidgetaction->setEnabled(false);
+    	p_dateaction->setEnabled(false);
 
     }
     else
@@ -319,6 +333,11 @@ void    hk_kdeformpartwidget::set_mode(hk_presentation::enum_mode s)
         p_subformaction->setEnabled(true);
 	p_formpropertyaction->setEnabled(true);
 	p_taborderaction->setEnabled(true);
+    	p_imageaction->setEnabled(true);
+    	p_tabwidgetaction->setEnabled(true);
+    	p_dateaction->setEnabled(true);
+    	p_form->setEnabled(true);
+    	if (propertyeditor())propertyeditor()->setEnabled(true);
     }
     p_form->repaint(0,0,p_form->QWidget::width(),p_form->QWidget::height(),true);
 
@@ -510,7 +529,6 @@ save_form_when_changed();
     hkdebug("hk_kdeformpartwidget::closeEvent nach abspeichern");
 #endif
    emit signal_closed(this);
-
     QWidget::closeEvent(e);
 }
 
@@ -520,6 +538,8 @@ void hk_kdeformpartwidget::save_form_when_changed(void)
 
    if (p_form &&p_form->has_changed())
     {
+
+    if (propertyeditor())propertyeditor()->identifier_changed();
         if (toolbar->is_filter_activated())
             toolbar->deactivate_filter();
         p_form->save_form();
@@ -571,7 +591,7 @@ void hk_kdeformpartwidget::load_form(const hk_string& n)
 //  p_form->formname(n);
     p_form->load_form(n);
     p_rowselector->set_presentationdatasource(p_form->presentationdatasource(),false);
-    if (p_form->datasource())toolbar->set_filter(QString::fromLocal8Bit(p_form->datasource()->temporaryfilter().c_str()));
+    if (p_form->datasource())toolbar->set_filter(QString::fromUtf8(l2u(p_form->datasource()->temporaryfilter()).c_str()));
     set_caption();
 }
 
@@ -609,6 +629,12 @@ void hk_kdeformpartwidget::fieldbutton_clicked(void)
                             if (p_selectoraction->isChecked()) thisfield=hk_visible::rowselector;
                             else
                             if (p_subformaction->isChecked()) thisfield=hk_visible::subform;
+                            else
+                            if (p_imageaction->isChecked()) thisfield=hk_visible::image;
+                            else
+                            if (p_tabwidgetaction->isChecked()) thisfield=hk_visible::tabvisible;
+                            else
+                            if (p_dateaction->isChecked()) thisfield=hk_visible::date;
   p_form->set_field2create(thisfield);
 }
 
@@ -651,6 +677,7 @@ void hk_kdeformpartwidget::save_form(void)
 /* if (toolbar->is_filter_activated())
     toolbar->deactivate_filter();
 */
+    if (propertyeditor())propertyeditor()->identifier_changed();
     p_form->save_form("",false);
     set_caption();
 
@@ -667,7 +694,7 @@ void hk_kdeformpartwidget::saveas_form(void)
 
     hk_string oldname=p_form->hk_presentation::name();
     p_form->set_name("");
-    if (p_form->save_form("",false))
+    if (p_form->save_form("",true))
     {
         set_caption();
     }
@@ -688,13 +715,13 @@ void hk_kdeformpartwidget::set_caption(void)
     hk_datasource* d=p_form->datasource();
     if (d!=NULL)
     {
-        if (!v)formname=QString::fromLocal8Bit(d->database()->connection()->drivername().c_str())+" "+formname;
-   
+        if (!v)formname=QString::fromUtf8(l2u(d->database()->connection()->drivername()).c_str())+" "+formname;
+
     }
-     formname+=QString::fromLocal8Bit (	
+     formname+=QString::fromUtf8 (l2u(
         p_form->label().size()>0?
-	p_form->label().c_str():
-	p_form->hk_presentation::name().c_str()
+	p_form->label():
+	p_form->hk_presentation::name()).c_str()
 );
     setCaption( formname  );
     if (v) v->setCaption(formname);
@@ -730,7 +757,7 @@ hk_kdeproperty* hk_kdeformpartwidget::propertyeditor(void)
 
 void hk_kdeformpartwidget::grid_partinfocus(hk_kdegridpart* )
 {
-//createGUI(p); 
+//createGUI(p);
 }
 
 void hk_kdeformpartwidget::grid_partoutfocus(hk_kdegridpart*)
@@ -742,12 +769,24 @@ void hk_kdeformpartwidget::grid_partoutfocus(hk_kdegridpart*)
 
 void hk_kdeformpartwidget::slot_focuswidget_changed(void)
 {
-        p_copyaction->setEnabled(p_form->formfocus()&&p_form->formfocus()->widget());
-        p_cutaction->setEnabled(p_form->formfocus()&&p_form->formfocus()->widget());
-        p_deleteaction->setEnabled(p_form->formfocus()&&p_form->formfocus()->widget());
+    p_copyaction->setEnabled(p_form->formfocus()&&p_form->formfocus()->widget());
+    p_cutaction->setEnabled(p_form->formfocus()&&p_form->formfocus()->widget());
+    p_deleteaction->setEnabled(p_form->formfocus()&&p_form->formfocus()->widget());
     p_resizeaction->setEnabled(mode()==hk_presentation::designmode&&p_form->focus_multipleselected());
     p_alignaction->setEnabled(mode()==hk_presentation::designmode&&p_form->focus_multipleselected());
-
+    QWidget* gridwidget=NULL;
+    QWidget* object =p_form->formfocus()->widget();
+    while (object!=NULL)
+    {
+       if ( dynamic_cast <hk_kdegrid*>(object)!=NULL  )
+       {
+        gridwidget=object;
+        object=NULL;
+       }
+       else    object=object->parentWidget();
+    }
+    hk_kdegrid* gr=dynamic_cast<hk_kdegrid*>(gridwidget);
+    p_definegridcolumnaction->setEnabled(mode()==hk_presentation::designmode&&gr);
 }
 
 void hk_kdeformpartwidget::slot_has_changed()
@@ -777,3 +816,56 @@ delete taborder;
 }
 
 
+void hk_kdeformpartwidget::show_widget(void)
+{
+  show();
+}
+
+void hk_kdeformpartwidget::hide_widget(void)
+{
+  hide();
+}
+
+void hk_kdeformpartwidget::close_widget(void)
+{
+  close();
+}
+
+
+void hk_kdeformpartwidget::withlabelbutton_clicked(void)
+{
+  p_form->set_create_with_label(!p_form->create_with_label());
+}
+
+void hk_kdeformpartwidget::show_gridcolumndialog()
+{
+QWidget* gridwidget=NULL;
+QWidget* object =p_form->formfocus()->widget();
+while (object!=NULL)
+{
+   if ( dynamic_cast <hk_kdegrid*>(object)!=NULL  )
+   {
+        gridwidget=object;
+        object=NULL;
+   }
+   else    object=object->parentWidget();
+}
+hk_kdegrid* gr=dynamic_cast<hk_kdegrid*>(gridwidget);
+if (gr)
+   gr->simplegrid()->show_gridcolumndialog();
+
+}
+
+
+
+void hk_kdeformpartwidget::set_caller_form(const hk_string&f)
+{
+ p_callerform=f;
+}
+
+hk_string hk_kdeformpartwidget::caller_form(void) const
+{
+    return p_callerform;
+}
+
+
