@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -31,7 +31,7 @@ class hk_kdesimplegrid;
 /**
  *
  *@short  shows data in a grid without columnheaders.
- *@version $Revision: 1.29 $
+ *@version $Revision: 1.31 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *This widget shows data of a datasource in a grid.
@@ -59,6 +59,11 @@ class hk_kdegrid :public QFrame, public hk_dsgrid
  */
         hk_kdesimplegrid* simplegrid(void){return p_grid;}
         hk_kdegridpart*   part(void){return p_part;}
+virtual void show_widget(void);
+virtual void hide_widget(void);
+virtual void close_widget(void);
+
+
     public slots:
 //	void datasource_enables(void);
 //	void datasource_disables(void);
@@ -80,6 +85,7 @@ class hk_kdegrid :public QFrame, public hk_dsgrid
         virtual void widget_specific_foregroundcolour_changed(const hk_colour&);
 	virtual void widget_specific_columns_created(void);
 	void widget_specific_rowheight_changes(void);
+	virtual bool	presentationmode_changed(void);
 
     private:
         hk_kdefinddialog* p_finddialog;
