@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-// $Revision: 1.34 $
+// $Revision: 1.36 $
 
 #include "hk_kdegridcolumndialog.h"
 
@@ -93,26 +93,26 @@ hk_kdegridcolumndialog::hk_kdegridcolumndialog( hk_kdegrid* parent,  const char*
     rightbox->setSelected(rightbox->currentItem(),true);
     rightbox_selectionchanged(   rightbox->selectedItem());
 
-    
+
     TabWidget->removePage(actiontab);
-    
+
     p_actionscrollview=new QScrollView(TabWidget);
     TabWidget->insertTab(p_actionscrollview,"");
     actiontab->reparent(p_actionscrollview->viewport(),QPoint(0,0));
     p_actionscrollview->addChild(actiontab);
     TabWidget->changeTab(p_actionscrollview,i18n("&Action"));
-    
+
     QSize s=actiontab->geometry().size();
     if (formattab->width()>s.width())s.setWidth(formattab->width());
     if (combotab->width()>s.width())s.setWidth(combotab->width());
-    
+
     if (formattab->height()>s.height())s.setHeight(formattab->height());
     if (combotab->height()>s.height())s.setHeight(combotab->height());
-    
+
     actiontab->setMinimumSize(s);
     /*tab_3->setMinimumSize(s);
     tab_4->setMinimumSize(s);*/
-    
+
 }
 
 
@@ -133,7 +133,7 @@ void hk_kdegridcolumndialog::addbutton_clicked()
     if (leftbox->currentText().isEmpty())return;
 
     fieldstruct f;
-    f.name=leftbox->currentText().local8Bit().data();
+    f.name=u2l(leftbox->currentText().utf8().data());
     fields.insert(fields.end(),f);
     rightbox->setSelected(rightbox->lastItem(),true);
     QListViewItem* feld=new QListViewItem(rightbox,rightbox->lastItem(),leftbox->currentText(),i18n("edit"));
@@ -215,7 +215,7 @@ void hk_kdegridcolumndialog::okbutton_clicked()
             gc->set_numberformat((*it).use_separators,(*it).digits);
             gc->set_displayname((*it).displayname);
             gc->set_readonly((*it).readonly);
-	    
+
 	    gc->set_on_click_action((*it).p_clickaction,true,true);
 	    gc->set_on_doubleclick_action((*it).p_doubleclickaction,true,true);
 	    gc->set_on_open_action((*it).p_onopenaction,true,true);
@@ -231,6 +231,7 @@ void hk_kdegridcolumndialog::okbutton_clicked()
 	    gc->set_on_getfocus_action((*it).p_on_getfocus_action,true,true);
 	    gc->set_on_loosefocus_action((*it).p_on_loosefocus_action,true,true);
 	    gc->set_on_key_action((*it).p_on_key_action,true,true);
+	    gc->set_on_select_action((*it).p_on_select_action,true,true);
 
             if ((*it).columntype==hk_dsgridcolumn::columncombo)
             {
@@ -261,6 +262,7 @@ void hk_kdegridcolumndialog::listentries_changed(void)
     storebutton->setEnabled(rightbox->childCount()>0);
     bool b=(columntypefield->currentItem()==2);
     combotab->setEnabled(b);
+    onselectactionbutton->setEnabled(b);
     listdatasourcetypefield->setEnabled((p_grid->presentationdatasource()==-1));
 set_buttontext();
 }
@@ -283,7 +285,7 @@ void hk_kdegridcolumndialog::set_columnvalues()
         fieldstruct f;
         hk_dsgridcolumn* gc=p_grid->gridcolumn(i);
         if (gc==NULL) def="";
-        else def=QString::fromLocal8Bit (gc->raw_defaultvalue().c_str());
+        else def=QString::fromUtf8 (l2u(gc->raw_defaultvalue()).c_str());
 
         switch (gc->columntype())
         {
@@ -322,20 +324,21 @@ void hk_kdegridcolumndialog::set_columnvalues()
 	f.p_on_getfocus_action=gc->on_getfocus_action();
 	f.p_on_loosefocus_action=gc->on_loosefocus_action();
 	f.p_on_key_action=gc->on_key_action();
-        
-	
-	
+	f.p_on_select_action=gc->on_select_action();
+
+
+
 	fields.insert(fields.end(),f);
 
-	
-	
-	
-	
-	
-	
+
+
+
+
+
+
 
         QListViewItem* feld=NULL;
-        feld=new QListViewItem(rightbox,rightbox->lastItem(),QString::fromLocal8Bit ((*it).c_str()),type);
+        feld=new QListViewItem(rightbox,rightbox->lastItem(),QString::fromUtf8 (l2u((*it)).c_str()),type);
 // rightbox->insertItem((*it).c_str());
         it++;i++;
     }
@@ -345,7 +348,7 @@ void hk_kdegridcolumndialog::set_columnvalues()
 
     while (it!=p_nonvisiblelist->end())
     {
-        leftbox->insertItem(QString::fromLocal8Bit ((*it).c_str()));
+        leftbox->insertItem(QString::fromUtf8 (l2u((*it)).c_str()));
         it++;
     }
 
@@ -358,7 +361,7 @@ void hk_kdegridcolumndialog::defaultvalue_changed()
 {
 
     if (p_currentfieldit!=fields.end())
-        (*p_currentfieldit).defaultvalue=defaultfield->text().local8Bit().data();
+        (*p_currentfieldit).defaultvalue=u2l(defaultfield->text().utf8().data());
 
 }
 
@@ -378,6 +381,7 @@ void hk_kdegridcolumndialog::columntype_changed()
     else cout <<"Warnung: p_currentfieldit==.end"<<endl;
 
     combotab->setEnabled(t==2);
+    onselectactionbutton->setEnabled(t==2);
 
     rightbox->currentItem()->setText(1,columntypefield->currentText());
     listentries_changed();
@@ -392,7 +396,7 @@ void hk_kdegridcolumndialog::rightbox_selectionchanged(QListViewItem* i)
 
     list<fieldstruct>::iterator it=fields.begin();
     bool found=false;
-    hk_string nn=i->text(0).local8Bit().data();
+    hk_string nn=u2l(i->text(0).utf8().data());
     while (it!=fields.end()&&!found)
     {
         if ((*it).name==nn)
@@ -404,11 +408,11 @@ void hk_kdegridcolumndialog::rightbox_selectionchanged(QListViewItem* i)
     }
     if (p_currentfieldit==fields.end()) return;
     defaultfield->blockSignals(true);
-    defaultfield->setText( QString::fromLocal8Bit ((*p_currentfieldit).defaultvalue.c_str()));
+    defaultfield->setText( QString::fromUtf8 (l2u((*p_currentfieldit).defaultvalue).c_str()));
     defaultfield->blockSignals(false);
 
     displayfield->blockSignals(true);
-    displayfield->setText( QString::fromLocal8Bit ((*p_currentfieldit).displayname.c_str()));
+    displayfield->setText( QString::fromUtf8 (l2u((*p_currentfieldit).displayname).c_str()));
     displayfield->blockSignals(false);
 
     readonlyfield->blockSignals(true);
@@ -465,11 +469,11 @@ void hk_kdegridcolumndialog::rightbox_selectionchanged(QListViewItem* i)
     set_currentlistdatasource();
 
     listcolumnfield->blockSignals(true);
-    listcolumnfield->setCurrentText(QString::fromLocal8Bit ((*p_currentfieldit).listcolumn.c_str()));
+    listcolumnfield->setCurrentText(QString::fromUtf8 (l2u((*p_currentfieldit).listcolumn).c_str()));
     listcolumnfield->blockSignals(false);
 
     viewcolumnfield->blockSignals(true);
-    viewcolumnfield->setCurrentText(QString::fromLocal8Bit ((*p_currentfieldit).viewcolumn.c_str()));
+    viewcolumnfield->setCurrentText(QString::fromUtf8 (l2u((*p_currentfieldit).viewcolumn).c_str()));
     viewcolumnfield->blockSignals(false);
 
     listentries_changed();
@@ -497,7 +501,7 @@ void hk_kdegridcolumndialog::alignment_changed()
 void hk_kdegridcolumndialog::displayname_changed()
 {
     if (p_currentfieldit!=fields.end())
-        (*p_currentfieldit).displayname=displayfield->text().local8Bit().data();
+        (*p_currentfieldit).displayname=u2l(displayfield->text().utf8().data());
 
 }
 
@@ -532,7 +536,7 @@ void hk_kdegridcolumndialog::listdatasource_changed()
     if (f.isEmpty()) f="";
     if (p_currentfieldit!=fields.end())
     {
-        (*p_currentfieldit).listdatasource=f.local8Bit().data();
+        (*p_currentfieldit).listdatasource=u2l(f.utf8().data());
 //cout <<"(*p_currentfieldit).listdatasource gesetzt " <<(*p_currentfieldit).listdatasource<<endl;
     }
     reload_listdatasource();
@@ -560,7 +564,7 @@ void hk_kdegridcolumndialog::reload_listdatasource(void)
         if (db==NULL) return;
         QString f=listdatasourcefield->text(listdatasourcefield->currentItem());
         if (f.isEmpty()) f="";
-        if (p_grid->presentation())p_grid->presentation()->get_datasource(f.local8Bit().data());
+        if (p_grid->presentation())p_grid->presentation()->get_datasource(u2l(f.utf8().data()));
         else
         {
 	    datasourcetype dt=dt_table;
@@ -570,7 +574,7 @@ void hk_kdegridcolumndialog::reload_listdatasource(void)
 	       case 2: dt =dt_view;break;
 	       default: dt=dt_table;
 	     }
-            ds=db->load_datasource(f.local8Bit().data(),dt);
+            ds=db->load_datasource(u2l(f.utf8().data()),dt);
         }
         if (ds==NULL) return;
     }
@@ -619,8 +623,8 @@ void hk_kdegridcolumndialog::reload_listdatasource(void)
     list<hk_column*>::iterator it=v->begin();
     while (it!=v->end())
     {
-        listcolumnfield->insertItem(QString::fromLocal8Bit ((*it)->name().c_str()));
-        viewcolumnfield->insertItem(QString::fromLocal8Bit ((*it)->name().c_str()));
+        listcolumnfield->insertItem(QString::fromUtf8 (l2u((*it)->name()).c_str()));
+        viewcolumnfield->insertItem(QString::fromUtf8 (l2u((*it)->name()).c_str()));
         it++;
     }
     listcolumnfield->blockSignals(false);
@@ -665,7 +669,7 @@ void hk_kdegridcolumndialog::listdatasourcetype_changed()
     int p=0;
     while (it!=v->end())
     {
-        listdatasourcefield->insertItem(QString::fromLocal8Bit ((*it).c_str()));
+        listdatasourcefield->insertItem(QString::fromUtf8 (l2u((*it)).c_str()));
     if (p_currentfieldit!=fields.end())
         if ((*p_currentfieldit).listdatasource==(*it))listdatasourcefield->setCurrentItem(p);
         it++;++p;
@@ -687,7 +691,7 @@ void hk_kdegridcolumndialog::set_currentlistdatasource(void)
     {
         if (p_currentfieldit!=fields.end())
         {
-            if ( listdatasourcefield->text(counter)== QString::fromLocal8Bit ((*p_currentfieldit).listdatasource.c_str()))
+            if ( listdatasourcefield->text(counter)== QString::fromUtf8 (l2u((*p_currentfieldit).listdatasource).c_str()))
                 current=counter;
         }                                         //else cout <<"p_currentfieldit!=fields.end()"<<endl;
         counter++;
@@ -703,7 +707,7 @@ void hk_kdegridcolumndialog::viewcolumn_changed()
 {
     if (p_currentfieldit!=fields.end())
     {
-        (*p_currentfieldit).viewcolumn=viewcolumnfield->currentText().local8Bit().data();
+        (*p_currentfieldit).viewcolumn=u2l(viewcolumnfield->currentText().utf8().data());
 //cout <<"viewcolumn_changed auf  "<<(*p_currentfieldit).viewcolumn<<endl;
     }
 }
@@ -713,7 +717,7 @@ void hk_kdegridcolumndialog::listcolumn_changed()
 {
     if (p_currentfieldit!=fields.end())
     {
-        (*p_currentfieldit).listcolumn=listcolumnfield->currentText().local8Bit().data();
+        (*p_currentfieldit).listcolumn=u2l(listcolumnfield->currentText().utf8().data());
 //cout <<"listcolumn_changed auf  "<<(*p_currentfieldit).listcolumn<<endl;
     }
 }
@@ -733,7 +737,7 @@ void hk_kdegridcolumndialog::load_presentationdatasources(void)
     list<hk_datasource*>::iterator it=dslist->begin();
     while (it!=dslist->end())
     {
-        QString name= QString::fromLocal8Bit (p_grid->presentation()->unique_datasourcename((*it)->presentationnumber()).c_str());
+        QString name= QString::fromUtf8 (l2u(p_grid->presentation()->unique_datasourcename((*it)->presentationnumber())).c_str());
         listdatasourcefield->insertItem(name);
         it++;
     }
@@ -745,10 +749,10 @@ void hk_kdegridcolumndialog::load_presentationdatasources(void)
 void hk_kdegridcolumndialog::onclickaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_clickaction,false);
     d->set_caption(NULL,"on_click_action");
@@ -767,10 +771,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::ondoubleclickaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_doubleclickaction,false);
     d->set_caption(NULL,"ondoubleclick_action");
@@ -789,10 +793,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::onopenaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_onopenaction,false);
     d->set_caption(NULL,"on_open_action");
@@ -811,10 +815,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::oncloseaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_oncloseaction,false);
     d->set_caption(NULL,"on_close_action");
@@ -833,10 +837,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::beforeupdateaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_before_update_action,false);
     d->set_caption(NULL,"before_update_action");
@@ -854,10 +858,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::afterupdateaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_after_update_action,false);
     d->set_caption(NULL,"after_update_action");
@@ -876,10 +880,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::beforerowchangeaction_changed()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_before_row_change_action,false);
     d->set_caption(NULL,"before_row_change_action");
@@ -898,10 +902,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::afterrowchangeaction_changed()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_after_row_change_action,false);
     d->set_caption(NULL,"before_after_row_change_action");
@@ -920,10 +924,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::beforedeleteaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_before_delete_action,false);
     d->set_caption(NULL,"before_delete_action");
@@ -942,10 +946,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::afterdeleteaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_after_delete_action,false);
     d->set_caption(NULL,"after_delete_action");
@@ -964,10 +968,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::beforeinsertaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_before_insert_action,false);
     d->set_caption(NULL,"before_insert_action");
@@ -986,10 +990,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::afterinsertaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_after_insert_action,false);
     d->set_caption(NULL,"after_insert_action");
@@ -1014,10 +1018,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::on_getfocusaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_on_getfocus_action,false);
     d->set_caption(NULL,"on_getfocus_action");
@@ -1036,10 +1040,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::on_loosefocusaction_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_on_loosefocus_action,false);
     d->set_caption(NULL,"on_loosefocus_action");
@@ -1058,10 +1062,10 @@ set_buttontext();
 void hk_kdegridcolumndialog::onkeybutton_clicked()
 {
     if (p_currentfieldit==fields.end()) return;
-    
-    hk_string warning; 
+
+    hk_string warning;
     int rownumber=0;
-    
+
     hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
     d->set_code((*p_currentfieldit).p_on_key_action,false);
     d->set_caption(NULL,"on_key_action");
@@ -1078,6 +1082,29 @@ set_buttontext();
 }
 
 
+void hk_kdegridcolumndialog::onselectaction_clicked()
+{
+    if (p_currentfieldit==fields.end()) return;
+
+    hk_string warning;
+    int rownumber=0;
+
+    hk_kdeinterpreterdialog* d = new hk_kdeinterpreterdialog(0,0,Qt::WShowModal);
+    d->set_code((*p_currentfieldit).p_on_select_action,false);
+    d->set_caption(NULL,"on_select_action");
+    int r=d->exec(rownumber,warning);
+    if (r==hk_kdeinterpreterdialog::Accepted&&d->has_changed())
+    {
+      (*p_currentfieldit).p_on_select_action=d->code();
+    }
+
+    delete d;
+set_buttontext();
+
+
+}
+
+
 
 
 
@@ -1099,8 +1126,9 @@ void hk_kdegridcolumndialog::set_buttontext(void)
     afterdeleteactionbutton->setText((*p_currentfieldit).p_after_delete_action.size()>0?settxt:notsettxt);
     beforeinsertactionbutton->setText((*p_currentfieldit).p_before_insert_action.size()>0?settxt:notsettxt);
     afterinsertactionbutton->setText((*p_currentfieldit).p_after_insert_action.size()>0?settxt:notsettxt);
+    onselectactionbutton->setText((*p_currentfieldit).p_on_select_action.size()>0?settxt:notsettxt);
 
     ongetfocusbutton->setText((*p_currentfieldit).p_on_getfocus_action.size()>0?settxt:notsettxt);
     onloosefocusbutton->setText((*p_currentfieldit).p_on_loosefocus_action.size()>0?settxt:notsettxt);
     onkeybutton->setText((*p_currentfieldit).p_on_key_action.size()>0?settxt:notsettxt);
-}    
+}
