@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -22,7 +22,7 @@ class hk_kdegrid;
 /**
  *
  *@internal
- *@version $Revision: 1.17 $
+ *@version $Revision: 1.18 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *
@@ -55,8 +55,8 @@ class hk_kdegridcolumndialog : public hk_kdegridcolumndialogbase
         void separator_changed();
         void viewcolumn_changed();
 
-	
-	
+
+
     virtual void onclickaction_clicked();
     virtual void ondoubleclickaction_clicked();
     virtual void onopenaction_clicked();
@@ -72,16 +72,17 @@ class hk_kdegridcolumndialog : public hk_kdegridcolumndialogbase
     virtual void on_getfocusaction_clicked();
     virtual void on_loosefocusaction_clicked();
     virtual void onkeybutton_clicked();
-	
-	
-	
-	
-	
-	
-	
-	
-	
-	
+    virtual void onselectaction_clicked();
+
+
+
+
+
+
+
+
+
+
     private:
         typedef  class  fieldstruct
         {
@@ -113,7 +114,7 @@ class hk_kdegridcolumndialog : public hk_kdegridcolumndialogbase
 		hk_string p_after_update_action,p_before_update_action;
 	        hk_string p_after_insert_action,p_before_insert_action;
 		hk_string p_clickaction,p_doubleclickaction, p_onopenaction,p_oncloseaction;
-		hk_string p_on_getfocus_action,p_on_loosefocus_action,p_on_key_action;
+		hk_string p_on_getfocus_action,p_on_loosefocus_action,p_on_key_action,p_on_select_action;
         };
 	void set_buttontext(void);
         list<fieldstruct> fields;
