@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.16 $
+//$Revision: 1.18 $
 
 #include "hk_kdeinterpreterdialog.h"
 #include <qbuttongroup.h>
@@ -81,7 +81,7 @@ rescode=Accepted;
     //p_private->p_selectallaction=new KAction( i18n("Select &All"), 0,0, this, SLOT( select_all() ) ,actionCollection(),"selectall");
     p_private->p_undoaction=new KAction(i18n("&Undo"),"undo",CTRL+Key_Z,this,SLOT(undo()),actionCollection(),"undo");
     p_private->p_undoaction->setEnabled(false);
-        
+
     p_private->p_toggleinsertaction= new KAction(i18n("Toggle &Insert"),Key_Insert,this,SLOT(toggle_insert()),actionCollection(),"toggleinsert");
     KStdAction::replace(p_designkate,SLOT(replace()),actionCollection());
     KStdAction::find(p_designkate,SLOT(find()),actionCollection());
@@ -197,6 +197,11 @@ void    hk_kdeinterpreterdialog::keyPressEvent ( QKeyEvent * e )
 
                 break;
             }
+	    case Key_F1 :
+	    {
+		help_clicked();
+		break;
+            }
 	    /*case Key_Z :
 	    {
 		p_katepart->undo();
@@ -219,7 +224,7 @@ void hk_kdeinterpreterdialog::done( int r )
 KConfig* c=kapp->config();
   c->setGroup("Interpreter");
   c->writeEntry("Geometry",geometry());
-  
+
 cerr <<"done close Interpreter"<<endl;
     hide();
     setResult( r );
@@ -298,7 +303,7 @@ void hk_kdeinterpreterdialog::reject()
 
 hk_string hk_kdeinterpreterdialog::code(void)
 {
-return p_designkate->getDoc()->text().local8Bit().data();
+return u2l(p_designkate->getDoc()->text().utf8().data());
 
 }
 void hk_kdeinterpreterdialog::set_code(const hk_string& c,bool registerchange)
@@ -348,13 +353,13 @@ void hk_kdeinterpreterdialog::set_caption(hk_visible* v,const hk_string& action)
 QString txt;
 if (v)
    {
-     txt=QString::fromLocal8Bit(v->identifier().c_str());
+     txt=QString::fromUtf8(l2u(v->identifier()).c_str());
      QString n;n.setNum(v->presentationnumber());
      txt+=" ("+n+")";
      txt+=" - ";
    }
 
-   txt+=QString::fromLocal8Bit(action.c_str());
+   txt+=QString::fromUtf8(l2u(action).c_str());
    setCaption(txt);
 }
 
@@ -368,3 +373,14 @@ void hk_kdeinterpreterdialog::slot_undo_changed(void)
 {
   p_private->p_undoaction->setEnabled(p_designkate->getDoc()->undoCount()>0);
 }
+
+
+
+
+
+void hk_kdeinterpreterdialog::help_clicked()
+{
+kapp->invokeHelp("pschapter1");
+}
+
+
