@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.28 $
+//$Revision: 1.31 $
 #include "hk_kdelabel.h"
 #include "hk_kdesimpleform.h"
 #include <qapplication.h>
@@ -42,7 +42,7 @@ void    hk_kdelabel::widget_specific_label_changed(void)
     hkdebug("hk_kdelabel::widget_specific_label_changed");
 #endif
     if (label().size()>0)
-     setText(QString::fromLocal8Bit (label().c_str()));
+     setText(QString::fromUtf8 (l2u(label()).c_str()));
     else
     {
       if ((topline()+bottomline()+leftline()+rightline()+diagonalloru()+diagonalluro())==0)
@@ -121,7 +121,7 @@ void hk_kdelabel::reposition(void)
 
 void hk_kdelabel::widget_specific_font_changed(void)
 {
-    setFont(QFont(QString::fromLocal8Bit (hk_label::font().fontname().c_str())
+    setFont(QFont(QString::fromUtf8 (l2u(hk_label::font().fontname()).c_str())
                   ,hk_label::font().fontsize(),hk_label::font().bold()?QFont::Bold:QFont::Normal,
 		   hk_label::font().italic()));
 }
@@ -246,9 +246,35 @@ repaint();
 
 void  hk_kdelabel::widget_specific_tooltip_changed(void)
 {
- QToolTip::add(this,QString::fromLocal8Bit (tooltip().c_str()));
+ QToolTip::add(this,QString::fromUtf8 (l2u(tooltip()).c_str()));
 }
 
 
+void hk_kdelabel::show_widget(void)
+{
+  show();
+}
+
+void hk_kdelabel::hide_widget(void)
+{
+  hide();
+}
+
+void hk_kdelabel::close_widget(void)
+{
+  close();
+}
+
+bool hk_kdelabel::presentationmode_changed()
+{
+if (!p_presentation)
+  {
+    setEnabled(is_enabled());
+    return hk_label::presentationmode_changed();
+  }
+bool result=hk_label::presentationmode_changed();
+   setEnabled(is_enabled());
+  return  result;
+}
 
 
