@@ -1,6 +1,6 @@
 
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -9,7 +9,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.64 $
+//$Revision: 1.70 $
 #include "hk_kdelineedit.h"
 #include "hk_kdelineedit.moc"
 #include <qkeycode.h>
@@ -63,7 +63,7 @@ hk_kdelineedit::~hk_kdelineedit()
 void hk_kdelineedit::keyPressEvent( QKeyEvent * e )
 {
    //p_while_keyaction=true;
-    hk_key nk=hk_key(e->key(),e->state(),(e->text().isNull()?"":e->text().local8Bit().data()));
+    hk_key nk=hk_key(e->key(),e->state(),(e->text().isNull()?"":u2l(e->text().utf8().data())));
     hk_key* k=NULL;
     if (p_gridcolumn)
       {
@@ -73,7 +73,7 @@ void hk_kdelineedit::keyPressEvent( QKeyEvent * e )
       }
       else
       {
-      
+
        set_key(nk);
        action_on_key();
        k=key();
@@ -83,10 +83,10 @@ void hk_kdelineedit::keyPressEvent( QKeyEvent * e )
       e->ignore();
       //p_while_keyaction=false;
       return;
-    
+
     }
-    
-    
+
+
     if (e->key()==Key_Return)
     {
         if (e->state()&ControlButton)
@@ -101,13 +101,13 @@ void hk_kdelineedit::keyPressEvent( QKeyEvent * e )
        {
          if (column() && column()->has_changed()) column()->reset_changed_data();
 	 else
-	 if (datasource() && datasource()->has_changed()) 
+	 if (datasource() && datasource()->has_changed())
 	 {
 	    datasource()->reset_changed_data();
 	    datasource()->store_changed_data();
-	 }   
+	 }
 	 widget_specific_row_change();
-	   
+
        }
        else
 
@@ -129,19 +129,19 @@ void hk_kdelineedit::keyPressEvent( QKeyEvent * e )
                         break;
                     }
 
-                    default: 
+                    default:
 		    //p_while_keyaction=false;
 		    return;
                 }
             }
 	    else
-	      if (e->key()==Key_0 &&e->state()&ControlButton) 
+	      if (e->key()==Key_0 &&e->state()&ControlButton)
 	       NULLselected( 0 );
-	    
+
         }
         QLineEdit::keyPressEvent(e);
     }
-//p_while_keyaction=false;    
+//p_while_keyaction=false;
 }
 
 
@@ -161,9 +161,10 @@ void hk_kdelineedit::slot_data_changed(void)
             hkdebug("kdelineedit::data will be updated");
 #endif
             if (is_numerictype(column()))
-                column()->set_asstring(format_number(text().local8Bit().data(),true,use_numberseparator(),commadigits(),locale()),true,true);
-            else column()->set_asstring(text().local8Bit().data(),true,true);
+                column()->set_asstring(format_number(u2l(text().utf8().data()),true,use_numberseparator(),commadigits(),locale()),true,true);
+            else column()->set_asstring(u2l(text().utf8().data()),true,true);
         }
+      action_on_valuechanged();
     }
 }
 
@@ -190,7 +191,7 @@ bool hk_kdelineedit::widget_specific_row_change(void)
     if (datasource()!=NULL)
         if (c!=NULL)
     {
-        hk_string v=datasource()->mode()==hk_datasource::mode_insertrow?
+        hk_string v=datasource()->mode()==hk_datasource::mode_insertrow &&!c->has_changed()?
             use_defaultvalue()?defaultvalue():"":
         (c->has_changed()?c->changed_data_asstring():c->asstring(true));
         if (is_numerictype(c)&&c->columntype()!=hk_column::auto_inccolumn&&v.length()>0
@@ -200,7 +201,7 @@ bool hk_kdelineedit::widget_specific_row_change(void)
             v=format_number(v,true,use_numberseparator(),commadigits(),locale());
         }
 
-        setText(QString::fromLocal8Bit (v.c_str()));
+        setText(QString::fromUtf8 (l2u(v).c_str()));
         if (hk_dsdatavisible::alignment()==hk_dsdatavisible::alignleft)
             setCursorPosition(0);
     }
@@ -226,19 +227,19 @@ void hk_kdelineedit::widget_specific_enable_disable()
             if (column() && column()->columntype()==hk_column::textcolumn) setMaxLength(column()->size());
             else setMaxLength(32767);
 
-            setEnabled(true);
+            setEnabled(is_enabled());
             widget_specific_row_change();
         }
         else setEnabled(false);
     }
     else
     {
-        if (p_presentation ) setEnabled(p_presentation->mode()==hk_presentation::viewmode);
+        if (p_presentation ) setEnabled(p_presentation->mode()==hk_presentation::viewmode &&is_enabled());
 	else
-	setEnabled(true);
-	
+	setEnabled(is_enabled());
+
         blockSignals(true);
-        setText(QString::fromLocal8Bit (use_defaultvalue()?defaultvalue().c_str():""));
+        setText(QString::fromUtf8 (use_defaultvalue()?l2u(defaultvalue()).c_str():""));
         blockSignals(false);
     }
 
@@ -276,7 +277,7 @@ void    hk_kdelineedit::widget_specific_insert_mode(void)
 {
 //  widget_specific_row_change();
     blockSignals(true);
-    setText(QString::fromLocal8Bit (use_defaultvalue()?defaultvalue().c_str():""));
+    setText(QString::fromUtf8 (use_defaultvalue()?l2u(defaultvalue()).c_str():""));
     blockSignals(false);
 }
 
@@ -339,7 +340,7 @@ void hk_kdelineedit::reposition(void)
 
 void hk_kdelineedit::widget_specific_font_changed(void)
 {
-    setFont(QFont(QString::fromLocal8Bit (hk_dslineedit::font().fontname().c_str())
+    setFont(QFont(QString::fromUtf8 (l2u(hk_dslineedit::font().fontname()).c_str())
                   ,hk_dslineedit::font().fontsize(),hk_dslineedit::font().bold()?QFont::Bold:QFont::Normal,
 		   hk_dslineedit::font().italic()));
 }
@@ -465,7 +466,7 @@ void    hk_kdelineedit::find_next(void)
 
             unsigned int r=c->find( from,
                 to,
-                p_finddialog->searchfield->currentText().local8Bit().data(),
+                u2l(p_finddialog->searchfield->currentText().utf8().data()),
                 !p_finddialog->part_of_columnbox->isChecked(),
                 p_finddialog->case_sensitivebox->isChecked(),
                 p_finddialog->find_backwardsbox->isChecked()
@@ -525,25 +526,26 @@ void    hk_kdelineedit::widget_specific_foregroundcolour_changed(const hk_colour
 void hk_kdelineedit::set_value(const hk_string&v)
 {
  hk_column* c=column();
- if (c)c->set_asstring(v);
- else setText(QString::fromLocal8Bit (v.c_str()));
+ if (c)hk_dslineedit::set_value(v);
+ else setText(QString::fromUtf8 (l2u(v).c_str()));
 
 }
 
 hk_string hk_kdelineedit::value(void)
 {
-  if (!column()) return text().local8Bit().data();
+  if (!column()) return u2l(text().utf8().data());
   else return hk_dslineedit::value();
 }
 
 
-void	hk_kdelineedit::presentationmode_changed(void)
+bool	hk_kdelineedit::presentationmode_changed(void)
 {
-if (!p_presentation) 
+if (!p_presentation)
   {
-    hk_dslineedit::presentationmode_changed();
-    return;
-  }  
+    return hk_dslineedit::presentationmode_changed();
+  }
+
+bool result=hk_dslineedit::presentationmode_changed();
 if (p_presentation->mode()==hk_presentation::designmode)
    {
     setEnabled(false);
@@ -553,25 +555,30 @@ if (p_presentation->mode()==hk_presentation::designmode)
    }
  else
  {
-   setEnabled(true);
+   setEnabled(is_enabled());
    if (!datasource()||!column())
     {
         blockSignals(true);
-        setText(QString::fromLocal8Bit (use_defaultvalue()?defaultvalue().c_str():""));
+        setText(QString::fromUtf8 (use_defaultvalue()?l2u(defaultvalue()).c_str():""));
         blockSignals(false);
-    
+
     }
  }
-hk_dslineedit::presentationmode_changed();
+return result;
 
 }
 
 
+void hk_kdelineedit::widget_specific_enabled_changed(void)
+{
+  setEnabled(is_enabled());
+}
+
 
 
 void  hk_kdelineedit::widget_specific_tooltip_changed(void)
 {
- QToolTip::add(this,QString::fromLocal8Bit (tooltip().c_str()));
+ QToolTip::add(this,QString::fromUtf8 (l2u(tooltip()).c_str()));
 }
 
 
@@ -593,6 +600,24 @@ void hk_kdelineedit::focusOutEvent ( QFocusEvent * e)
 void hk_kdelineedit::closeEvent ( QCloseEvent * e )
 {
   //if (p_while_keyaction) e->ignore();
-  //else 
+  //else
   KLineEdit::closeEvent(e);
 }
+
+void hk_kdelineedit::show_widget(void)
+{
+  show();
+}
+
+void hk_kdelineedit::hide_widget(void)
+{
+  hide();
+}
+
+void hk_kdelineedit::close_widget(void)
+{
+  close();
+}
+
+
+
