@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -23,7 +23,7 @@ class hk_dsgridcolumn;
 /**
  *
  *@short KDE Widget to edit/display data in a field.
- *@version $Revision: 1.23 $
+ *@version $Revision: 1.26 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *Just set the datasource and the column (defined in the parent class @ref hk_dsdatavisible).
@@ -37,6 +37,9 @@ class  hk_kdelineedit : public KLineEdit , public hk_dslineedit
         virtual ~hk_kdelineedit();
 	virtual void set_value(const hk_string&);
 	virtual hk_string value(void);
+virtual void show_widget(void);
+virtual void hide_widget(void);
+virtual void close_widget(void);
 
     protected:
      virtual void focusInEvent ( QFocusEvent * );
@@ -61,7 +64,8 @@ class  hk_kdelineedit : public KLineEdit , public hk_dslineedit
         virtual QPopupMenu* createPopupMenu(void);
         virtual void widget_specific_backgroundcolour_changed(const hk_colour&);
         virtual void widget_specific_foregroundcolour_changed(const hk_colour&);
-	virtual void	presentationmode_changed(void);
+	virtual void widget_specific_enabled_changed(void);
+	virtual bool	presentationmode_changed(void);
 
     public slots:
         void    find_clicked(int);
@@ -82,6 +86,6 @@ class  hk_kdelineedit : public KLineEdit , public hk_dslineedit
         int     NULLpopupid;
         int     findpopupid;
 	//bool p_while_keyaction;
-	
+
 };
 #endif
