@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.50 $
+//$Revision: 1.56 $
 #include <hk_datasource.h>
 #include <qbrush.h>
 #include <hk_kdememo.h>
@@ -70,8 +70,10 @@ void hk_kdememo::slot_data_changed(void)
     if (!p_widget_specific_row_change)
     {
         has_changed=true;
+        set_data_has_changed(); // from hk_dsdatavisible
 /*	        if (column()!=NULL)
-                   column()->set_asstring(text().local8Bit().data(),true,true);*/
+                   column()->set_asstring(text().utf8().data(),true,true);*/
+    action_on_valuechanged();
 
     }
 }
@@ -101,7 +103,7 @@ bool hk_kdememo::widget_specific_row_change(void)
 #ifdef HK_DEBUG
         hkdebug("hk_kdememo::widget_specific_row_change default");
 #endif
-        setText(QString::fromLocal8Bit (c->has_changed()?c->changed_data_asstring().c_str():c->asstring(true).c_str()));
+        setText(QString::fromUtf8 (c->has_changed()?l2u(c->changed_data_asstring()).c_str():l2u(c->asstring(true)).c_str()));
     }
 
     p_widget_specific_row_change=false;
@@ -124,7 +126,7 @@ void hk_kdememo::widget_specific_enable_disable()
         p_widget_specific_row_change=true;
         if (datasource()->is_enabled()>0)
         {
-            setEnabled(true);
+            setEnabled(is_enabled());
             widget_specific_row_change();
         }
         else setEnabled(false);
@@ -132,9 +134,9 @@ void hk_kdememo::widget_specific_enable_disable()
     }
     else
     {
-        if (p_presentation ) setEnabled(p_presentation->mode()==hk_presentation::viewmode);
+        if (p_presentation ) setEnabled(p_presentation->mode()==hk_presentation::viewmode&&is_enabled());
 	else
-	setEnabled(true);
+	setEnabled(is_enabled());
 	if (datasource()&&!datasource()->is_enabled()) setEnabled(false);
         blockSignals(true);
         setText("");
@@ -204,7 +206,7 @@ void hk_kdememo::before_store_changed_data()
     {
         if (column()!=NULL)
         {
-            column()->set_asstring(text().local8Bit().data(),true,true);
+            column()->set_asstring(u2l(text().utf8().data()),true,true);
             has_changed=false;
         }
     }
@@ -250,7 +252,7 @@ void hk_kdememo::reposition(void)
 
 void hk_kdememo::widget_specific_font_changed(void)
 {
-    setFont(QFont(QString::fromLocal8Bit (hk_dsmemo::font().fontname().c_str())
+    setFont(QFont(QString::fromUtf8 (l2u(hk_dsmemo::font().fontname()).c_str())
                   ,hk_dsmemo::font().fontsize(),hk_dsmemo::font().bold()?QFont::Bold:QFont::Normal,
 		   hk_dsmemo::font().italic()));
 }
@@ -259,7 +261,7 @@ void hk_kdememo::widget_specific_font_changed(void)
 void    hk_kdememo::widget_specific_insert_mode(void)
 {
     blockSignals(true);
-    setText(QString::fromLocal8Bit (use_defaultvalue()?defaultvalue().c_str():""));
+    setText(QString::fromUtf8(use_defaultvalue()?l2u(defaultvalue()).c_str():""));
     blockSignals(false);
 }
 
@@ -267,7 +269,7 @@ void    hk_kdememo::widget_specific_insert_mode(void)
 void hk_kdememo::keyPressEvent( QKeyEvent * e )
 {
    //p_while_keyaction=true;
-    hk_key nk=hk_key(e->key(),e->state(),(e->text().isNull()?"":e->text().local8Bit().data()));
+    hk_key nk=hk_key(e->key(),e->state(),(e->text().isNull()?"":u2l(e->text().utf8().data())));
     hk_key* k=NULL;
     if (p_gridcolumn)
       {
@@ -277,7 +279,7 @@ void hk_kdememo::keyPressEvent( QKeyEvent * e )
       }
       else
       {
-      
+
        set_key(nk);
        action_on_key();
        k=key();
@@ -287,18 +289,18 @@ void hk_kdememo::keyPressEvent( QKeyEvent * e )
       e->ignore();
       //p_while_keyaction=false;
       return;
-    
+
     }
-    
-    
-    
+
+
+
 
     if (column()==NULL)
     {
          QTextEdit::keyPressEvent(e);
          return;
-    } 
-    
+    }
+
     if (e->key()==Key_F && e->state()&ControlButton) find_clicked(findpopupid);
             else
         if (column()->is_readonly()||is_readonly())
@@ -313,18 +315,18 @@ void hk_kdememo::keyPressEvent( QKeyEvent * e )
             default: return;
           }
         }
-    
+
     if (e->key()==Key_Escape)
        {
          if (column() && column()->has_changed()) column()->reset_changed_data();
 	 else
-	 if (datasource() && datasource()->has_changed()) 
+	 if (datasource() && datasource()->has_changed())
 	 {
 	    datasource()->reset_changed_data();
 	    datasource()->store_changed_data();
-	 }   
+	 }
 	 widget_specific_row_change();
-	   
+
        }
     else  QTextEdit::keyPressEvent(e);
 }
@@ -471,7 +473,7 @@ void    hk_kdememo::find_next(void)
 
             unsigned int r=c->find( from,
                 to,
-                p_finddialog->searchfield->currentText().local8Bit().data(),
+                u2l(p_finddialog->searchfield->currentText().utf8().data()),
                 !p_finddialog->part_of_columnbox->isChecked(),
                 p_finddialog->case_sensitivebox->isChecked(),
                 p_finddialog->find_backwardsbox->isChecked()
@@ -527,22 +529,23 @@ void    hk_kdememo::NULLselected( int r )
 void hk_kdememo::set_value(const hk_string&v)
 {
  hk_column* c=column();
- if (c)c->set_asstring(v);
- else setText(QString::fromLocal8Bit (v.c_str()));
+ hk_dsmemo::set_value(v);
+ if (!c) setText(QString::fromUtf8 (l2u(v).c_str()));
 
 }
 
 hk_string hk_kdememo::value(void)
 {
-  if (!column()) return text().local8Bit().data();
+  if (!column()) return u2l(text().utf8().data());
   else return hk_dsmemo::value();
 }
 
 
-void	hk_kdememo::presentationmode_changed(void)
+bool	hk_kdememo::presentationmode_changed(void)
 {
-hk_dsmemo::presentationmode_changed();
-if (!p_presentation) return;
+bool result=hk_dsmemo::presentationmode_changed();
+if (!result)return false;
+if (!p_presentation) return true;
 if (p_presentation->mode()==hk_presentation::designmode)
    {
     setEnabled(false);
@@ -552,14 +555,14 @@ if (p_presentation->mode()==hk_presentation::designmode)
    }
  else
  {
-   setEnabled(true);
+   setEnabled(is_enabled());
  }
-
+return true;
 }
 
 void  hk_kdememo::widget_specific_tooltip_changed(void)
 {
- QToolTip::add(this,QString::fromLocal8Bit (tooltip().c_str()));
+ QToolTip::add(this,QString::fromUtf8 ((tooltip()).c_str()));
 }
 
 
@@ -579,3 +582,22 @@ void hk_kdememo::focusOutEvent ( QFocusEvent * e)
 }
 
 
+void hk_kdememo::show_widget(void)
+{
+  show();
+}
+
+void hk_kdememo::hide_widget(void)
+{
+  hide();
+}
+
+void hk_kdememo::close_widget(void)
+{
+  close();
+}
+
+void hk_kdememo::widget_specific_enabled_changed(void)
+{
+  setEnabled(is_enabled());
+}
