@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -18,7 +18,7 @@ class hk_kdefinddialog;
 /**
  *
  *@short KDE Widget to edit/display long data like text in a field.
- *@version $Revision: 1.19 $
+ *@version $Revision: 1.22 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *Just set the datasource and the column (defined in the parent class @ref hk_dsdatavisible).
@@ -33,10 +33,13 @@ class hk_kdememo: public QTextEdit,public hk_dsmemo
         ~hk_kdememo();
 	virtual void set_value(const hk_string&);
 	virtual hk_string value(void);
+virtual void show_widget(void);
+virtual void hide_widget(void);
+virtual void close_widget(void);
 
     protected:
      virtual void focusInEvent ( QFocusEvent * );
-     virtual void focusOutEvent ( QFocusEvent * ); 
+     virtual void focusOutEvent ( QFocusEvent * );
      virtual void    widget_specific_tooltip_changed(void);
         virtual bool    widget_specific_coordinates(uint px,uint py,uint pwidth,uint pheight);
         virtual bool    widget_specific_row_change(void);
@@ -44,7 +47,8 @@ class hk_kdememo: public QTextEdit,public hk_dsmemo
         virtual void    widget_specific_row_deleted(void);
         virtual void    widget_specific_row_added(void);
         virtual void    widget_specific_alignment(void);
-	virtual void	presentationmode_changed(void);
+	virtual void widget_specific_enabled_changed(void);
+	virtual bool	presentationmode_changed(void);
         bool    datasource_disable(void);
         bool    datasource_enable(void);
         void    datasource_delete(void);
