@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_classes library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -11,6 +11,8 @@
 #include "hk_kdeqbe.h"
 #include "hk_kdedbdesigner.h"
 #include <hk_column.h>
+#include<hk_database.h>
+#include<hk_connection.h>
 #include <qtable.h>
 #include <qsplitter.h>
 #include <qstringlist.h>
@@ -21,7 +23,7 @@
 
 class internalgrid:public QTable
 {
-public: 
+public:
 internalgrid(QWidget* parent,hk_kdeqbe* qbe, const char* name=0):QTable(parent,name)
    {
      p_qbe=qbe;
@@ -29,15 +31,15 @@ internalgrid(QWidget* parent,hk_kdeqbe* qbe, const char* name=0):QTable(parent,n
      installEventFilter(this);
    }
 hk_kdeqbe* p_qbe;
-   
+
 protected:
 bool delete_rows(void)
-	{ 
+	{
 	  QMemArray<int> myarray(0);
 	  int i=0; int col=0;
 	  int leftcol=999;
 	  while (i<numSelections())
-	  { 
+	  {
 	  QTableSelection s=selection(i);
 	  if (isColumnSelected(s.leftCol(),true))
 	  {
@@ -48,18 +50,18 @@ bool delete_rows(void)
 	      myarray[col]=c;
 	      ++col;
 	     }
-	  }    
+	  }
 	  ++i;
 	  }
 	  myarray.sort();
 	  if (myarray.size()==0) return false;
 	  removeColumns(myarray);
-         setCurrentCell(currentRow(),leftcol);  
+         setCurrentCell(currentRow(),leftcol);
  	 p_qbe->slot_has_changed();
 	 return true;
 	}
-	
-	
+
+
 bool   eventFilter( QObject *o, QEvent *e )
 	{
 	  if (e->type()==QEvent::KeyPress)
@@ -67,7 +69,7 @@ bool   eventFilter( QObject *o, QEvent *e )
             QKeyEvent *ke = (QKeyEvent*)e;
             if (ke->key() == Key_Delete&& o->isWidgetType())
 	    {
-	      
+
 	       QWidget* w=(QWidget*)o;
 	       while (w)
 	       {
@@ -77,12 +79,12 @@ bool   eventFilter( QObject *o, QEvent *e )
 		}
 		w=w->parentWidget();
 	       }
-	    }	
+	    }
 	  }
-	
+
         return QTable::eventFilter(o,e);
        };
-       
+
 
 
 
@@ -93,7 +95,7 @@ virtual void contentsDragEnterEvent(QDragEnterEvent* event)
 
 virtual void contentsDropEvent(QDropEvent* event)
 {
-  
+
    if (! event->encodedData("application/x-hk_kdedbdesigner"))
     {
       cerr <<"internalgrid event->encodedData==0 !!!"<<endl;
@@ -109,7 +111,7 @@ virtual void contentsDropEvent(QDropEvent* event)
             cerr <<eventtxt<<endl;
 	    return;
 	 }
-    
+
     int dcol=columnAt(event->pos().x());
     p_qbe->add_column(dcol,vupn,columnname);
     event->acceptAction(true);
@@ -117,7 +119,7 @@ virtual void contentsDropEvent(QDropEvent* event)
 } // end drop Event
 
 
-}; //  internalgrid END 
+}; //  internalgrid END
 
 
 class internalcombo: public QComboTableItem
@@ -128,7 +130,7 @@ internalcombo(internalgrid *table, const QStringList &list, bool editable = FALS
    {
    p_grid=table;
    }
-   
+
 void setContentFromEditor( QWidget *w )
 {
 
@@ -140,19 +142,21 @@ void setContentFromEditor( QWidget *w )
     if ( w->inherits( "QComboBox" ) ) {
 	QComboBox *cb = (QComboBox*)w;
 	QString s=cb->currentText();
-	if (!s.isEmpty()&& text(0)!=s)
+	if (!s.isEmpty() && s!=p_settext)
 	{
 	QStringList l;
 	l.append(s);
 	setStringList(l);
 	setText( s );
+	p_settext=s;
         p_grid->p_qbe->slot_has_changed();
 	}
 
     }
 
 }
-   
+private:
+QString p_settext;
 };
 
 
@@ -176,7 +180,15 @@ QStringList p_tablenames;
 const int maxrows=15;
 const int maxcolumns=64;
 
-
+const int R_TABLE=0;
+const int R_FIELDNAME=1;
+const int R_ALIAS=2;
+const int R_FUNCTION=3;
+const int R_ORDER=4;
+const int R_SHOW=5;
+const int R_UPDATEVALUE=6;
+const int R_CRITERIA=7;
+const int R_OR=8;
 
 
 
@@ -195,29 +207,29 @@ hk_kdeqbe::hk_kdeqbe(QWidget* w,const char* n,WFlags f) :KParts::MainWindow(w,n,
   p_private->p_table=new internalgrid(p_private->p_splitter,this);
   p_private->p_table->setNumRows(maxrows);
   p_private->p_table->setNumCols(maxcolumns);
-  p_private->p_table->verticalHeader()->setLabel(0,i18n("Table:"));
-  p_private->p_table->verticalHeader()->setLabel(1,i18n("Fieldname:"));
-  p_private->p_table->verticalHeader()->setLabel(2,i18n("Alias:"));
-  p_private->p_table->verticalHeader()->setLabel(3,i18n("Function:"));
-  p_private->p_table->verticalHeader()->setLabel(4,i18n("Order:"));
-  p_private->p_table->verticalHeader()->setLabel(5,i18n("Show:"));
-  p_private->p_table->verticalHeader()->setLabel(6,i18n("Updatevalue:"));
-  p_private->p_table->verticalHeader()->setLabel(7,i18n("Criteria:"));
-  p_private->p_table->verticalHeader()->setLabel(8,i18n("Or:"));
-  for (int k=0;k<maxrows;++k)
+  p_private->p_table->verticalHeader()->setLabel(R_TABLE,i18n("Table:"));
+  p_private->p_table->verticalHeader()->setLabel(R_FIELDNAME,i18n("Fieldname:"));
+  p_private->p_table->verticalHeader()->setLabel(R_ALIAS,i18n("Alias:"));
+  p_private->p_table->verticalHeader()->setLabel(R_FUNCTION,i18n("Function:"));
+  p_private->p_table->verticalHeader()->setLabel(R_ORDER,i18n("Order:"));
+  p_private->p_table->verticalHeader()->setLabel(R_SHOW,i18n("Show:"));
+  p_private->p_table->verticalHeader()->setLabel(R_UPDATEVALUE,i18n("Updatevalue:"));
+  p_private->p_table->verticalHeader()->setLabel(R_CRITERIA,i18n("Criteria:"));
+  p_private->p_table->verticalHeader()->setLabel(R_OR,i18n("Or:"));
+  for (int k=R_TABLE;k<maxrows;++k)
    {
      p_private->p_table->setRowHeight(k,(int)(p_private->p_table->rowHeight(k)*1.5+0.5));
    }
-  for (int k=9;k<maxrows;++k)
+  for (int k=R_OR+1;k<maxrows;++k)
    {
   	p_private->p_table->verticalHeader()->setLabel(k,"");
    }
-  
+
   for (int k=0;k<p_private->p_table->numCols();++k)
    {
      init_column(k);
    }
-  widget_specific_querytype_has_changed(hk_qbe::qt_select,hk_qbe::qt_select); 
+  widget_specific_querytype_has_changed(hk_qbe::qt_select,hk_qbe::qt_select);
   connect(p_private->p_table, SIGNAL(valueChanged(int,int)),this,SLOT(value_changed(int,int)));
   connect(p_private->p_designer,SIGNAL(signal_definition_has_changed()),this, SLOT (datasourcedefiniton_changed()));
   connect(p_private->p_designer,SIGNAL(signal_field_doubleclicked(int,const hk_string&)),
@@ -245,11 +257,11 @@ void hk_kdeqbe::init_column(int col)
   QStringList sl;
   p_private->p_table->horizontalHeader()->setLabel(col,"");
   QComboTableItem* citem= new QComboTableItem(p_private->p_table,sl);
-  p_private->p_table->setItem(0,col,citem);
+  p_private->p_table->setItem(R_TABLE,col,citem);
   citem= new internalcombo(p_private->p_table,sl);
   citem->setEditable(true);
-  p_private->p_table->setItem(1,col,citem);
-	
+  p_private->p_table->setItem(R_FIELDNAME,col,citem);
+
   sl.clear();
   sl.append(i18n("Group"));
   sl.append(i18n("Sum"));
@@ -259,19 +271,19 @@ void hk_kdeqbe::init_column(int col)
   sl.append(i18n("Average"));
   sl.append(i18n("Condition"));
   citem= new QComboTableItem(p_private->p_table,sl);
-  p_private->p_table->setItem(3,col,citem);
-  p_private->p_table->setColumnWidth(col,p_private->p_table->columnWidth(col)*2);	
+  p_private->p_table->setItem(R_FUNCTION,col,citem);
+  p_private->p_table->setColumnWidth(col,p_private->p_table->columnWidth(col)*2);
   sl.clear();
   sl.append(i18n("none"));
   sl.append(i18n("ascending"));
   sl.append(i18n("descending"));
   citem= new QComboTableItem(p_private->p_table,sl);
-  p_private->p_table->setItem(4,col,citem);
+  p_private->p_table->setItem(R_ORDER,col,citem);
   sl.clear();
   sl.append(i18n("Yes"));
   sl.append(i18n("No"));
   QComboTableItem* ch=new QComboTableItem(p_private->p_table,sl);
-  p_private->p_table->setItem(5,col,ch);
+  p_private->p_table->setItem(R_SHOW,col,ch);
   p_private->p_table->setColumnWidth(col,160);
 }
 
@@ -284,11 +296,22 @@ void hk_kdeqbe::set_datasource(hk_datasource* ds)
 #endif
      hk_qbe::set_datasource(ds);
      hk_database* db=NULL;
-     if (ds) db=ds->database(); 
+     if (ds) db=ds->database();
      p_private->p_designer->set_database(db);
      p_private->p_designer->set_presentation(this);
 }
 
+void hk_kdeqbe::set_database(hk_database* db)
+{
+#ifdef HK_DEBUG
+    hkdebug("hk_kdeqbe::set_datasource");
+#endif
+     hk_qbe::set_database(db);
+     //p_private->p_designer->set_database(db);
+     p_private->p_designer->set_presentation(this);
+     widget_specific_querytype_has_changed(querytype(),querytype());
+}
+
 
 
 
@@ -338,7 +361,7 @@ void hk_kdeqbe::datasourcedefiniton_changed(void)
 
 
 void hk_kdeqbe::set_tablenamelist(void)
-{ 
+{
 #ifdef HK_DEBUG
     hkdebug("hk_kdeqbe::set_tablenamelist");
 #endif
@@ -348,8 +371,8 @@ void hk_kdeqbe::set_tablenamelist(void)
   list<hk_datasource*>::iterator it=dslist->begin();
   while (it!=dslist->end())
   {
-    p_private->p_tablenames.append(QString::fromLocal8Bit(
-    unique_shortdatasourcename((*it)->presentationnumber()).c_str()));
+    p_private->p_tablenames.append(QString::fromUtf8(l2u(
+    unique_shortdatasourcename((*it)->presentationnumber())).c_str()));
     ++it;
   }
 }
@@ -362,8 +385,8 @@ void hk_kdeqbe::set_tablenames(void)
   set_tablenamelist();
   for (int k=0;k<p_private->p_table->numCols();++k)
   {
-    
-    QComboTableItem* item=(QComboTableItem*)(p_private->p_table->item(0,k));
+
+    QComboTableItem* item=(QComboTableItem*)(p_private->p_table->item(R_TABLE,k));
     QString current=item->currentText();
     init_tablenames(k);
     int i=p_private->p_tablenames.findIndex(current);
@@ -376,7 +399,7 @@ void hk_kdeqbe::init_tablenames(int col)
 #ifdef HK_DEBUG
     hkdebug("hk_kdeqbe::init_tablenames");
 #endif
-   QComboTableItem* item=(QComboTableItem*)(p_private->p_table->item(0,col));
+   QComboTableItem* item=(QComboTableItem*)(p_private->p_table->item(R_TABLE,col));
     item->setStringList(p_private->p_tablenames);
 }
 
@@ -387,7 +410,7 @@ void hk_kdeqbe::value_changed(int row, int col)
     hkdebug("hk_kdeqbe::value_changed");
 #endif
    set_has_changed();
-   if (row==0/*table*/)
+   if (row==R_TABLE/*table*/)
       {
          set_columnnames(col);
       }
@@ -401,10 +424,10 @@ void hk_kdeqbe::set_columnnames(int col)
     hkdebug("hk_kdeqbe::set_columnnames("+longint2string(col)+")");
 #endif
    set_has_changed();
-   QComboTableItem* item=(QComboTableItem*)(p_private->p_table->item(1,col));
-   hk_string tbl=p_private->p_table->item(0,col)->text().local8Bit().data();
+   QComboTableItem* item=(QComboTableItem*)(p_private->p_table->item(R_FIELDNAME,col));
+   hk_string tbl=u2l(p_private->p_table->item(R_TABLE,col)->text().utf8().data());
    hk_datasource* ds= get_datasource_by_shortname(tbl);
-  ((QComboTableItem*)p_private->p_table->item(1,col))->setEditable(tbl=="");
+  ((QComboTableItem*)p_private->p_table->item(R_FIELDNAME,col))->setEditable(tbl=="");
 
    QStringList strlist;
     strlist.append("");
@@ -416,8 +439,8 @@ void hk_kdeqbe::set_columnnames(int col)
       strlist.append("*");
       list<hk_column*>::iterator it=collist->begin();
       while (it!=collist->end())
-      {  
-       strlist.append(QString::fromLocal8Bit((*it)->name().c_str()));
+      {
+       strlist.append(QString::fromUtf8(l2u((*it)->name()).c_str()));
        ++it;
       }
      }
@@ -431,39 +454,60 @@ void hk_kdeqbe::set_columnnames(int col)
 #ifdef HK_DEBUG
     hkdebug("hk_kdeqbe::widget_specific_querytype_has_changed");
 #endif
+
+  if (!database())
+    {
+     //cerr <<"no database"<<endl;
+     return;
+    }
+    bool s_alias=database()->connection()->server_supports(hk_connection::SUPPORTS_SQL_ALIAS);
+    bool s_where=database()->connection()->server_supports(hk_connection::SUPPORTS_SQL_WHERE);
+    bool s_groupby=database()->connection()->server_supports(hk_connection::SUPPORTS_SQL_GROUP_BY);
+    bool s_orderby=database()->connection()->server_supports(hk_connection::SUPPORTS_SQL_ORDER_BY);
+    //cerr <<"a:"<<s_alias<<" w:"<<s_where<<" g:"<<s_groupby<<" o:"<<s_orderby<<endl;
        switch (nt)
       {
-        case qt_select:  
-			p_private->p_table->showRow(2);//Alias
-			p_private->p_table->hideRow(3);//Function
-			p_private->p_table->showRow(4);//Order
-			p_private->p_table->showRow(5);//show
-			p_private->p_table->hideRow(6);//UpdateValue
+        case qt_select:
+			p_private->p_table->showRow(R_ALIAS);//Alias
+			p_private->p_table->hideRow(R_FUNCTION);//Function
+			p_private->p_table->showRow(R_ORDER);//Order
+			p_private->p_table->showRow(R_SHOW);//show
+			p_private->p_table->hideRow(R_UPDATEVALUE);//UpdateValue
 			break;
-        case qt_groupselect:  
-			p_private->p_table->showRow(2);//Alias
-			p_private->p_table->showRow(3);//Function
-			p_private->p_table->showRow(4);//Order
-			p_private->p_table->hideRow(5);//show
-			p_private->p_table->hideRow(6);//UpdateValue
+        case qt_groupselect:
+			p_private->p_table->showRow(R_ALIAS);//Alias
+			p_private->p_table->showRow(R_FUNCTION);//Function
+			p_private->p_table->showRow(R_ORDER);//Order
+			p_private->p_table->hideRow(R_SHOW);//show
+			p_private->p_table->hideRow(R_UPDATEVALUE);//UpdateValue
 			break;
-	case qt_update: 
-			p_private->p_table->hideRow(2);//Alias
-			p_private->p_table->hideRow(3);//Function
-			p_private->p_table->hideRow(4);//Order
-			p_private->p_table->hideRow(5);//show
-			p_private->p_table->showRow(6);//UpdateValue
+	case qt_update:
+			p_private->p_table->hideRow(R_ALIAS);//Alias
+			p_private->p_table->hideRow(R_FUNCTION);//Function
+			p_private->p_table->hideRow(R_ORDER);//Order
+			p_private->p_table->hideRow(R_SHOW);//show
+			p_private->p_table->showRow(R_UPDATEVALUE);//UpdateValue
 			break;
-	case qt_delete: 
-			p_private->p_table->hideRow(2);//Alias
-			p_private->p_table->hideRow(3);//Function
-			p_private->p_table->hideRow(4);//Order
-			p_private->p_table->hideRow(5);//show
-			p_private->p_table->hideRow(6);//UpdateValue
+	case qt_delete:
+			p_private->p_table->hideRow(R_ALIAS);//Alias
+			p_private->p_table->hideRow(R_FUNCTION);//Function
+			p_private->p_table->hideRow(R_ORDER);//Order
+			p_private->p_table->hideRow(R_SHOW);//show
+			p_private->p_table->hideRow(R_UPDATEVALUE);//UpdateValue
       }
+
+   if (!s_alias)   p_private->p_table->hideRow(R_ALIAS);
+   if (!s_groupby)   p_private->p_table->hideRow(R_FUNCTION);
+   if (!s_orderby)   p_private->p_table->hideRow(R_ORDER);
+   if (!s_where)
+     {
+         for(int i=R_CRITERIA;i<maxrows;++i)
+		p_private->p_table->hideRow(i);//WHERE Fields
+
+     }
   emit signal_qbetype_has_changed();
   }
-  
+
 
 
 void hk_kdeqbe::set_columnvalues(void)
@@ -475,20 +519,20 @@ void hk_kdeqbe::set_columnvalues(void)
   clear_definition(false);
   for (int i=0;i<p_private->p_table->numCols();++i)
   {
-    if ( ((QComboTableItem*)(p_private->p_table->item(1,i)))->currentItem()>0 // field
-          || !(((QComboTableItem*)(p_private->p_table->item(1,i)))->currentText().isEmpty())
+    if ( ((QComboTableItem*)(p_private->p_table->item(R_FIELDNAME,i)))->currentItem()>0 // field
+          || !(((QComboTableItem*)(p_private->p_table->item(R_FIELDNAME,i)))->currentText().isEmpty())
        )
-     { 
+     {
 
         hk_qbedataclass cl;
-	hk_datasource* ds=get_datasource_by_shortname(p_private->p_table->item(0,i)->text().local8Bit().data());
+	hk_datasource* ds=get_datasource_by_shortname(u2l(p_private->p_table->item(R_TABLE,i)->text().utf8().data()));
 	if (ds)
 	{
 	  cl.table=ds->presentationnumber();
 	}  else cl.table=-1;
-	cl.field=p_private->p_table->item(1,i)->text().local8Bit().data();
-	if (p_private->p_table->item(2,i))cl.alias=p_private->p_table->item(2,i)->text().local8Bit().data();
-	switch(((QComboTableItem*)(p_private->p_table->item(3,i)))->currentItem())
+	cl.field=u2l(p_private->p_table->item(R_FIELDNAME,i)->text().utf8().data());
+	if (p_private->p_table->item(R_ALIAS,i))cl.alias=u2l(p_private->p_table->item(R_ALIAS,i)->text().utf8().data());
+	switch(((QComboTableItem*)(p_private->p_table->item(R_FUNCTION,i)))->currentItem())
 	{
 	  case 0: cl.functiontype=ft_group;break;
 	  case 1: cl.functiontype=ft_sum;break;
@@ -497,31 +541,31 @@ void hk_kdeqbe::set_columnvalues(void)
 	  case 4: cl.functiontype=ft_max;break;
 	  case 5: cl.functiontype=ft_condition;break;
 	}
-	switch(((QComboTableItem*)(p_private->p_table->item(4,i)))->currentItem())
+	switch(((QComboTableItem*)(p_private->p_table->item(R_ORDER,i)))->currentItem())
 	{
 	  case 0: cl.order=none;break;
 	  case 1: cl.order=ascending;break;
 	  case 2: cl.order=descending;break;
 	}
-	cl.show=(((QComboTableItem*)(p_private->p_table->item(5,i)))->currentItem()==0);
-	
-	
-	if (p_private->p_table->item(6,i))cl.updatevalue=p_private->p_table->item(6,i)->text().local8Bit().data();
-	int endconditions=7;
-	for (int c=7;c<maxrows;++c)
+	cl.show=(((QComboTableItem*)(p_private->p_table->item(R_SHOW,i)))->currentItem()==0);
+
+
+	if (p_private->p_table->item(R_UPDATEVALUE,i))cl.updatevalue=u2l(p_private->p_table->item(R_UPDATEVALUE,i)->text().utf8().data());
+	int endconditions=R_CRITERIA;
+	for (int c=R_CRITERIA;c<maxrows;++c)
 	  {
-	    hk_string condi= trim(p_private->p_table->text(c,i).local8Bit().data());
-	    if (condi.size()>0) endconditions=c; 
-	  
+	    hk_string condi= trim(u2l(p_private->p_table->text(c,i).utf8().data()));
+	    if (condi.size()>0) endconditions=c;
+
 	  }
-	
-         for(int c=7;c<=endconditions;++c)
+
+         for(int c=R_CRITERIA;c<=endconditions;++c)
 	 	{
-		  hk_string condi= trim(p_private->p_table->text(c,i).local8Bit().data());
+		  hk_string condi= trim(u2l(p_private->p_table->text(c,i).utf8().data()));
 		  cl.conditions.insert(cl.conditions.end(),condi);
 		}
         add_definition(&cl);
-     }  
+     }
   }
   set_block_has_changed(false);
 }
@@ -536,39 +580,40 @@ void hk_kdeqbe::loaddata(const hk_string& definition)
    int counter=0;
    set_tablenames();
    while (it!=definitionlist()->end())
-   {  
-	QComboTableItem* item=(QComboTableItem*)(p_private->p_table->item(0,counter));
-        int i=p_private->p_tablenames.findIndex(QString::fromLocal8Bit(unique_shortdatasourcename((*it).table).c_str()));
+   {
+	QComboTableItem* item=(QComboTableItem*)(p_private->p_table->item(R_TABLE,counter));
+	int i=p_private->p_tablenames.findIndex(QString::fromUtf8(l2u(unique_shortdatasourcename((*it).table)).c_str()));
+
         if (i>-1)
-	   { 
+	   {
 	      item->setCurrentItem(i);  // set tablename
 	      set_columnnames(counter);
 	   }
-	
-	item=(QComboTableItem*)(p_private->p_table->item(1,counter));
-        
+
+	item=(QComboTableItem*)(p_private->p_table->item(R_FIELDNAME,counter));
+
 	i=-1;
 	for (int k=0;k<item->count();++k)
 	  {
-	    if (item->text(k)==QString::fromLocal8Bit((*it).field.c_str()))
+	    if (item->text(k)==QString::fromUtf8(l2u((*it).field).c_str()))
 	      i=k;
 	  }
         if (i>-1)
-	   { 
+	   {
 	      item->setCurrentItem(i);  // set fieldname
 	   }
-	 if ((*it).table==-1) 
+	 if ((*it).table==-1)
 	  {
 	    QStringList strlist;
             strlist.append("");
-	    strlist.append(QString::fromLocal8Bit((*it).field.c_str()));
+	    strlist.append(QString::fromUtf8(l2u((*it).field).c_str()));
             item->setEditable(true);
 	    item->setStringList(strlist);
 	    item->setCurrentItem(1);
-	  } 
+	  }
 	//set alias
-	p_private->p_table->setText(2,counter,QString::fromLocal8Bit((*it).alias.c_str()));   
-        
+	p_private->p_table->setText(R_ALIAS,counter,QString::fromUtf8(l2u((*it).alias).c_str()));
+
 	//set functiontype
 	i=0;
 	switch ((*it).functiontype)
@@ -581,11 +626,11 @@ void hk_kdeqbe::loaddata(const hk_string& definition)
 	case ft_avg:i=5;break;
 	case ft_condition:i=6;break;
         }
-	item=(QComboTableItem*)(p_private->p_table->item(3,counter));
+	item=(QComboTableItem*)(p_private->p_table->item(R_FUNCTION,counter));
 	item->setCurrentItem(i);
-	
+
 	// set order
-	item=(QComboTableItem*)(p_private->p_table->item(4,counter));
+	item=(QComboTableItem*)(p_private->p_table->item(R_ORDER,counter));
 	switch ((*it).order)
 	{
 	case none: i=0;break;
@@ -593,23 +638,23 @@ void hk_kdeqbe::loaddata(const hk_string& definition)
 	case descending: i=2;break;
 	}
 	item->setCurrentItem(i);
-	
+
 	//set show
-	item=(QComboTableItem*)(p_private->p_table->item(5,counter));
+	item=(QComboTableItem*)(p_private->p_table->item(R_SHOW,counter));
 	if ((*it).show) i=0; else i=1;
 	item->setCurrentItem(i);
 	//set updatevalue
-	p_private->p_table->setText(6,counter,QString::fromLocal8Bit((*it).updatevalue.c_str()));   
+	p_private->p_table->setText(R_UPDATEVALUE,counter,QString::fromUtf8(l2u((*it).updatevalue).c_str()));
         vector<hk_string>::iterator condit;
 	vector<hk_string> l=(*it).conditions;
 	condit=l.begin();
-	i=7;
+	i=R_CRITERIA;
 	while( condit!=l.end())
 	{
-	 p_private->p_table->setText(i,counter,QString::fromLocal8Bit((*condit).c_str()));
+	 p_private->p_table->setText(i,counter,QString::fromUtf8(l2u((*condit)).c_str()));
 	 ++condit;++i;
 	}
-       
+
     ++it;++counter;
    }
   emit (signal_distinct_has_changed());
@@ -618,7 +663,7 @@ void hk_kdeqbe::loaddata(const hk_string& definition)
 void hk_kdeqbe::add_column(int table, const hk_string& columnname)
 {
   int pos=0;
-    while(!p_private->p_table->text(1,pos).isEmpty() &&pos<p_private->p_table->numCols())
+    while(!p_private->p_table->text(R_TABLE,pos).isEmpty() &&pos<p_private->p_table->numCols())
    {
      ++pos;
    }
@@ -638,28 +683,28 @@ void hk_kdeqbe::add_column(int pos, int table, const hk_string& columnname)
 p_private->p_table->insertColumns(pos);
 init_column(pos);
 init_tablenames(pos);
-int i=p_private->p_tablenames.findIndex(QString::fromLocal8Bit(unique_shortdatasourcename(table).c_str()));
-QComboTableItem* item=(QComboTableItem*)(p_private->p_table->item(0,pos));
+int i=p_private->p_tablenames.findIndex(QString::fromUtf8(l2u(unique_shortdatasourcename(table)).c_str()));
+QComboTableItem* item=(QComboTableItem*)(p_private->p_table->item(R_TABLE,pos));
 if (i>-1)
-   {  
+   {
       item->setCurrentItem(i);  // set tablename
       set_columnnames(pos);
    }
 
-item=(QComboTableItem*)(p_private->p_table->item(1,pos));
-        
+item=(QComboTableItem*)(p_private->p_table->item(R_FIELDNAME,pos));
+
 i=-1;
 for (int k=0;k<item->count();++k)
   {
-    if (item->text(k)==QString::fromLocal8Bit(columnname.c_str()))
+    if (item->text(k)==QString::fromUtf8(l2u(columnname).c_str()))
       i=k;
   }
    if (i>-1)
-   { 
+   {
       item->setCurrentItem(i);  // set fieldname
    }
- p_private->p_table->setCurrentCell(p_private->p_table->currentRow(),pos);  
-   
+ p_private->p_table->setCurrentCell(p_private->p_table->currentRow(),pos);
+
 }
 
 
