@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.15 $
+//$Revision: 1.23 $
 
 #include "hk_kdequerypartwidget.h"
 #include "hk_kdequerypartwidget.moc"
@@ -19,6 +19,7 @@
 #include <qlayout.h>
 #include <qvariant.h>
 #include <qtooltip.h>
+#include <qclipboard.h>
 #include <qwhatsthis.h>
 #include <qimage.h>
 #include <qpixmap.h>
@@ -83,6 +84,7 @@ hk_kdequerypartwidget::hk_kdequerypartwidget(hk_kdequerypart* part,QWidget* w,co
     KLibFactory* p_factory= KLibLoader::self()->factory( "libkatepart" );
     p_private->p_katepart = (Kate::Document *) p_factory->create (0L, "kate", "KTextEditor::Document");
     p_private->p_designkate=(Kate::View *)p_private->p_katepart->createView (this, 0L);
+    p_private->p_designkate->setFocus();
     setName( "hk_kdequerypartwidget" );
     resize( 596, 480 );
     p_factory= KLibLoader::self()->factory( "libhk_kdegridpart" );
@@ -90,9 +92,9 @@ hk_kdequerypartwidget::hk_kdequerypartwidget(hk_kdequerypart* part,QWidget* w,co
    if (!p_private->p_part)
     {
      show_warningmessage(hk_translate("Fatal error! Grid part could not be loaded!\nThis is a installation error. Check your installation!\
- Did you install knoda into the correct directory? Program will exit now...")); 
+ Did you install knoda into the correct directory? Program will exit now..."));
      exit(1);
-    } 
+    }
      p_factory= KLibLoader::self()->factory( "libhk_kdeqbepart" );
     p_private->p_qbepart=(KParts::ReadWritePart*) p_factory->create (this, "hk_kdeqbepart", "KParts::ReadWritePart");
     p_private->p_grid = (hk_kdegrid*)p_private->p_part->widget();
@@ -117,6 +119,7 @@ hk_kdequerypartwidget::hk_kdequerypartwidget(hk_kdequerypart* part,QWidget* w,co
     p_qbetypeselectaction=NULL;
     p_qbetypeselect=NULL;
     p_copyaction=NULL;
+    p_copybackendsqlaction=NULL;
     p_pasteaction=NULL;
     p_replaceaction=NULL;
     p_findaction=NULL;
@@ -127,6 +130,7 @@ hk_kdequerypartwidget::hk_kdequerypartwidget(hk_kdequerypart* part,QWidget* w,co
     p_redoaction=NULL;
     p_selectallaction=NULL;
     p_configeditoraction=NULL;
+    p_storeresultaction=NULL;
 
     set_nodesignmode(runtime_only());
     designbutton_clicked();
@@ -135,7 +139,7 @@ hk_kdequerypartwidget::hk_kdequerypartwidget(hk_kdequerypart* part,QWidget* w,co
     p_private->p_designkate->setLineNumbersOn(true);
     p_private->highlighting_set=false;
     p_private->p_qbe->hide();
-    
+
 
 }
 
@@ -149,7 +153,7 @@ hk_kdequerypartwidget::~hk_kdequerypartwidget()
     p_private->p_designkate=NULL;
     delete p_private->p_katepart;
     hk_datasource* d=p_private->p_grid->datasource();
-    
+
     if (d!=NULL)
     {
         if (!d->presentation())d->disable();
@@ -183,19 +187,23 @@ void hk_kdequerypartwidget::set_datasource(hk_datasource* d)
     if (d)
      {
       db=d->database();
-      
-      if (d->type()==hk_datasource::ds_view) 
+
+      if (d->type()==hk_datasource::ds_view)
        {
        p_private->p_asview=true;
        p_private->p_grid->load_view();
        }
-     } 
+     }
     p_private->p_qbe->set_database(db);
     if (d!=NULL)
     {
-    p_private->p_designkate->getDoc()->blockSignals(true);
-    if (d->sql().c_str())p_private->p_designkate->getDoc()->setText(QString::fromLocal8Bit(d->sql().c_str()));
-    p_private->p_designkate->getDoc()->blockSignals(false);
+    //p_private->p_designkate->getDoc()->blockSignals(true);
+    if (d->sql().c_str())
+     {
+       p_private->p_designkate->getDoc()->setText(QString::fromUtf8(l2u(d->sql()).c_str()));
+       p_private->p_designkate->getDoc()->clearUndo();
+     }
+    //p_private->p_designkate->getDoc()->blockSignals(false);
     }
     reset_has_changed();
 
@@ -225,9 +233,9 @@ void hk_kdequerypartwidget::internal_set_designmode(void)
     }
     hk_datasource* d=p_private->p_grid->datasource();
     if (d!=NULL) d->disable();
-    
-    
-    
+
+
+
     if (p_qbetypeselectaction)p_qbetypeselectaction->setEnabled(use_qbe());
     if (p_qbetypeselect)p_qbetypeselect->setEnabled(use_qbe());
     if (p_distinctaction)p_distinctaction->setEnabled(use_qbe());
@@ -243,18 +251,19 @@ void hk_kdequerypartwidget::internal_set_designmode(void)
     if (p_findpreviousaction)p_findpreviousaction->setEnabled(!use_qbe());
     if (p_selectallaction)p_selectallaction->setEnabled(!use_qbe());
     if (p_configeditoraction)p_configeditoraction->setEnabled(!use_qbe());
+    if (p_storeresultaction)p_storeresultaction->setEnabled(false);
+
+
+
+
+
+
 
-    
-    
-    
-    
-    
-    
     if (use_qbe())
     {
      p_private->p_querypart->setXMLFile(locate("data","hk_kdeclasses/hk_kdequerypartqbe.rc"));
      //if (p_private->p_querypart->manager())p_private->p_querypart->manager()->setActivePart(p_private->p_querypart);
-     
+
 	set_block_has_changed(true);
 	raiseWidget(p_private->p_qbe);
 	set_block_has_changed(false);
@@ -264,7 +273,7 @@ void hk_kdequerypartwidget::internal_set_designmode(void)
      p_private->p_querypart->setXMLFile(locate("data","hk_kdeclasses/hk_kdequerypartsql.rc"));
      //if (p_private->p_querypart->manager())p_private->p_querypart->manager()->setActivePart(p_private->p_querypart);
         raiseWidget(p_private->p_designkate);
-        p_private->p_designkate->setFocus();	
+        p_private->p_designkate->setFocus();
 
     if (p_designaction)p_designaction->setChecked(true);
     unsigned int i=0;
@@ -315,8 +324,8 @@ void hk_kdequerypartwidget::internal_set_viewmode(void)
     if (p_qbetypeselect)p_qbetypeselect->setEnabled(false);
     if (p_distinctaction)p_distinctaction->setEnabled(false);
     if (p_addaction)p_addaction->setEnabled(false);
-    
-    
+
+
     if (p_copyaction)p_copyaction->setEnabled(false);
     if (p_cutaction)p_cutaction->setEnabled(false);
     if (p_undoaction)p_undoaction->setEnabled(false);
@@ -329,21 +338,22 @@ void hk_kdequerypartwidget::internal_set_viewmode(void)
     if (p_selectallaction)p_selectallaction->setEnabled(false);
     if (p_configeditoraction)p_configeditoraction->setEnabled(false);
     if (p_qbeaction)p_qbeaction->setEnabled(false);
-    
-    
-    
-    
-    
-    
-    
-    
-    
+    if (p_storeresultaction)p_storeresultaction->setEnabled(true);
+
+
+
+
+
+
+
+
+
     hk_datasource* d=p_private->p_grid->datasource();
     bool actionquery=false;
 
     if (!use_qbe())
     {
-    hk_string tst_sql=p_private->p_designkate->getDoc()->text().local8Bit().data();
+    hk_string tst_sql=u2l(p_private->p_designkate->getDoc()->text().utf8().data());
     hk_string separator=" \t\n";
     hk_string::size_type startpos=hk_string::npos;
     for (unsigned int tt=0;tt<tst_sql.size();tt++)
@@ -351,14 +361,14 @@ void hk_kdequerypartwidget::internal_set_viewmode(void)
         tst_sql[tt]=toupper(tst_sql[tt]);
     }
    startpos=tst_sql.find_first_not_of(separator);
-   if (startpos==hk_string::npos) 
+   if (startpos==hk_string::npos)
       {
         set_designmode();
 	return;
       }
    hk_string::size_type endpos=tst_sql.find_first_of(separator,startpos+1);
     hk_string value=tst_sql.substr(startpos,endpos-startpos);
-    
+
     actionquery=(value=="ALTER");
     if (!actionquery) actionquery=(value=="DROP");
     if (!actionquery) actionquery=(value=="INSERT");
@@ -368,37 +378,37 @@ void hk_kdequerypartwidget::internal_set_viewmode(void)
     if (!actionquery) actionquery=(value=="REVOKE");
     if (!actionquery) actionquery=(value=="FLUSH");
     }// !use_qbe end
-    
+
     if (d!=NULL)
     {
         if ((!use_qbe()&&!actionquery)||
 	((use_qbe()&& p_private->p_qbe &&
-	(p_private->p_qbe->querytype()==hk_qbe::qt_select 
+	(p_private->p_qbe->querytype()==hk_qbe::qt_select
 	||p_private->p_qbe->querytype()==hk_qbe::qt_groupselect)))
 	)
-        {   
+        {
             if (use_qbe()&& p_private->p_qbe)
-	    {  
+	    {
               p_private->p_qbe->set_columnvalues();
 	      if (d->set_query(p_private->p_qbe))
 	      {
 	        p_private->p_designkate->getDoc()->blockSignals(true);
-                if (d->sql().c_str())p_private->p_designkate->getDoc()->setText(QString::fromLocal8Bit(d->sql().c_str()));
+                if (d->sql().c_str())p_private->p_designkate->getDoc()->setText(QString::fromUtf8(l2u(d->sql()).c_str()));
                 p_private->p_designkate->getDoc()->blockSignals(false);
 	      }
 	      else
-	      {cerr <<"use_qbe="<<use_qbe()<<" p_qbe="<<p_private->p_qbe<<endl;
-	        if (!runtime_only()) 
-		{ 
+	      {//cerr <<"use_qbe="<<use_qbe()<<" p_qbe="<<p_private->p_qbe<<endl;
+	        if (!runtime_only())
+		{
 		  set_designmode();
 		  return;
-		}  
+		}
 	      }
 	    }
 	    else
 	    {
-	     d->set_sql(p_private->p_designkate->getDoc()->text().local8Bit().data(),true);
-	    } 
+	     d->set_sql(u2l(p_private->p_designkate->getDoc()->text().utf8().data()),true);
+	    }
             if ( !d->enable())
             {
                 hk_string reason=hk_translate("Query could not be executed")+"\n"+hk_translate("Servermessage: ")+d->database()->connection()->last_servermessage();
@@ -416,11 +426,11 @@ void hk_kdequerypartwidget::internal_set_viewmode(void)
             hk_actionquery* q=d->database()->new_actionquery();
             if (q!=NULL)
             {
-                hk_string sql=p_private->p_designkate->getDoc()->text().local8Bit().data();
+                hk_string sql=u2l(p_private->p_designkate->getDoc()->text().utf8().data());
 	      if (p_private->p_qbe&&use_qbe())
 	      {
 	      p_private->p_qbe->set_columnvalues();
-	       if(p_private->p_qbe->querytype()==hk_qbe::qt_update 
+	       if(p_private->p_qbe->querytype()==hk_qbe::qt_update
 	       ||p_private->p_qbe->querytype()==hk_qbe::qt_delete)
                 if (!p_private->p_qbe->create_sql(sql))
 		{
@@ -433,7 +443,7 @@ void hk_kdequerypartwidget::internal_set_viewmode(void)
 	          set_designmode();
 		  return;
 	      	}
-  	      }  
+  	      }
 		q->set_sql(sql,true);
                 if (q->execute())
                     show_warningmessage(hk_class::hk_translate("Query was successful"));
@@ -503,7 +513,7 @@ void hk_kdequerypartwidget::before_source_vanishes(void)
         hk_datasource* d=datasource();
         if (d!=NULL)d->disable();
         set_datasource(NULL);
-	
+
     }
     //hk_dsquery::before_source_vanishes();
 }
@@ -517,7 +527,7 @@ void hk_kdequerypartwidget::query_changed(void)
     set_has_changed();
     //p_private->p_saveaction->setEnabled(true);
 
-    if (datasource()!=NULL)  datasource()->set_sql(p_private->p_designkate->getDoc()->text().local8Bit().data(),true);
+    if (datasource()!=NULL)  datasource()->set_sql(u2l(p_private->p_designkate->getDoc()->text().utf8().data()),true);
 }
 
 
@@ -534,8 +544,8 @@ void hk_kdequerypartwidget::closeEvent ( QCloseEvent* e)
     }
     delete p_private->p_katepart;
     p_private->p_katepart=NULL;
-    
-    
+
+
     QWidgetStack::closeEvent(e);
    emit signal_closed(this);
 
@@ -557,7 +567,7 @@ bool hk_kdequerypartwidget::save_query(const hk_string& n,bool ask)
     set_caption();
     if (p_private->p_qbe) p_private->p_qbe->set_columnvalues();
     if (use_qbe()&& p_private->p_qbe)
-	    {  
+	    {
 	      p_private->p_grid->datasource()->set_query(p_private->p_qbe);
 	    }
      return hk_dsquery::save_query(n,ask);
@@ -574,9 +584,14 @@ bool hk_kdequerypartwidget::load_query(void)
     bool r= hk_dsquery::load_query();
     hk_datasource* d=datasource();
     if (d==NULL)return false;
-    p_private->p_designkate->getDoc()->blockSignals(true);
-    if (d->sql().c_str())p_private->p_designkate->getDoc()->setText(QString::fromLocal8Bit(d->sql().c_str()));
-    p_private->p_designkate->getDoc()->blockSignals(false);
+    //p_private->p_designkate->getDoc()->blockSignals(true);
+    if (d->sql().c_str())
+    {
+    p_private->p_designkate->getDoc()->setText(QString::fromUtf8(l2u(d->sql()).c_str()));
+    p_private->p_designkate->getDoc()->clearUndo();
+
+    }
+    //p_private->p_designkate->getDoc()->blockSignals(false);
     p_private->p_grid->set_font(hk_font());
     set_caption();
     reset_has_changed();
@@ -605,7 +620,7 @@ void hk_kdequerypartwidget::saveasbutton_clicked(void)
     if (!p_private->p_grid->datasource()) return;
     hk_string oldname=p_private->p_grid->datasource()->name();
     p_private->p_grid->datasource()->set_name("");
-    if (save_query("",false))
+    if (save_query("",true))
     {
         reset_has_changed();
 
@@ -636,8 +651,8 @@ void hk_kdequerypartwidget::set_caption(void)
     if (d!=NULL)
     {
         QString n=((d->type()==hk_datasource::ds_view)? i18n("View - "):i18n("Query - "));
-        n+=QString::fromLocal8Bit(d->name().c_str());
-	QString name=QString::fromLocal8Bit(d->database()->connection()->drivername().c_str())+" "+n;
+        n+=QString::fromUtf8(l2u(d->name()).c_str());
+	QString name=QString::fromUtf8(l2u(d->database()->connection()->drivername()).c_str())+" "+n;
         setCaption(name);
     	KMdiChildView* v=dynamic_cast<KMdiChildView*>(parent());
         if (v) v->setCaption(n);
@@ -673,7 +688,7 @@ void hk_kdequerypartwidget::print(void)
 
 void    hk_kdequerypartwidget::keyPressEvent ( QKeyEvent * e )
 {
-  
+
   QWidgetStack::keyPressEvent(e);
 }
 
@@ -711,17 +726,17 @@ void hk_kdequerypartwidget::action_useqbe(void)
     hkdebug("hk_kdeqbe::action_useqbe");
 #endif
   if (!use_qbe() && !show_yesnodialog(
-  			hk_translate("If you change to the QBE window your SQL statement will be lost. Continue?"),true)) 
+  			hk_translate("If you change to the QBE window your SQL statement will be lost. Continue?"),true))
 	{
 	    p_qbeaction->blockSignals(true);
     	    p_qbeaction->setChecked(use_qbe());
             p_qbeaction->blockSignals(false);
         return;
 	}
-   
+
      set_use_qbe(!use_qbe());
 
-     
+
      if (in_designmode()) designbutton_clicked();
     p_qbeaction->blockSignals(true);
     p_qbeaction->setChecked(use_qbe());
@@ -748,7 +763,7 @@ hk_kdeqbe*  hk_kdequerypartwidget::kdeqbe(void) const
 
 
 void hk_kdequerypartwidget::qbe_has_changed(void)
-{  
+{
   set_has_changed();
 }
 
@@ -770,7 +785,7 @@ void hk_kdequerypartwidget::showMaximized()
 
 void hk_kdequerypartwidget::set_has_changed(enum_has_changed forcesetting)
 {
-cerr <<"hk_kdequerypartwidget::set_has_changed"<<endl;
+//cerr <<"hk_kdequerypartwidget::set_has_changed"<<endl;
 hk_dsquery::set_has_changed(forcesetting);
  if (p_saveaction)p_saveaction->setEnabled(!runtime_only()&& has_changed());
 }
@@ -789,6 +804,15 @@ void hk_kdequerypartwidget::copy_clicked(void)
 if (p_private->p_designkate)p_private->p_designkate->copy();
 }
 
+
+void hk_kdequerypartwidget::copybackendsql_clicked(void)
+{
+if (datasource())
+   {
+	QApplication::clipboard()->setText(QString::fromUtf8(l2u(datasource()->backendsql()).c_str()));
+   }
+}
+
 void hk_kdequerypartwidget::paste_clicked(void)
 {
 if (p_private->p_designkate)p_private->p_designkate->paste();
@@ -841,4 +865,24 @@ if (p_private->p_katepart)p_private->p_katepart->configDialog();
 }
 
 
+void hk_kdequerypartwidget::show_widget(void)
+{
+  show();
+}
 
+void hk_kdequerypartwidget::hide_widget(void)
+{
+  hide();
+}
+
+void hk_kdequerypartwidget::close_widget(void)
+{
+  close();
+}
+
+
+void hk_kdequerypartwidget::storeresult_clicked(void)
+{
+  if (!datasource()) return;
+  datasource()->database()->copy_table(datasource(),true,false,true);
+}
