@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -14,6 +14,12 @@
 #include <hk_presentation.h>
 #include <qtable.h>
 #include <qpushbutton.h>
+#include <qgroupbox.h>
+#include <qcombobox.h>
+
+#include <kapplication.h>
+#include <kconfig.h>
+#include <klocale.h>
 
 
 
@@ -30,21 +36,48 @@ ok_button->installEventFilter(this);
 cancel_button->installEventFilter(this);
 grid->setColumnWidth(0,w);
 grid->setColumnWidth(1,w);
-grid->horizontalHeader()->setLabel(0,QString::fromLocal8Bit(
+grid->horizontalHeader()->setLabel(0,QString::fromUtf8(l2u(
 			master->designer()->presentation()
-				->unique_datasourcename(master->datasource()->presentationnumber()).c_str()));
+				->unique_datasourcename(master->datasource()->presentationnumber())).c_str()));
 
-grid->horizontalHeader()->setLabel(1,QString::fromLocal8Bit(
+grid->horizontalHeader()->setLabel(1,QString::fromUtf8(l2u(
 			master->designer()->presentation()
-				->unique_datasourcename(slave->datasource()->presentationnumber()).c_str()));
+				->unique_datasourcename(slave->datasource()->presentationnumber())).c_str()));
+
 
-				
 set_stringlist(&p_mastercollist,p_masterdsframe->datasource()->columnnames());
 set_stringlist(&p_slavecollist,p_slavedsframe->datasource()->columnnames());
 add_row();
 //ok_button->setEnabled(false);
 set_existing_fields();
 connect(grid,SIGNAL(valueChanged(int,int)),this,SLOT(slot_data_changed(int,int)));
+  KConfig* c=kapp->config();
+  QRect rect(0,0,500,300);
+  c->setGroup("Relationdialog");
+  QRect g;
+  g=c->readRectEntry("Geometry",&rect);
+  setGeometry(g);
+  int cw=150;
+  cw=c->readNumEntry("ColwidthLeft",cw);
+  grid->setColumnWidth(0,cw);
+  cw=c->readNumEntry("ColwidthRight",cw);
+  grid->setColumnWidth(1,cw);
+  if (master&&master->designer()->presentation()&&master->designer()->presentation()&&master->designer()->presentation()->presentationtype()==hk_presentation::referentialintegrity)
+   integritybox->show();
+  else
+   integritybox->hide();
+
+QString cascade=i18n("Cascade");
+QString restrict=i18n("Restrict");
+onupdatefield->insertItem(restrict);
+onupdatefield->insertItem(cascade);
+ondeletefield->insertItem(restrict);
+ondeletefield->insertItem(cascade);
+if (r)
+  {
+     onupdatefield->setCurrentItem(r->updatecascade());
+     ondeletefield->setCurrentItem(r->deletecascade());
+  }
 }
 
 
@@ -82,7 +115,7 @@ void hk_kderelationdialog::set_stringlist(QStringList* strlist,list<hk_string>*
    list<hk_string>::iterator it= collist->begin();
    while (it!=collist->end())
    {
-       strlist->append(QString::fromLocal8Bit((*it).c_str()));
+       strlist->append(QString::fromUtf8(l2u((*it)).c_str()));
      ++it;
    }
 
@@ -95,12 +128,17 @@ void hk_kderelationdialog::set_stringlist(QStringList* strlist,list<hk_string>*
 void hk_kderelationdialog::set_existing_fields(void)
 {
 if (!p_slavedsframe->datasource())return;
+if (p_slavedsframe->designer()->presentation()->presentationtype()==hk_presentation::referentialintegrity)
+  {
+  set_existing_refintegrityfields();
+  return;
+  }
+
 if (p_slavedsframe->datasource()->depending_on()!=p_masterdsframe->datasource())
    {
-      
+
       return;
    }
-   
  list<hk_string>* slavefields=p_slavedsframe->datasource()->depending_on_thisfields();
  list<hk_string>* masterfields=p_slavedsframe->datasource()->depending_on_masterfields();
 list<hk_string>::iterator slaveit=slavefields->begin();
@@ -116,18 +154,42 @@ while (slaveit!=slavefields->end())
 }
 
 
+void hk_kderelationdialog::set_existing_refintegrityfields(void)
+{
+list <referentialclass>* rl= p_slavedsframe->datasource()->referenceslist();
+list <referentialclass>::iterator rit=rl->begin();
+ while (rit!=rl->end())
+ {
+     if ((*rit).p_masterdatasource==p_masterdsframe->datasource()->name())
+     {
+       list<dependingclass>::iterator it=(*rit).p_fields.begin();
+       while (it!=(*rit).p_fields.end())
+       {
+	((QComboTableItem*)(grid->item(grid->numRows()-1,0)))->setCurrentItem(textposition(&p_mastercollist,(*it).masterfield));
+	((QComboTableItem*)(grid->item(grid->numRows()-1,1)))->setCurrentItem(textposition(&p_slavecollist,(*it).dependingfield));
 
+        ++it;
+        add_row();
+
+       }
+       onupdatefield->setCurrentItem(((*rit).p_updatecascade?1:0));
+       ondeletefield->setCurrentItem(((*rit).p_deletecascade?1:0));
+       return;
+      }
+   ++rit;
+ }
+}
 
 int hk_kderelationdialog::textposition(QStringList* thelist,const hk_string& txt )
 {
-return thelist->findIndex(QString::fromLocal8Bit(txt.c_str()));
+return thelist->findIndex(QString::fromUtf8(l2u(txt).c_str()));
 }
 
 
 
 int hk_kderelationdialog::masterindex(const QString& string)
 {
-return textposition(&p_mastercollist,string.local8Bit().data());
+return textposition(&p_mastercollist,u2l(string.utf8().data()));
 }
 
 
@@ -135,7 +197,7 @@ return textposition(&p_mastercollist,string.local8Bit().data());
 
 int hk_kderelationdialog::slaveindex(const QString& string)
 {
-return textposition(&p_slavecollist,string.local8Bit().data());
+return textposition(&p_slavecollist,u2l(string.utf8().data()));
 }
 
 
@@ -143,20 +205,31 @@ return textposition(&p_slavecollist,string.local8Bit().data());
 
 void hk_kderelationdialog::ok_button_clicked(void)
 {
- 
+  if(p_slavedsframe->designer()->presentation()->presentationtype()==hk_presentation::referentialintegrity)
+    set_referentialintegrity();
+  else
+    set_relation();
+
+accept();
+KConfig* c=kapp->config();
+  c->setGroup("Relationdialog");
+  c->writeEntry("Geometry",geometry());
+  c->writeEntry("ColwidthLeft",grid->columnWidth(0));
+  c->writeEntry("ColwidthRight",grid->columnWidth(1));
+
+}
+
+
+void hk_kderelationdialog::set_relation(void)
+{
   if (p_slavedsframe->datasource()&&p_slavedsframe->datasource()->depending_on())
-    {  
+    {
        hk_kdedbrelation* r=p_designer->get_relation(p_slavedsframe->datasource()->depending_on(),p_slavedsframe->datasource());
        if (r && r!=p_relation) p_designer->delete_relation(r);
-    
+
     }
 
 
-
-
-
-
-
 p_slavedsframe->datasource()->clear_depending_fields();
  p_slavedsframe->datasource()->set_depending_on_presentationdatasource(
  		p_masterdsframe->datasource()->presentationnumber(),
@@ -166,23 +239,51 @@ p_slavedsframe->datasource()->clear_depending_fields();
 
 for (int row=0;row<grid->numRows()-1;++row)
   {
-    hk_string mastertxt=grid->item(row,0)->text().local8Bit().data();
-    hk_string slavetxt=grid->item(row,1)->text().local8Bit().data();
+    hk_string mastertxt=u2l(grid->item(row,0)->text().utf8().data());
+    hk_string slavetxt=u2l(grid->item(row,1)->text().utf8().data());
     if (mastertxt.size()>0 && slavetxt.size()>0)
         p_slavedsframe->datasource()->add_depending_fields(slavetxt,mastertxt,true);
   }
 
-accept();
 }
 
+void hk_kderelationdialog::set_referentialintegrity(void)
+{
+      if (p_relation && p_relation->referentialname().size()>0)
+      {
+        if (!p_slavedsframe->datasource()->drop_reference( p_relation->referentialname()))
+        {
+         hk_class::show_warningmessage(hk_class::hk_translate("Error: could not delete old reference"));
+         return;
+        }
+      }
+      referentialclass ref;
+      ref.p_masterdatasource=p_masterdsframe->datasource()->name();
+      //ref.p_name=trim(ref_is_on->asstring());
+      for (int row=0;row<grid->numRows()-1;++row)
+      {
+        dependingclass dep;
+        dep.masterfield=u2l(grid->item(row,0)->text().utf8().data());
+        dep.dependingfield=u2l(grid->item(row,1)->text().utf8().data());
+        if (dep.masterfield.size()>0 && dep.dependingfield.size()>0)
+        ref.p_fields.push_back(dep);
+      }
+      ref.p_updatecascade=(onupdatefield->currentItem()==1);
+      ref.p_deletecascade=(ondeletefield->currentItem()==1);
+      p_slavedsframe->datasource()->add_reference(ref);
+   if (p_relation)
+   {
+   p_relation->set_referentialintegrity(ref,p_masterdsframe,p_slavedsframe);
 
+   }
+}
 
 
 void hk_kderelationdialog::slot_data_changed(int row, int /*col*/)
 {
-  if (row==grid->numRows()-1 
+  if (row==grid->numRows()-1
   	&& grid->item(row,0)
-	&&  !grid->item(row,0)->text().isEmpty() 
+	&&  !grid->item(row,0)->text().isEmpty()
 	&& !grid->item(row,1)->text().isEmpty())
   	{
 		add_row();
@@ -204,7 +305,7 @@ void hk_kderelationdialog::keyPressEvent(QKeyEvent* /*event*/)
 
 
 
-}	
+}
 
 
 
@@ -228,7 +329,7 @@ int c=0;//cerr <<"a new ="<<endrow-beginrow+1<<endl;
 else
 {
 //cerr <<"delete_row "<<grid->currentRow()<<endl;
-if (grid->currentRow()>-1 &&grid->currentRow()<grid->numRows()-1) 
+if (grid->currentRow()>-1 &&grid->currentRow()<grid->numRows()-1)
 	grid->removeRow(grid->currentRow());
 }
 
@@ -242,7 +343,7 @@ bool hk_kderelationdialog::eventFilter(QObject* object,QEvent* e)
  QKeyEvent* event=dynamic_cast<QKeyEvent*>(e);
  if (event  && event->key()==Qt::Key_Delete && event->type()==QEvent::KeyRelease)
    {
-       delete_rows(); 
+       delete_rows();
        //event->accept();
        return true;
    }
