@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -27,7 +27,8 @@ public:
     ~hk_kderelationdialog();
     int masterindex(const QString&);
     int slaveindex(const QString&);
-
+    void set_relation(void);
+    void set_referentialintegrity(void);
 public slots:
     virtual void ok_button_clicked();
     virtual void slot_data_changed(int,int);
@@ -36,12 +37,13 @@ public slots:
 protected:
 void keyPressEvent(QKeyEvent * );
 bool eventFilter(QObject* object,QEvent* event);
-  
-  
-  
+
+
+
 private:
   void set_stringlist(QStringList* strlist,list<hk_string>*);
   void set_existing_fields(void);
+  void set_existing_refintegrityfields(void);
   int    textposition(QStringList* ,const hk_string&  );
 void delete_rows(void);
 hk_kdedatasourceframe* p_masterdsframe;
