@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.21 $
+//$Revision: 1.22 $
 
 #include "hk_kdereportdata.h"
 #include "hk_kdereportsection.h"
@@ -50,9 +50,9 @@ void hk_kdereportdata::paintEvent(QPaintEvent* e)
     p.setPen( colorGroup().background() );
     p.setPen( white );
     p.drawRect(0,0,QWidget::width(),QWidget::height());
-    QString d=QString::fromLocal8Bit ((columnname().size()>0?columnname().c_str():"-"));
+    QString d=QString::fromUtf8 ((columnname().size()>0?l2u(columnname()).c_str():"-"));
     d+=" / ";
-    d+=QString::fromLocal8Bit ((data().size()>0?data().c_str():"-"));
+    d+=QString::fromUtf8 ((data().size()>0?l2u(data()).c_str():"-"));
     p.setPen(colorGroup().foreground());
     p.drawText(3,12,d);
     if (leftline()) p.drawLine(0,0,0,QWidget::height());
