@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.13 $
+//$Revision: 1.18 $
 
 #include "hk_kdereportpartwidget.h"
 #include "hk_kdetoolbar.h"
@@ -64,13 +64,13 @@ hk_kdepreviewwindow(QWidget * parent , const char * name = 0, WFlags f = WDestru
        p_previewpart=(KParts::ReadOnlyPart*) p_factory->create(this,"kgvpart","KParts::ReadOnlyPart");
        if (p_previewpart) l->addWidget(p_previewpart->widget());
        add_actions();
-     }  
+     }
 virtual ~hk_kdepreviewwindow()
         {
 	  delete p_previewpart;
 	}
 void add_actions(void)
-  {  
+  {
    if(!p_previewpart) return;
    QDomNodeList l= p_previewpart->domDocument().elementsByTagName("ToolBar");
    if (l.length()==0) return;
@@ -79,7 +79,7 @@ void add_actions(void)
    {
      QDomElement n=a.item(i).toElement();
      KAction* newact=p_previewpart->action(n);
-     if (newact) 
+     if (newact)
        {
          newact->plug(p_toolbar);
        }
@@ -120,7 +120,7 @@ class hk_kdereportpartwidgetscrollview :public QScrollView
         }
 	~hk_kdereportpartwidgetscrollview()
 	{
-	
+
 	}
         void set_report(hk_kdesimplereport* r){p_report=r;}
     protected:
@@ -185,11 +185,11 @@ hk_kdereportpartwidget::hk_kdereportpartwidget (hk_kdereportpart* reportpart,QWi
     p_bulkaction->insert(p_bulkforegroundcolouraction);
     p_bulkaction->insert(p_bulkbackgroundcolouraction);
 
-    
-    
-    
-    
-    
+
+
+
+
+
     QPixmap p;
     KDockWidget* maindock=createDockWidget("",p,0,"");
     maindock->setEnableDocking(KDockWidget::DockNone);
@@ -198,8 +198,8 @@ hk_kdereportpartwidget::hk_kdereportpartwidget (hk_kdereportpart* reportpart,QWi
     setMainDockWidget(maindock);
     p_stack= new QWidgetStack(maindock);
     maindock->setWidget(p_stack);
-    
-    
+
+
     p_scrollview = new hk_kdereportpartwidgetscrollview(p_stack);
     p_stack->addWidget(p_scrollview,0);
     p_report = new hk_kdesimplereport( p_scrollview->viewport() );
@@ -208,8 +208,8 @@ hk_kdereportpartwidget::hk_kdereportpartwidget (hk_kdereportpart* reportpart,QWi
     set_caption();
     p_reportpropertyaction=new KAction(i18n("&Propertyeditor"),loader->loadIcon("propertyeditor",KIcon::User),0,p_report,SLOT(show_property()),p_reportpart->actionCollection(),"viewproperty");
 
-    
-    
+
+
     p_deleteaction=new KAction(i18n("&Delete"),Key_Delete,p_report,SLOT(delete_widgets()),p_reportpart->actionCollection(),"delete");
     p_copyaction= new KAction(i18n("&Copy"),CTRL+Key_C,p_report,SLOT(copy_widgets()),p_reportpart->actionCollection(),"copy");
     p_pasteaction=new KAction(i18n("&Paste"),CTRL+Key_V,p_report,SLOT(paste_widgets()),p_reportpart->actionCollection(),"paste");
@@ -237,17 +237,17 @@ hk_kdereportpartwidget::hk_kdereportpartwidget (hk_kdereportpart* reportpart,QWi
     p_alignaction->insert(p_alignrightaction);
     p_alignaction->insert(p_aligntopaction);
     p_alignaction->insert(p_alignbottomaction);
-    
-    
+
+
      connect(p_report,SIGNAL(signal_has_changed()),this,SLOT(slot_has_changed()));
-   
+
    connect (QApplication::clipboard(), SIGNAL(dataChanged()),this, SLOT(clipboard_changed()));
     connect( p_report, SIGNAL( signal_focuswidget_changed() ), this, SLOT( slot_focuswidget_changed() ) );
 
-    
-    
-    
-    
+
+
+
+
     //setCentralWidget(p_scrollview);
     set_reporttoolbar();
     p_scrollview->addChild(p_report);
@@ -263,6 +263,8 @@ hk_kdereportpartwidget::~hk_kdereportpartwidget(void)
 #ifdef HK_DEBUG
     hkdebug("hk_kdereportpartwidget::~hk_kdereportpartwidget");
 #endif
+     cerr <<"report callerform:"<<caller_form()<<endl;
+     emit signal_raise_form(caller_form());
 
 }
 
@@ -342,17 +344,17 @@ void hk_kdereportpartwidget::closeEvent ( QCloseEvent* e)
 #ifdef HK_DEBUG
     hkdebug("hk_kdereportpartwidget::closeEvent");
 #endif
-    
+
     if (p_report->while_executing())
     {
       e->ignore();
       return;
-    }  
+    }
     if (p_report->has_changed())
     {
         p_report->save_report();
     }
-    
+
     if(!p_whilepreview)
     {
         //setCentralWidget(NULL);
@@ -380,6 +382,14 @@ void hk_kdereportpartwidget::set_nodesignmode(bool d)
 
 }
 
+hk_presentation::enum_mode  hk_kdereportpartwidget::mode(void)
+{
+#ifdef HK_DEBUG
+    hkdebug("hk_kdereportpartwidget::mode");
+#endif
+
+    return p_report->mode();
+}
 
 void    hk_kdereportpartwidget::set_mode(hk_presentation::enum_mode s)
 {
@@ -415,28 +425,28 @@ void    hk_kdereportpartwidget::set_mode(hk_presentation::enum_mode s)
 	    }
             p_previewwindow=new hk_kdepreviewwindow(this);
             if (p_previewwindow!=NULL)
-            {      
+            {
 
                 p_whilepreview=true;
                 p_stack->addWidget(p_previewwindow,1);
 		p_stack->raiseWidget(p_previewwindow);
                 //createGUI(p_previewpart);
                 if (p_previewwindow->p_previewpart)
-		  p_previewwindow->p_previewpart->openURL(QString::fromLocal8Bit(p_report->outputfile().c_str()));
+		  p_previewwindow->p_previewpart->openURL(QString::fromUtf8(l2u(p_report->outputfile()).c_str()));
                 p_previewwindow->show();
                 p_whilepreview=false;
                 if (p_closewindow) close();
                 p_printaction->setEnabled(true);
                 set_caption();
             }
-        
+
         p_reportpart->setXMLFile(locate("data","hk_kdeclasses/hk_kdereportpartview.rc"));
 	p_copyaction->setEnabled(false);
         p_cutaction->setEnabled(false);
         p_pasteaction->setEnabled(false);
         p_deleteaction->setEnabled(false);
 
-	
+
 	}
         else
         {
@@ -446,8 +456,8 @@ void    hk_kdereportpartwidget::set_mode(hk_presentation::enum_mode s)
     }
     else
     {                                             //design mode
-//setCaption(QString::fromLocal8Bit(p_report->hk_presentation::name().c_str()));
-        
+//setCaption(QString::fromUtf8(l2u(p_report->hk_presentation::name()).c_str()));
+
 	p_report->set_mode(s);
 	p_printaction->setEnabled(false);
         //createGUI(NULL);
@@ -513,7 +523,7 @@ void hk_kdereportpartwidget::saveas_report(void)
 {
     hk_string oldname=p_report->hk_presentation::name();
     p_report->set_name("");
-    if (p_report->save_report("",false))
+    if (p_report->save_report("",true))
     {
         set_caption();
     }
@@ -573,9 +583,9 @@ void hk_kdereportpartwidget::select_section(void)
 
 void hk_kdereportpartwidget::set_caption(void)
 {
- 
+
     QString reportname=i18n( "Report - "  );
-    reportname+=QString::fromLocal8Bit (p_report->hk_presentation::name().c_str());
+    reportname+=QString::fromUtf8 (l2u(p_report->hk_presentation::name()).c_str());
 
     setCaption( reportname  );
     KMdiChildView* v=dynamic_cast<KMdiChildView*>(parent());
@@ -615,7 +625,7 @@ void hk_kdereportpartwidget::slot_has_changed()
 
 void hk_kdereportpartwidget::clipboard_changed()
 {
-if (p_pasteaction) 
+if (p_pasteaction)
 p_pasteaction->setEnabled(QApplication::clipboard()->data()&&QApplication::clipboard()->data()->provides("application/x-hk_kdesimplereportcopy"));
 }
 
@@ -630,3 +640,28 @@ void hk_kdereportpartwidget::slot_focuswidget_changed(void)
 
 }
 
+void hk_kdereportpartwidget::show_widget(void)
+{
+  show();
+}
+
+void hk_kdereportpartwidget::hide_widget(void)
+{
+  hide();
+}
+
+void hk_kdereportpartwidget::close_widget(void)
+{
+  close();
+}
+
+void hk_kdereportpartwidget::set_caller_form(const hk_string&f)
+{
+ p_callerform=f;
+}
+
+hk_string hk_kdereportpartwidget::caller_form(void) const
+{
+    return p_callerform;
+}
+
