@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.56 $
+//$Revision: 1.57 $
 #include "hk_kdereportproperty.h"
 #include "hk_kdesimplereport.h"
 #include "hk_kdesubreportdialog.h"
@@ -147,7 +147,7 @@ hk_kdereportproperty::hk_kdereportproperty( hk_kdesimplereport* parent,  const c
     int i=0;
     while (it!=l->end())
     {
-        reporttypefield->insertItem(QString::fromLocal8Bit((*it).c_str()));
+        reporttypefield->insertItem(QString::fromUtf8(l2u((*it)).c_str()));
         if (p_report->reporttype()==(*it)) reporttypefield->setCurrentItem(i);
         it++; i++;
     }
@@ -316,7 +316,7 @@ void hk_kdereportproperty::datasource_selected()
     if (db==NULL) return;
     QString f=datasourcefield->currentText();
     if (f.isEmpty()) f="";
-    hk_datasource* ds= p_report->get_datasource(f.local8Bit().data());
+    hk_datasource* ds= p_report->get_datasource(u2l(f.utf8().data()));
     if (ds==NULL) return;
     list<hk_column*>* v=NULL;
     hk_datasource* tmpds=NULL;
@@ -349,8 +349,8 @@ void hk_kdereportproperty::datasource_selected()
     int i=1;
     while (it!=v->end())
     {
-        columnfield->insertItem(QString::fromLocal8Bit((*it)->name().c_str()));
-        if (QString::fromLocal8Bit((*it)->name().c_str())==currentvalue) columnfield->setCurrentItem(i);
+        columnfield->insertItem(QString::fromUtf8(l2u((*it)->name()).c_str()));
+        if (QString::fromUtf8(l2u((*it)->name()).c_str())==currentvalue) columnfield->setCurrentItem(i);
         it++;i++;
     }
     if (tmpds)
@@ -406,7 +406,7 @@ void hk_kdereportproperty::datasourcebutton_clicked()
     hkdebug("hk_kdereportproperty::datasourcebutton_clicked");
 #endif
     hk_kdeformdatasourcedialog* d = new hk_kdeformdatasourcedialog(p_report,this,0,true);
-    hk_datasource* ds=p_report->get_datasource(datasourcefield->currentText().local8Bit().data());
+    hk_datasource* ds=p_report->get_datasource(u2l(datasourcefield->currentText().utf8().data()));
     d->set_datasource(ds);
     d->set_displaytype(hk_kdeformdatasourcedialog::d_report);
     if (ds)
@@ -698,7 +698,7 @@ void hk_kdereportproperty::set_visible(void)
     }
 
     identifierfield->blockSignals(true);
-    identifierfield->setText(QString::fromLocal8Bit (p_visible->identifier().c_str()));
+    identifierfield->setText(QString::fromUtf8 (l2u(p_visible->identifier()).c_str()));
     identifierfield->blockSignals(false);
     set_sizevisible();
     set_fontvisible();
@@ -787,7 +787,7 @@ void hk_kdereportproperty::set_fontvisible(void)
     fontsizefield->blockSignals(false);
 
     fontfield->blockSignals(true);
-    fontfield->setEditText(QString::fromLocal8Bit(f.fontname().c_str()));
+    fontfield->setEditText(QString::fromUtf8(l2u(f.fontname()).c_str()));
     fontfield->blockSignals(false);
     boldfield->blockSignals(true);
     boldfield->setCurrentItem(f.bold()?0:1);
@@ -815,7 +815,7 @@ void hk_kdereportproperty::set_reportdatavisible(void)
     onprintaction->setEnabled(true);
 
     valuefield->blockSignals(true);
-    valuefield->setText(QString::fromLocal8Bit(d->data().c_str()));
+    valuefield->setText(QString::fromUtf8(l2u(d->data()).c_str()));
     valuefield->blockSignals(false);
     alignmentfield->blockSignals(true);
     int a=0;
@@ -863,7 +863,7 @@ void hk_kdereportproperty::set_reportdatavisible(void)
     diagonallurofield->blockSignals(false);
 
     columnfield->blockSignals(true);
-    columnfield->setEditText(QString::fromLocal8Bit(d->columnname().c_str()));
+    columnfield->setEditText(QString::fromUtf8(l2u(d->columnname()).c_str()));
     columnfield->blockSignals(false);
 
     runningcountfield->blockSignals(true);
@@ -892,10 +892,10 @@ void hk_kdereportproperty::set_reportsectionvisible(void)
     wordbreakfield->blockSignals(true);
     wordbreakfield->setCurrentItem(s->new_page_after_section()?0:1);
     wordbreakfield->blockSignals(false);
-    QString n=QString::fromLocal8Bit(s->subreportname().c_str());
+    QString n=QString::fromUtf8(l2u(s->subreportname()).c_str());
     subreportbutton->setText(s->subreportname().size()>0?n:i18n("None"));
     columnfield->blockSignals(true);
-    columnfield->setEditText(QString::fromLocal8Bit(s->columnname().c_str()));
+    columnfield->setEditText(QString::fromUtf8(l2u(s->columnname()).c_str()));
     columnfield->blockSignals(false);
     sortingfield->blockSignals(true);
     if (s->reportsectionpair())
@@ -924,7 +924,7 @@ void hk_kdereportproperty::set_reportvisible(void)
     reporttypefield->clear();
     while (it!=l->end())
     {
-        reporttypefield->insertItem(QString::fromLocal8Bit((*it).c_str()));
+        reporttypefield->insertItem(QString::fromUtf8(l2u((*it)).c_str()));
         if (p_report->reporttype()==(*it)) reporttypefield->setCurrentItem(i);
         it++; i++;
     }
@@ -999,7 +999,7 @@ void hk_kdereportproperty::set_datasourcelist(void)
     int item=1;
     while (it!=dslist->end())
     {
-        QString name= QString::fromLocal8Bit(p_report->unique_datasourcename((*it)->presentationnumber()).c_str());
+        QString name= QString::fromUtf8(l2u(p_report->unique_datasourcename((*it)->presentationnumber())).c_str());
         datasourcefield->insertItem(name);
         hk_dsvisible* ds = dynamic_cast <hk_dsvisible*>(p_visible);
         if (ds!=NULL)
@@ -1067,8 +1067,8 @@ void hk_kdereportproperty::set_objectfontvisible(void)
     hkdebug("hk_kdereportproperty::set_objectfontvisible");
 #endif
     if (p_visible==NULL)return;
-    hk_string ps =  fontfield->currentText().local8Bit().data();
-    hk_font f(fontfield->currentText().local8Bit().data(),fontsizefield->value());
+    hk_string ps =  u2l(fontfield->currentText().utf8().data());
+    hk_font f(u2l(fontfield->currentText().utf8().data()),fontsizefield->value());
     f.set_bold(boldfield->currentItem()==0);
     f.set_italic(italicfield->currentItem()==0);
     p_visible->set_font(f);
@@ -1132,7 +1132,7 @@ void hk_kdereportproperty::set_objectdsvisible(void)
     if (datasourcefield->currentText()=="") ds->set_presentationdatasource(-1);
     while (it!=dslist->end())
     {
-        QString name= QString::fromLocal8Bit(p_report->unique_datasourcename((*it)->presentationnumber()).c_str());
+        QString name= QString::fromUtf8(l2u(p_report->unique_datasourcename((*it)->presentationnumber())).c_str());
         if (name==datasourcefield->currentText())
         {
             ds->set_presentationdatasource( (*it)->presentationnumber() );
@@ -1198,7 +1198,7 @@ void hk_kdereportproperty::set_objectreportdatavisible(void)
     if (p_visible==NULL) return;
     hk_kdereportdata* rd = dynamic_cast <hk_kdereportdata*>(p_visible);
     if (rd==NULL) return;
-    rd->set_data(valuefield->text().local8Bit().data());
+    rd->set_data(u2l(valuefield->text().utf8().data()));
     int i=alignmentfield->currentItem();
     hk_dsdatavisible::alignmenttype at=hk_dsdatavisible::alignleft;
     switch (i)
@@ -1218,7 +1218,7 @@ void hk_kdereportproperty::set_objectreportdatavisible(void)
     rd->set_bottomline(bottomlinefield->currentItem()==0);
     rd->set_diagonalluro(diagonallurofield->currentItem()==0);
     rd->set_diagonalloru(diagonallorufield->currentItem()==0);
-    rd->set_columnname(columnfield->currentText().local8Bit().data());
+    rd->set_columnname(u2l(columnfield->currentText().utf8().data()));
     rd->set_runningcount(runningcountfield->currentItem()==0);
     rd->set_numberformat(separatorfield->currentItem()==0,digitfield->value());
 
@@ -1233,7 +1233,7 @@ void hk_kdereportproperty::subreportbutton_clicked()
     hk_kdesubreportdialog* d = new hk_kdesubreportdialog(s,p_report,0,true);
     d->exec();
     delete d;
-    QString n=QString::fromLocal8Bit(s->subreportname().c_str());
+    QString n=QString::fromUtf8(l2u(s->subreportname()).c_str());
     subreportbutton->setText(s->subreportname().size()>0?n:i18n("None"));
 
 }
@@ -1275,7 +1275,7 @@ void hk_kdereportproperty::set_bordervisible(void)
 void hk_kdereportproperty::identifier_changed(void)
 {
 
-hk_string t=identifierfield->text().local8Bit().data();
+hk_string t=u2l(identifierfield->text().utf8().data());
 if (p_visible->identifier()!=t) p_visible->set_identifier(t);
 
 
