@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.108 $
+//$Revision: 1.125 $
 #include "hk_kdesimpleform.h"
 #include "hk_kdeform.h"
 #include "hk_kdeformpartwidget.h"
@@ -25,8 +25,10 @@
 #include "hk_kdeproperty.h"
 #include "hk_kdelabel.h"
 #include "hk_kdesubform.h"
+#include "hk_kdeimage.h"
 #include "hk_kdegridpart.h"
 #include "hk_kdedbdesigner.h"
+#include "hk_kdedate.h"
 #include "../hk_kdeformpart/hk_kdeformpart.h"
 
 #include "hk_visible.h"
@@ -42,6 +44,7 @@
 #include <qlayout.h>
 #include <qcolor.h>
 #include <qtooltip.h>
+#include <qdesktopwidget.h>
 #include <kparts/partmanager.h>
 #include <klocale.h>
 #include <kaction.h>
@@ -55,11 +58,6 @@
 #include <kiconloader.h>
 #include <kparts/genericfactory.h>
 
-#ifdef HAVE_SSTREAM
-#include <sstream>
-#else
-#include <strstream.h>
-#endif
 
 
 class hk_kdesimpleformprivate
@@ -69,9 +67,13 @@ hk_kdesimpleformprivate()
    {
      while_modechange=false;
      in_loop=false;
+     p_already_selected_widget_clicked=false;
      p_dbdesigneraction=NULL;
      p_designer=NULL;
      p_propertydock=NULL;
+     p_with_label=false;
+     p_moverect.setRect(0,0,0,0);
+     
    }
 
  ~hk_kdesimpleformprivate()
@@ -81,9 +83,12 @@ hk_kdesimpleformprivate()
 
 bool while_modechange;
 bool in_loop;
+bool p_with_label;
 hk_kdedbdesignerwindow* p_designer;
 KAction * p_dbdesigneraction;
 KDockWidget* p_propertydock;
+QRect p_moverect;
+bool p_already_selected_widget_clicked;
 };
 
 
@@ -175,10 +180,10 @@ hk_dsgrid*  hk_kdesimpleform::widget_specific_new_grid(void)
    if (!p_part)
     {
      show_warningmessage(hk_translate("Fatal error! Grid part could not be loaded!\nThis is a installation error. Check your installation!\
- Did you install knoda into the correct directory? Program will exit now...")); 
+ Did you install knoda into the correct directory? Program will exit now..."));
      exit(1);
-    } 
- 
+    }
+
     p_partsmanager->addPart(p_part);
     hk_kdegrid* g=p_part?(hk_kdegrid*)p_part->widget():new hk_kdegrid(this,0,0,this);
     if (g==NULL) return NULL;
@@ -311,6 +316,35 @@ hk_label* hk_kdesimpleform::widget_specific_new_label(void)
     return s;
 }
 
+hk_dsdate*       hk_kdesimpleform::widget_specific_new_date(void)
+{
+    hk_kdedate* l=new hk_kdedate(this,this);
+    l->show();
+#ifdef HK_DEBUG
+    l->hkclassname("date");
+#endif
+//	set_focus(l);
+    return l;
+}
+
+hk_dsimage*      hk_kdesimpleform::widget_specific_new_image(void)
+{
+hk_kdeimage* i=new hk_kdeimage(this,this);
+cerr <<"new_image"<<endl;
+#ifdef HK_DEBUG
+    i->show();
+    i->hkclassname("image");
+#endif
+return i;
+}
+
+
+hk_tabvisible*   hk_kdesimpleform::widget_specific_new_tabvisible(void)
+{
+return NULL;
+}
+
+
 
 void    hk_kdesimpleform::widget_specific_fieldresize(hk_visible* v)
 {
@@ -343,9 +377,9 @@ void hk_kdesimpleform::before_source_vanishes(void)
     else
     if (p_formpartwidget)p_formpartwidget->save_form_when_changed();
     hk_form::before_source_vanishes();
-    
+
    QWidget* p=parentWidget();
- 
+
     if (p_autoclose &&!p_sourcevanishflag)
     {
         if (p!=NULL)
@@ -362,13 +396,13 @@ if (doemit)
       {hk_kdeform* k=p_kdeform;
        set_kdeform(NULL);
        k->close();
-      } 
+      }
     else
     if (p_formpartwidget)
       {hk_kdeformpartwidget* k=p_formpartwidget;
        set_formpartwidget(NULL);
        k->close();
-      } 
+      }
     else p->close();
    close();
 }
@@ -383,7 +417,7 @@ void hk_kdesimpleform::database_has_vanished(void)
     bool doemit=false;
     hk_form::database_has_vanished();
    QWidget* p=parentWidget();
-    
+
     if (p_autoclose&&!p_sourcevanishflag)
     {
         if (parentWidget()!=NULL)
@@ -399,13 +433,13 @@ if (doemit)
       {hk_kdeform* k=p_kdeform;
        set_kdeform(NULL);
        k->close();
-      } 
-    else 
+      }
+    else
         if (p_formpartwidget)
       {hk_kdeformpartwidget* k=p_formpartwidget;
        set_formpartwidget(NULL);
        k->close();
-      } 
+      }
     else p->close();
    close();
 }
@@ -428,7 +462,7 @@ void    hk_kdesimpleform::mousePressEvent(QMouseEvent* m)
                 else
                 {
                     clearfocus();
-                    if (p_property!=NULL) p_property->set_object(this);
+                       set_currentobject(this);
                 }
                 break;
             }
@@ -472,7 +506,7 @@ void hk_kdesimpleform::set_field2create(enum_visibletype v)
 }
 
 
-void hk_kdesimpleform::create_field(const QPoint& position)
+hk_visible* hk_kdesimpleform::create_field(const QPoint& position)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_kdesimpleform::create_field");
@@ -484,6 +518,15 @@ void hk_kdesimpleform::create_field(const QPoint& position)
 	if (snap2gridy()>0&&point.y()%snap2gridy()>0)
 		point.setY((point.y()/snap2gridy())*snap2gridy());
 
+       hk_label* l=NULL;
+      if (create_with_label()&&(p_field2create != textlabel  &&p_field2create !=boolean ))
+      {
+       enum_visibletype t= p_field2create;
+       p_field2create=textlabel;
+	l=dynamic_cast<hk_label*>(create_field(point));
+       p_field2create=t;
+       point.setX(point.x()+130);
+      }
     switch (p_field2create)
     {
         case lineedit : newfield = new_lineedit();
@@ -504,6 +547,12 @@ void hk_kdesimpleform::create_field(const QPoint& position)
         break;
         case subform : newfield = new_subform();
         break;
+        case image : newfield = new_image();
+        break;
+/*        case tabvisible : newfield = new_tabvisible();
+        break;*/
+        case date : newfield = new_date();
+        break;
         default:;
 
     }
@@ -525,6 +574,7 @@ void hk_kdesimpleform::create_field(const QPoint& position)
 	}
         set_focus(dynamic_cast <QWidget*>(newfield),false);
     }
+    else cerr <<"hk_kdesimpleform newfield=NULL!"<<endl;
 #ifdef HK_DEBUG
     hkdebug("hk_kdesimpleform::create_field focus setzen");
 #endif
@@ -532,6 +582,11 @@ void hk_kdesimpleform::create_field(const QPoint& position)
     p_createflag=true;
     emit field_created();
     p_field2create=other;
+    if (create_with_label()&& newfield && l)
+       {
+       newfield->set_buddylabel(l->presentationnumber());
+       }
+    return newfield;
 }
 
 
@@ -610,7 +665,7 @@ bool hk_kdesimpleform::formeventFilter(QObject* object,QEvent* event)
         }
     }
 
-    
+
     if (dynamic_cast <hk_kderowselector*>(widget)!=NULL)
     {
         if (dynamic_cast <hk_kdegrid*>(widget->parentWidget())!=NULL)
@@ -631,6 +686,13 @@ bool hk_kdesimpleform::formeventFilter(QObject* object,QEvent* event)
             keyReleaseEvent((QKeyEvent*)event);
             break;
         };
+        case QEvent::MouseButtonRelease :
+        {
+         if (p_private->p_already_selected_widget_clicked)
+          set_focus(widget,false);
+          p_private->p_already_selected_widget_clicked=false;
+          break;
+        };
         case QEvent::MouseButtonPress    :
         {
 
@@ -648,8 +710,9 @@ bool hk_kdesimpleform::formeventFilter(QObject* object,QEvent* event)
                                                   // i.e. a menu
                 if ( dynamic_cast <QPopupMenu*>(object))
                     return QWidget::eventFilter(object,event);
-
-                set_focus(widget,((QMouseEvent*)event)->state() &ControlButton);
+		p_private->p_already_selected_widget_clicked=has_already_focus(widget);
+                if (!p_private->p_already_selected_widget_clicked)
+                    set_focus(widget,((QMouseEvent*)event)->state() &ControlButton);
                 if (widget!=NULL)p_focus->show();
                 p_originalposition=mapFromGlobal(((QMouseEvent*)event)->globalPos());
 		if (snap2gridx()>0 &&(!(((QMouseEvent*)event)->state()&Qt::ControlButton)))
@@ -670,35 +733,19 @@ bool hk_kdesimpleform::formeventFilter(QObject* object,QEvent* event)
         {
             if (
                 (((QMouseEvent*)event)->state() & LeftButton ) == LeftButton&&
-                widget==p_focus->widget()
+                widget!=this
                 )
             {
 //move object
+                 p_private->p_already_selected_widget_clicked=false;
                 QPoint newpos=mapFromGlobal(((QMouseEvent*)event)->globalPos());
 		if (snap2gridx()>0&&!(((QMouseEvent*)event)->state() & ControlButton))
 			newpos.setX((newpos.x()/snap2gridx())*snap2gridx());
 		if (snap2gridy()>0&&!(((QMouseEvent*)event)->state() & ControlButton))
 			newpos.setY((newpos.y()/snap2gridy())*snap2gridy());
 		QPoint difference=p_originalposition-newpos;
-		QPoint buf=p_originalposition;
+                move_widgets(difference.x(),difference.y());
                 p_originalposition=newpos;
-                if ( widget->x()-difference.x()<0)
-		    {
-		      difference.setX(widget->x());
-		      p_originalposition.setX(buf.x());
-		    }
-                if ( widget->y()-difference.y()<0)
-		    {
-		     difference.setY(widget->y());
-		      p_originalposition.setY(buf.y());
-		    }
-                if ( widget->x()+widget->width()-difference.x()>(signed)designwidth())
-                    difference.setX(-(designwidth()-widget->x()-widget->width()));
-                if ( widget->y()+widget->height()-difference.y()>(signed)designheight())
-                    difference.setY(-(designheight()-widget->y()-widget->height()));
-                widget->move(widget->x()-difference.x(),widget->y()-difference.y());
-                p_focus->set_positions();
-                p_property->focus_resized();
             }
             break;
         };
@@ -713,6 +760,105 @@ bool hk_kdesimpleform::formeventFilter(QObject* object,QEvent* event)
 }
 
 
+
+void hk_kdesimpleform::move_widgets(int xdiff,int ydiff)
+{
+
+//move object
+  QWidget* wid=p_focus->widget();
+  if (!wid) return;
+  QPoint buf=p_originalposition;
+  hk_visible* v=dynamic_cast<hk_visible*>(wid);
+  if (p_multiplefocus.size()>0)
+  {
+  if (v) v->set_movebuddylabel(false);
+      list<hk_kdeformfocus*>::iterator it=p_multiplefocus.begin();
+      while (it!=p_multiplefocus.end())
+      {
+        hk_kdeformfocus* f=(*it);
+        v=dynamic_cast<hk_visible*>(f->widget());
+        if (v) v->set_movebuddylabel(false);
+        it++;
+       }
+  }
+
+  
+  p_private->p_moverect.setX(wid->x());
+  p_private->p_moverect.setY(wid->y());
+  p_private->p_moverect.setWidth(wid->width());
+  p_private->p_moverect.setHeight(wid->height());
+  if (p_multiplefocus.size()>0)
+  {
+      list<hk_kdeformfocus*>::iterator it=p_multiplefocus.begin();
+      while (it!=p_multiplefocus.end())
+      {
+        hk_kdeformfocus* f=(*it);
+        QWidget* w=f->widget();
+        if (w)
+        {
+          if (w->x()<p_private->p_moverect.x())
+             p_private->p_moverect.setX(w->x());
+          if (w->y()<p_private->p_moverect.y())
+             p_private->p_moverect.setY(w->y());
+          
+          if (w->x()+w->width()>p_private->p_moverect.x()+p_private->p_moverect.width())
+             p_private->p_moverect.setWidth(w->x()+w->width()-p_private->p_moverect.x());
+          if (w->y()+w->height()>p_private->p_moverect.y()+p_private->p_moverect.height())
+             p_private->p_moverect.setHeight(w->y()+w->height()-p_private->p_moverect.y());
+        }
+        it++;
+       }
+  }
+		QPoint difference(xdiff,ydiff);
+  if ( p_private->p_moverect.x()-difference.x()<0)
+		    {
+		      difference.setX(p_private->p_moverect.x());
+		      p_originalposition.setX(buf.x());
+		    }
+  if ( p_private->p_moverect.y()-difference.y()<0)
+		    {
+		     difference.setY(p_private->p_moverect.y());
+		      p_originalposition.setY(buf.y());
+		    }
+  if ( p_private->p_moverect.x()+p_private->p_moverect.width()-difference.x()>(signed)designwidth())
+      difference.setX(-(designwidth()-p_private->p_moverect.x()-p_private->p_moverect.width()));
+  if ( p_private->p_moverect.y()+p_private->p_moverect.height()-difference.y()>(signed)designheight())
+      difference.setY(-(designheight()-p_private->p_moverect.y()-p_private->p_moverect.height()));
+  if (p_focus->widget()) p_focus->widget()->move(p_focus->widget()->x()-difference.x(),p_focus->widget()->y()-difference.y());
+  
+      list<hk_kdeformfocus*>::iterator it=p_multiplefocus.begin();
+      while (it!=p_multiplefocus.end())
+      {
+        hk_kdeformfocus* f=(*it);
+        QWidget* w=f->widget();
+        if (w)
+        {
+        w->move(w->x()-difference.x(),w->y()-difference.y());
+        }
+        it++;
+       }
+  p_focus->set_positions();
+  p_property->focus_resized();
+
+
+  v=dynamic_cast<hk_visible*>(wid);
+  if (p_multiplefocus.size()>0)
+  {
+  if (v) v->set_movebuddylabel(true);
+      list<hk_kdeformfocus*>::iterator it=p_multiplefocus.begin();
+      while (it!=p_multiplefocus.end())
+      {
+        hk_kdeformfocus* f=(*it);
+        v=dynamic_cast<hk_visible*>(f->widget());
+        if (v) v->set_movebuddylabel(true);
+        it++;
+       }
+  }
+
+
+}
+
+
 void hk_kdesimpleform::widget_specific_modechanges(enum_mode s)
 {
 #ifdef HK_DEBUG
@@ -729,8 +875,8 @@ void hk_kdesimpleform::widget_specific_modechanges(enum_mode s)
 	if (p_property)
 	{
         if (p_focus->widget()!=NULL)
-            p_property->set_object( dynamic_cast <hk_visible*> (p_focus->widget()));
-        else p_property->set_object(this);
+            set_currentobject( dynamic_cast <hk_visible*> (p_focus->widget()));
+        else set_currentobject(this);
 	}
         while (it!=p_multiplefocus.end())
         {
@@ -751,14 +897,14 @@ void hk_kdesimpleform::widget_specific_modechanges(enum_mode s)
             it++;
         }
         p_focus->hide();
-        if(p_property!=NULL) 
+        if(p_property!=NULL)
 	  {
 	       if (p_private->p_propertydock)
 	       {
                  if (p_private->p_propertydock->mayBeHide())
 		    p_private->p_propertydock->changeHideShowState();
 		 //p_private->p_propertydock->hide();
-	       }	 
+	       }
                else
 	       p_property->hide();
 	  }
@@ -777,7 +923,7 @@ void hk_kdesimpleform::widget_specific_modechanges(enum_mode s)
 	   if (t) t->selectAll();
 	 }
 	 //cerr <<"FOCUS SETZEN"<<w->className()<<endl;
-	} 
+	}
 	else
 	cerr <<" NO FOCUS"<<endl;
         }
@@ -824,12 +970,12 @@ void hk_kdesimpleform::keyPressEvent ( QKeyEvent * event )
               {
                unsigned int diff=(event->state()&ControlButton?1:snap2gridx());
 	       if (sizetype()==relative) diff =horizontal2relativ(diff);
-               if (widget->x()>=diff) widget->set_x(widget->x()-diff);
+         	move_widgets(diff,0);
               }
 
             }
 	break;
-    
+
     case Key_Right:
 	if (p_focus &&p_focus->widget()&&mode()==designmode)
 	{
@@ -838,7 +984,7 @@ void hk_kdesimpleform::keyPressEvent ( QKeyEvent * event )
 	{
    	unsigned int diff=(event->state()&ControlButton?1:snap2gridx());
 	       if (sizetype()==relative) diff =horizontal2relativ(diff);
-	if (widget->x()+widget->width()+diff<=10000) widget->set_x(widget->x()+diff);
+		move_widgets(-diff,0);
 	}
 
 	}
@@ -852,7 +998,7 @@ void hk_kdesimpleform::keyPressEvent ( QKeyEvent * event )
 	{
 	unsigned int diff=(event->state()&ControlButton?1:snap2gridy());
 	       if (sizetype()==relative) diff =vertical2relativ(diff);
-	if (widget->y()>=diff) widget->set_y(widget->y()-diff);
+	move_widgets(0,diff);
 	}
 
 	}
@@ -866,12 +1012,12 @@ void hk_kdesimpleform::keyPressEvent ( QKeyEvent * event )
 	{
 	unsigned int diff=(event->state()&ControlButton?1:snap2gridy());
 	       if (sizetype()==relative) diff =vertical2relativ(diff);
-	if (widget->y()+widget->height()+diff<=10000) widget->set_y(widget->y()+diff);
+	move_widgets(0,-diff);
 	}
 
 	}
 	break;
-        
+
 	default  :     ;
     }
     QWidget::keyPressEvent(event);
@@ -899,7 +1045,7 @@ void hk_kdesimpleform::clearfocus(void)
     //p_controlbutton=false;
     clearmultiplefocus();
     enable_actions();
-
+	emit signal_focuswidget_changed();
 }
 
 
@@ -912,10 +1058,9 @@ void hk_kdesimpleform::set_focus(QWidget*f, bool p_controlbutton)
     if (f==NULL || f==this)
     {
         clearfocus();
-	emit signal_focuswidget_changed();
         return;
     }
-    
+
         QWidget* widget=dynamic_cast<hk_kdesimpleform*>(f);
 	if (widget)
 	{
@@ -923,7 +1068,7 @@ void hk_kdesimpleform::set_focus(QWidget*f, bool p_controlbutton)
         QWidget* object =widget;
         while (object!=NULL)
         {
-            if ( dynamic_cast <hk_kdesubform*>(object)!=NULL   
+            if ( dynamic_cast <hk_kdesubform*>(object)!=NULL
 	        ||dynamic_cast <hk_kdegrid*>(object)!=NULL
 	       )
             {
@@ -934,25 +1079,15 @@ void hk_kdesimpleform::set_focus(QWidget*f, bool p_controlbutton)
         }
 	if (widget) f=widget;
         }
-    
-    
-    
-    
-    
+
+
+
+
+
     if (p_controlbutton==true)
     {
 
-        if (p_focus->widget()==f )
-        {
-            return;
-        }
-        list<hk_kdeformfocus*>::iterator it=p_multiplefocus.begin();
-        while (it!=p_multiplefocus.end())         //check if widget is already set
-        {
-            hk_kdeformfocus* w=(*it);
-            it++;
-            if (w->widget()==f) return;
-        }
+      if (has_already_focus(f)) return;
 
     }
 
@@ -970,13 +1105,33 @@ void hk_kdesimpleform::set_focus(QWidget*f, bool p_controlbutton)
     if (p_property!=NULL)
     {
         QObject::connect(p_focus,SIGNAL(size_changed()),p_property,SLOT(focus_resized()));
-        p_property->set_object(v);
+        set_currentobject(v);
     }
-    
+
 emit signal_focuswidget_changed();
 }
 
 
+
+bool hk_kdesimpleform::has_already_focus(QWidget* f)
+{
+if (!f) return false;
+        if (p_focus->widget()==f )
+        {
+            return true;
+        }
+        list<hk_kdeformfocus*>::iterator it=p_multiplefocus.begin();
+        while (it!=p_multiplefocus.end())         //check if widget is already set
+        {
+            hk_kdeformfocus* w=(*it);
+            it++;
+            if (w->widget()==f) return true;
+        }
+return false;
+}
+
+
+
 void hk_kdesimpleform::delete_widgets(void)
 {
 #ifdef HK_DEBUG
@@ -1009,8 +1164,8 @@ void hk_kdesimpleform::delete_widgets(void)
     p_focus->set_widget(NULL);
     hk_kdegrid* g=dynamic_cast <hk_kdegrid*>(w);
     remove_visible(dynamic_cast <hk_visible*>(del));
+    set_currentobject(this);
     if (g)delete g->part();else delete w;
-    if (p_property!=NULL) p_property->set_object(this);
     clearfocus();
     set_has_changed();
 }
@@ -1050,12 +1205,28 @@ void hk_kdesimpleform::mousemenu(QMouseEvent* m)
     p_settoall->insertItem(i18n("Foregroundcolour"),20);
     p_settoall->insertItem(i18n("Backgroundcolour"),21);
 
+        QWidget* gridwidget=NULL;
+        QWidget* object =p_focus->widget();
+        while (object!=NULL)
+        {
+            if ( dynamic_cast <hk_kdegrid*>(object)!=NULL  )
+            {
+                gridwidget=object;
+                object=NULL;
+            }
+            else    object=object->parentWidget();
+        }
+
+    
+    
     if (p_focus->widget()!=NULL)
     {
         p_popup->insertItem( i18n( "&Delete" ),13 );
         p_popup->insertSeparator();
         p_popup->insertItem(i18n("Into background"),16);
         p_popup->insertItem(i18n("Into foreground"),17);
+        if (gridwidget)
+        p_popup->insertItem(i18n("Define columns"),18);
         p_popup->insertSeparator();
     }
     p_popup->insertItem( i18n( "Show &property editor" ),14 );
@@ -1150,7 +1321,15 @@ void hk_kdesimpleform::mousemenu(QMouseEvent* m)
             }
             break;
         }
-        case 19 :   set_for_all(bulkfont);break;
+        case 18:    {  
+        		hk_kdegrid* gr=dynamic_cast<hk_kdegrid*>(gridwidget);
+        		if (gr)
+        		   gr->simplegrid()->show_gridcolumndialog();
+        		
+        		
+        	    }
+        		break;
+        case 19:    set_for_all(bulkfont);break;
         case 20:    set_for_all(bulkforeground);break;
         case 21:    set_for_all(bulkbackground);break;
         default:;
@@ -1168,17 +1347,17 @@ void hk_kdesimpleform::show_property(void)
     if (mode()!=hk_presentation::designmode)return;
     bool newproperty=false;
     if (p_property==NULL)
-    {   
-        
+    {
+
          if (p_kdeform||p_formpartwidget)
-	 { 
+	 {
 	   p_property=new hk_kdeproperty(this,0,false);
          if (p_kdeform)
         {
 	 QPixmap p;
 	 p_private->p_propertydock=p_kdeform->createDockWidget("Property editor",p,0L,"");
 	 p_private->p_propertydock->setWidget(p_property);
-	 p_private->p_propertydock->manualDock(p_kdeform->getMainDockWidget(),KDockWidget::DockRight);
+	 p_private->p_propertydock->manualDock(p_kdeform->getMainDockWidget(),KDockWidget::DockRight,67);
 	}
 	else
 	if (p_formpartwidget)
@@ -1187,26 +1366,26 @@ void hk_kdesimpleform::show_property(void)
 	   QVBoxLayout* layout=new QVBoxLayout(p_formpartwidget->p_splitter);
 	   layout->addWidget(p_property);*/
 
-	 
+
 	 QPixmap p;
 	 p_private->p_propertydock=p_formpartwidget->createDockWidget("Property editor",p,0L,"");
 	 p_private->p_propertydock->setWidget(p_property);
-	 p_private->p_propertydock->manualDock(p_formpartwidget->getMainDockWidget(),KDockWidget::DockRight);
+	 p_private->p_propertydock->manualDock(p_formpartwidget->getMainDockWidget(),KDockWidget::DockRight,67);
 	}
 
        newproperty=true;
        }
     }
     if (p_property!=NULL &&!masterform())
-    {   
+    {
      if (p_private->p_propertydock)
         {
 	  //p_private->p_propertydock->makeDockVisible();
 	     if (p_private->p_propertydock->mayBeShow())
 	     p_private->p_propertydock->changeHideShowState();
           //p_private->p_propertydock->show();
-	}  
-     
+	}
+
      else
      p_property->show();
      //qApp->processEvents();
@@ -1436,7 +1615,7 @@ void hk_kdesimpleform::set_actions(KActionCollection* collection)
     delete p_aligntopaction;
     delete p_alignbottomaction;
     delete p_private->p_dbdesigneraction;
-    
+
     p_deleteaction=NULL;
     p_copyaction=NULL;
     p_pasteaction=NULL;
@@ -1456,7 +1635,7 @@ void hk_kdesimpleform::set_actions(KActionCollection* collection)
     p_aligntopaction=NULL;
     p_alignbottomaction=NULL;
     p_private->p_dbdesigneraction=NULL;
-   
+
    }
     //if (p_property) delete p_property;
     //p_property=NULL;
@@ -1487,11 +1666,8 @@ bool hk_kdesimpleform::is_formobject(QWidget* v)
 void hk_kdesimpleform::create_copydata(ostream& stream,QWidget*w)
 {
     hk_string vistag="FORMOBJECT";
-#ifdef HAVE_SSTREAM
-    stringstream tststream;
-#else
-    strstream tststream;
-#endif
+    STRINGSTREAM tststream;
+
     hk_string tststring;
     if (w)
     {
@@ -1515,11 +1691,7 @@ void hk_kdesimpleform::copy_widgets(void)
     if (!p_focus || !p_focus->widget()) return;
     QStoredDrag* p_drag = new QStoredDrag("application/x-hk_kdesimpleformcopy");
     hk_string cpyinfo;
-#ifdef HAVE_SSTREAM
-    stringstream stream;
-#else
-    strstream stream;
-#endif
+STRINGSTREAM stream;
 
     list<hk_kdeformfocus*>::iterator it=p_multiplefocus.begin();
     while (it!=p_multiplefocus.end())
@@ -1607,12 +1779,21 @@ void hk_kdesimpleform::enable_actions(void)
 
 bool    hk_kdesimpleform::set_mode(enum_mode s)
 {
-    if (p_private->while_modechange) return true;
+    if (p_private->while_modechange)
+    {
+      cerr <<"rejected because while_modechange"<<endl;
+     return true;
+    }
     p_private->while_modechange=true;
     bool r=hk_form::set_mode(s);
-
+    if (!r)
+    {  
+     p_private->while_modechange=false;
+     return false;
+     }
    if (s==hk_presentation::viewmode)
     {
+    setEnabled(is_enabled());
         if (p_formpropertyaction)p_formpropertyaction->setEnabled(false);
 	if (p_private->p_designer)
 		{
@@ -1623,6 +1804,8 @@ bool    hk_kdesimpleform::set_mode(enum_mode s)
     }
     else
     {
+    setEnabled(true);
+    if (p_property)p_property->setEnabled(true);
         if(p_formpropertyaction)p_formpropertyaction->setEnabled(true);
 
     }
@@ -1708,7 +1891,7 @@ void    hk_kdesimpleform::widget_specific_backgroundcolour_changed(const hk_colo
         {
             case textlabel :;
             case boolean :   if ((*it)->backgroundcolour()==oldcolour)
-            (*it)->set_backgroundcolour(backgroundcolour());
+            (*it)->set_backgroundcolour(backgroundcolour(),false);
             break;
             default:;
 
@@ -1777,7 +1960,7 @@ void hk_kdesimpleform::script_error(hk_visible* v, hk_interpreter::enum_action a
 
    }
 
-
+p_while_errorhandling=true;
 
     hk_string error=replace_all("%LINENUMBER%",hk_translate("Line %LINENUMBER%: "),longint2string(interpreter()->error_rownumber()))
     				+interpreter()->errormessage();
@@ -1786,8 +1969,8 @@ hk_dsgridcolumn* gc=dynamic_cast<hk_dsgridcolumn*>(v);
 if (gc)
   {
     error=replace_all("%1",hk_translate("Gridcolumn '%1':\n"),gc->columnname())+error;
-  
-  
+
+
   }
 
 hk_dsvisible* dv=dynamic_cast<hk_dsvisible*>(v);
@@ -1799,9 +1982,10 @@ if (dv)
 
 if (!runtime_only())
    {
-      
+
      if (!gc||(gc &&!a==hk_interpreter::a_on_key))
-     { 
+     {
+       if (a==hk_interpreter::a_on_open) p_private->while_modechange=false;
       if (kdeform()) kdeform()->set_mode(hk_presentation::designmode);
         else set_mode(hk_presentation::designmode);
      }
@@ -1812,8 +1996,9 @@ if (!runtime_only())
      }
     if (p_property)
 	    {
-	     set_focus(dynamic_cast<QWidget*>(v),false);
-	     p_property->set_object(v);
+	     if (mode()==hk_form::designmode)
+	       set_focus(dynamic_cast<QWidget*>(v),false);
+	     set_currentobject(v);
 	     switch (a)
 	     {
 		case hk_interpreter::a_click :
@@ -1828,18 +2013,18 @@ if (!runtime_only())
 		case hk_interpreter::a_on_close :
 				p_property->closeactionbutton_clicked(presentation()->interpreter()->error_rownumber()-1,error);
 				break;
-		
+
 		case hk_interpreter::a_on_getfocus :
 				p_property->ongetfocusbutton_clicked(presentation()->interpreter()->error_rownumber()-1,error);
 				break;
 		case hk_interpreter::a_on_loosefocus :
 				p_property->onloosefocusbutton_clicked(presentation()->interpreter()->error_rownumber()-1,error);
 				break;
-		
+
 		case hk_interpreter::a_on_key :
 				p_property->onkeybutton_clicked(presentation()->interpreter()->error_rownumber()-1,error);
 				break;
-		
+
 		case hk_interpreter::a_after_row_change :
 				p_property->afterrowchangebutton_clicked(presentation()->interpreter()->error_rownumber()-1,error);
 				break;
@@ -1864,6 +2049,12 @@ if (!runtime_only())
 		case hk_interpreter::a_after_insert :
 				p_property->afterinsertbutton_clicked(presentation()->interpreter()->error_rownumber()-1,error);
 				break;
+		case hk_interpreter::a_on_select :
+				p_property->onselectbutton_clicked(presentation()->interpreter()->error_rownumber()-1,error);
+				break;
+		case hk_interpreter::a_on_valuechanged :
+				p_property->onvaluechangedbutton_clicked(presentation()->interpreter()->error_rownumber()-1,error);
+				break;
 			default:;
 
 	     }
@@ -1901,7 +2092,7 @@ if (g)
   QWidget* w=dynamic_cast<QWidget*>(e->reason()==QFocusEvent::Backtab
   		?taborder_previous(grid)
 	      	:taborder_next(grid));
-  
+
   if (w) w->setFocus();
   }
 }
@@ -2005,8 +2196,7 @@ void hk_kdesimpleform::dbdesignaction(void)
 
 void hk_kdesimpleform::designer_deleted(void)
 {
- if (p_property)
-     p_property->set_object(p_property->object());
+ set_currentobject(p_property->object());
 p_private->p_designer=NULL;
 }
 
@@ -2047,14 +2237,14 @@ bool hk_kdesimpleform::focusNextPrevChild(bool forward)
   {
   v=dynamic_cast<hk_visible*>(wid);
   hk_kdesimplegrid* grid=dynamic_cast<hk_kdesimplegrid*>(wid);
-  if (grid) 
+  if (grid)
   {
    v=grid->kdegrid();
-  } 
+  }
   else
   wid=wid->parentWidget();
   }
-  if (!v) 
+  if (!v)
    {
      cerr <<"hk_kdesimpleform::focusNextPrevChild focusData kein hk_visible objekt!"<<endl;
      return false;
@@ -2063,8 +2253,8 @@ bool hk_kdesimpleform::focusNextPrevChild(bool forward)
     v=taborder_next(v);
   else
     v=taborder_previous(v);
-  
-  if (!v) 
+
+  if (!v)
    {
      cerr <<"hk_kdesimpleform::focusNextPrevChild taborder_next/previsous gab NULL zurck!"<<endl;
      return false;
@@ -2072,7 +2262,7 @@ bool hk_kdesimpleform::focusNextPrevChild(bool forward)
   QWidget* w=dynamic_cast<QWidget*>(v);
   if (w)
    {
-   w->setFocus(); 
+   w->setFocus();
    }
   return true;
 }
@@ -2093,7 +2283,7 @@ void hk_kdesimpleform::goto_taborder_first()
   QWidget* w=dynamic_cast<QWidget*>(first_tabobject());
   if (w)
    {
-   w->setFocus(); 
+   w->setFocus();
    }
 
 }
@@ -2103,7 +2293,7 @@ void hk_kdesimpleform::goto_taborder_last()
   QWidget* w=dynamic_cast<QWidget*>(last_tabobject());
   if (w)
    {
-   w->setFocus(); 
+   w->setFocus();
    }
 
 
@@ -2121,7 +2311,7 @@ void hk_kdesimpleform::set_focus(hk_visible* v)
 
 void  hk_kdesimpleform::widget_specific_tooltip_changed(void)
 {
- QToolTip::add(this,QString::fromLocal8Bit (tooltip().c_str()));
+ QToolTip::add(this,QString::fromUtf8 (l2u(tooltip()).c_str()));
 }
 
 
@@ -2144,13 +2334,14 @@ void hk_kdesimpleform::focusOutEvent ( QFocusEvent * e)
 
 
 
-bool hk_kdesimpleform::show_asdialog(void)
+bool hk_kdesimpleform::show_asdialog(hk_form* parentform)
 {
     if ( p_private->in_loop ) {
 	qWarning( "hk_kdesimpleform::exec: Recursive call detected." );
 	return false;
     }
-
+    hk_kdesimpleform* pf=dynamic_cast<hk_kdesimpleform*>(parentform);
+    if (pf) reparent(pf,WShowModal| WType_Dialog,pos());
     //bool destructiveClose = testWFlags( WDestructiveClose );
     clearWFlags( WDestructiveClose );
 
@@ -2175,11 +2366,11 @@ void hk_kdesimpleform::done( void )
     bool store_ok=true;
     while(it!=l->end()&& store_ok)
     {
-    if ((*it)->has_changed()) 
+    if ((*it)->has_changed())
       store_ok=(*it)->store_changed_data();
     ++it;
     }
-    
+
     if (store_ok)hide();
     close();
 
@@ -2221,3 +2412,53 @@ bool hk_kdesimpleform::widget_specific_coordinates(uint px,uint py,uint ,uint )
 }
 
 
+void hk_kdesimpleform::show_widget(void)
+{
+  show();
+}
+
+void hk_kdesimpleform::hide_widget(void)
+{
+  hide();
+}
+
+void hk_kdesimpleform::close_widget(void)
+{
+  close();
+}
+
+void hk_kdesimpleform::set_create_with_label(bool w)
+{
+p_private->p_with_label=w;
+}
+
+bool hk_kdesimpleform::create_with_label(void) const
+{
+  return p_private->p_with_label;
+}
+
+void hk_kdesimpleform::set_currentobject(hk_visible* o)
+{
+if (!p_property) return;
+ //p_property->identifier_changed();
+ p_property->set_object(o);
+
+}
+
+
+void hk_kdesimpleform::widget_specific_enabled_changed(void)
+{
+cerr <<"widget_specific_enabled_changed: "<<(is_enabled()?"true":"false")<<endl;
+  //if (mode()==viewmode)setEnabled(is_enabled());
+}
+
+int hk_kdesimpleform::screen_width()
+{
+  return QApplication::desktop()->screenGeometry(this).width();
+}
+
+int hk_kdesimpleform::screen_height()
+{
+  return QApplication::desktop()->screenGeometry(this).height();
+}
+
