@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -28,7 +28,7 @@ class  KActionCollection;
 /**
  *
  *@short KDE Widget to display forms.
- *@version $Revision: 1.46 $
+ *@version $Revision: 1.53 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *hk_kdesimpleform is a KDE widget to display and alter forms.
@@ -67,8 +67,12 @@ virtual void goto_taborder_first();
 virtual void goto_taborder_last();
 virtual void set_focus(hk_visible*);
 	void	hide();
-        
-	
+virtual void show_widget(void);
+virtual void hide_widget(void);
+virtual void close_widget(void);
+        void set_create_with_label(bool);
+        bool create_with_label(void) const;
+
 	signals:
         void mouseclick(const QPoint&);
         void field_created(void);
@@ -105,18 +109,21 @@ virtual        void show_property(void);
 	void dbdesignaction(void);
 	void designer_deleted(void);
         void            load_form(const hk_string& name="");
-virtual bool show_asdialog(void);
+virtual bool show_asdialog(hk_form* parentform=NULL);
+virtual int screen_width();
+virtual int screen_height();
 
     protected:
         virtual void closeEvent ( QCloseEvent* e);
      virtual void focusInEvent ( QFocusEvent * );
-     virtual void focusOutEvent ( QFocusEvent * ); 
+     virtual void focusOutEvent ( QFocusEvent * );
      virtual void    widget_specific_tooltip_changed(void);
         virtual bool focusNextPrevChild(bool forward);
         virtual void set_has_changed(enum_has_changed forcesetting=standard);
         void set_kdeform(hk_kdeform*);
 	void set_formpartwidget(hk_kdeformpartwidget*);
 	void set_actions(KActionCollection*);
+	bool has_already_focus(QWidget*);
         virtual bool    widget_specific_coordinates(uint px,uint py,uint pwidth,uint pheight);
 
         virtual hk_dsgrid*      widget_specific_new_grid(void);
@@ -136,8 +143,12 @@ virtual bool show_asdialog(void);
         virtual void            widget_specific_after_loadform(void);
         virtual void        widget_specific_backgroundcolour_changed(const hk_colour&);
         virtual void        widget_specific_foregroundcolour_changed(const hk_colour&);
+        virtual hk_dsdate*       widget_specific_new_date(void);
+        virtual hk_dsimage*      widget_specific_new_image(void);
+        virtual hk_tabvisible*   widget_specific_new_tabvisible(void);
+	virtual void widget_specific_enabled_changed(void);
         virtual void            database_has_vanished(void);
-        
+
 	virtual void            paintEvent(QPaintEvent*);
         virtual void            mousePressEvent(QMouseEvent*);
         virtual void            mouseReleaseEvent(QMouseEvent*);
@@ -147,18 +158,18 @@ virtual bool show_asdialog(void);
         virtual void            keyReleaseEvent ( QKeyEvent * );
         bool eventFilter(QObject* object,QEvent* event);
         bool formeventFilter(QObject* object,QEvent* event);
-
+        void move_widgets(int xdiff,int ydiff);
     protected slots:
     virtual void done(void);
-    
+
     private:
-    
-    
+
+
     private slots:
 
     private:
         bool is_formobject(QWidget*);
-        void create_field(const QPoint&);
+        hk_visible* create_field(const QPoint&);
         void clearmultiplefocus(void);
         void clearfocus(void);
         void mousemenu(QMouseEvent*);
@@ -196,7 +207,7 @@ virtual bool show_asdialog(void);
         KAction* p_aligntopaction;
         KAction* p_alignbottomaction;
 	hk_kdesimpleformprivate* p_private;
-
+        void set_currentobject(hk_visible* );
 //    KAction* p_resizeaction;
 //    KAction* p_moveaction;
 };
