@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,21 +8,36 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.117 $
+//$Revision: 1.133 $
+
+#include "hk_kdesimplegrid.h"
+#include "hk_kdesimplegrid.moc"
+#include <hk_datetime.h>
+#include <hk_dsboolean.h>
+#include <hk_database.h>
+#include <hk_connection.h>
+#include <hk_dsgridcolumn.h>
+
+#include "hk_kdelineedit.h"
+#include "hk_kdecombobox.h"
+#include "hk_kdesimpleform.h"
+#include "hk_kdegrid.h"
+#include "hk_kdegridcolumndialog.h"
+#include "hk_dsgridcolumn.h"
+#include "hk_kdememo.h"
 
-#include <hk_kdesimplegrid.h>
-#include <hk_kdesimplegrid.moc>
-#include <qdrawutil.h>
 #include <list>
 #include <locale.h>
-#include <hk_datetime.h>
+
 #include <qscrollbar.h>
 #include <qheader.h>
 #include <qkeycode.h>
 #include <qpainter.h>
+#include <qdrawutil.h>
 #include <qcolor.h>
 #include <qpaintdevicemetrics.h>
 #include <qfontmetrics.h>
+#include <qfontinfo.h>
 #include <qapplication.h>
 #include <qclipboard.h>
 #include <qapplication.h>
@@ -30,26 +45,18 @@
 #include <qiconset.h>
 #include <qlistbox.h>
 #include <qtooltip.h>
-#include "hk_kdesimpleform.h"
-#include "hk_kdegrid.h"
-#include "hk_kdegridcolumndialog.h"
-#include "hk_dsgridcolumn.h"
-#include "hk_kdememo.h"
 #include <qlabel.h>
 #include <qlistview.h>
 #include <qstyle.h>
 #include <qdragobject.h>
 #include <qdatetime.h>
-#include "hk_kdelineedit.h"
-#include "hk_kdecombobox.h"
-#include <hk_dsgridcolumn.h>
-#include <hk_dsboolean.h>
-#include <hk_database.h>
+
 #include <kglobal.h>
 #include <kglobalsettings.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kprinter.h>
+#include <kfiledialog.h>
 
 class hk_griddrag: public QTextDrag
 {
@@ -173,7 +180,7 @@ void internalcheckbox::paintEvent(QPaintEvent*)
             if (column()->changed_data_is_nullvalue()) draw=2;
 	    else
             if (column()->changed_data_asbool()) draw=1;
-	    
+
         }
         else
         {
@@ -201,12 +208,12 @@ void internalcheckbox::paintEvent(QPaintEvent*)
         QBrush brush =QBrush(nullcolor);
 	brush.setStyle(QBrush::Dense5Pattern);
         qDrawPlainRect(&painter,left+2,top+2,square-4,square-4,nullcolor,0,&brush);
-	    
-	    
-	    
+
+
+
 	    break;
 	    }
-   default:;	        
+   default:;
    }
 
 
@@ -253,8 +260,8 @@ void internalcheckbox::mousePressEvent(QMouseEvent* )
 	    if (column()->is_notnull())column()->set_asbool(true);
 	    else
 	    column()->set_asnullvalue();
-	   } 
-	}   
+	   }
+	}
         else
 	{
            if (column()->is_nullvalue())column()->set_asbool(true);
@@ -265,9 +272,9 @@ void internalcheckbox::mousePressEvent(QMouseEvent* )
 	    if (column()->is_notnull())column()->set_asbool(true);
 	    else
 	    column()->set_asnullvalue();
-	   } 
+	   }
 //            column()->set_asbool(!column()->asbool());
-	}    
+	}
     }else cerr <<"internalcheckbox::mousePressEvent() ist NULL"<<endl;
     blinkcursorslot();
 }
@@ -332,7 +339,9 @@ hk_dsvisible(form)
     verticalHeader()->setTracking(false);
     setDragEnabled(true);
     QFont f=QWidget::font();
-   cerr <<"fontsize:"<<f.pointSize()<<" rowheight:"<<p_grid->rowheight()<<endl;
+    QFontInfo info(f);
+   //cerr <<"fontsize:"<<f.pointSize()<<" rowheight:"<<p_grid->rowheight()<<"infosize:"<<info.pointSize()<<"pixelsize:"<<info.pixelSize()<<endl;
+   if (p_grid)p_grid->set_rowheight(info.pixelSize()+6,false);
 }
 
 
@@ -353,7 +362,8 @@ QTableItem* hk_kdesimplegrid::item(int ,int ) const
 
 hk_column* hk_kdesimplegrid::actual_column(void)
 {
-    return p_grid->gridcolumn(currentColumn())->column();
+    if (p_grid->gridcolumn(currentColumn()))return p_grid->gridcolumn(currentColumn())->column();
+    else return NULL;
 }
 
 
@@ -387,27 +397,30 @@ clear_vertical_header();
         {
             if(datasource()->columns()!=NULL)
                 setNumCols(p_grid->columnscount());
-		
-	   int newnumrows=datasource()->max_rows()+((datasource()->is_readonly()||p_grid->is_readonly())?0:1);	
+
+	   int newnumrows=datasource()->max_rows()+((datasource()->is_readonly()||p_grid->is_readonly())?0:1);
 	   if (newnumrows>numRows())
 	    {
    		QString r;
     		r.setNum(numRows());
     		verticalHeader()->setLabel(numRows()-1,no_image,r);
-	    
+
 	    }
             setNumRows(newnumrows);
             //paint_vertical_header();
             setEnabled(true);
             for(unsigned int count=0;count<p_grid->columnscount();count++)
             {
+                if (p_grid->gridcolumn(count))
+                {
                 horizontalHeader()->setLabel(horizontalHeader()->mapToLogical(count),
-                    (p_grid->gridcolumn(count)->displayname().length()==0?QString::fromLocal8Bit (p_grid->gridcolumn(count)->displayname().size()==0?
-                    p_grid->gridcolumn(count)->columnname().c_str():
-                p_grid->gridcolumn(count)->displayname().c_str())
-                    :QString::fromLocal8Bit (p_grid->gridcolumn(count)->displayname().c_str())),
+                    (p_grid->gridcolumn(count)->displayname().length()==0?QString::fromUtf8 (p_grid->gridcolumn(count)->displayname().size()==0?
+                    l2u(p_grid->gridcolumn(count)->columnname()).c_str():
+                l2u(p_grid->gridcolumn(count)->displayname()).c_str())
+                    :QString::fromUtf8 (l2u(p_grid->gridcolumn(count)->displayname()).c_str())),
                     p_grid->gridcolumn(count)->columnwidth());
                 setColumnWidth(count,p_grid->gridcolumn(count)->columnwidth());
+                }
                 horizontalHeader()->setMovingEnabled(true);
                 set_statustext();
 
@@ -435,8 +448,8 @@ void hk_kdesimplegrid::resizeData(int )
 
 QString hk_kdesimplegrid::text(int row, int col) const
 {
-    if (p_grid->gridcolumn(col)->column()==NULL) return "";
-    return QString::fromLocal8Bit(p_grid->gridcolumn(col)->column()->asstring_at(row,true).c_str());
+    if (!p_grid->gridcolumn(col) ||p_grid->gridcolumn(col)->column()==NULL) return "";
+    return QString::fromUtf8(l2u(p_grid->gridcolumn(col)->column()->asstring_at(row,true)).c_str());
 }
 
 
@@ -449,7 +462,7 @@ void hk_kdesimplegrid::paintCell(QPainter* p,int row, int col, const QRect& cr,b
     if (row%2!=0)colgrp.setColor(QColorGroup::Base,KGlobalSettings::alternateBackgroundColor());
     QTable::paintCell(p,row,col,cr,selected,colgrp);
     if (datasource()!=NULL)
-        if ((datasource()->is_enabled())&&((unsigned int)col<p_grid->columnscount()))
+        if ((datasource()->is_enabled())&&((unsigned int)col<p_grid->columnscount())&& p_grid->gridcolumn(col))
     {
         switch(p_grid->gridcolumn(col)->columntype())
         {
@@ -466,7 +479,7 @@ void hk_kdesimplegrid::paintCell(QPainter* p,int row, int col, const QRect& cr,b
 
 void hk_kdesimplegrid::paint_textcell(QPainter* p,int row, int col, const QRect& ,bool selected , const QColorGroup&)
 {
-    if (p_grid->gridcolumn(col)->column()==NULL) return;
+    if (!p_grid->gridcolumn(col)||p_grid->gridcolumn(col)->column()==NULL) return;
 bool is_null=false;
     Qt::AlignmentFlags f;
     QPen pen=p->pen();
@@ -485,7 +498,7 @@ bool is_null=false;
         (((unsigned int)row==datasource()->row_position()&&datasource()->mode()!=hk_datasource::mode_insertrow)||
         ((unsigned int)row==datasource()->max_rows()&&datasource()->mode()==hk_datasource::mode_insertrow)) )
     {
-        txt=QString::fromLocal8Bit (p_grid->gridcolumn(col)->column()->changed_data_asstring(true).c_str());
+        txt=QString::fromUtf8 (l2u(p_grid->gridcolumn(col)->column()->changed_data_asstring(true)).c_str());
 	is_null=p_grid->gridcolumn(col)->column()->changed_data_is_nullvalue();
     }
     else
@@ -495,21 +508,21 @@ bool is_null=false;
                                                   //&&col==currentColumn())
             if (p_grid->gridcolumn(col)->use_defaultvalue())
 	    {
-                txt=QString::fromLocal8Bit (p_grid->gridcolumn(col)->defaultvalue().c_str());
+                txt=QString::fromUtf8 (l2u(p_grid->gridcolumn(col)->defaultvalue()).c_str());
 		is_null=txt.isEmpty();
 	    }
         }
         else
 	{
-            txt=QString::fromLocal8Bit (p_grid->gridcolumn(col)->column()->asstring_at(row,true).c_str());
+            txt=QString::fromUtf8 (l2u(p_grid->gridcolumn(col)->column()->asstring_at(row,true)).c_str());
 	    is_null=p_grid->gridcolumn(col)->column()->is_nullvalue_at(row);
-	}    
+	}
     }
     if ((!is_null&&is_numerictype(p_grid->gridcolumn(col)->column())&&p_grid->gridcolumn(col)->column()->columntype()!=hk_column::auto_inccolumn &&txt.length()>0)
         || (p_grid->gridcolumn(col)->column()->columntype()==hk_column::auto_inccolumn
         && (unsigned int)row!=datasource()->max_rows())
         )
-        txt=format_number(txt.local8Bit().data(),true,p_grid->gridcolumn(col)->use_numberseparator(),p_grid->gridcolumn(col)->commadigits(),locale()).c_str();
+        txt=format_number(u2l(txt.utf8().data()),true,p_grid->gridcolumn(col)->use_numberseparator(),p_grid->gridcolumn(col)->commadigits(),locale()).c_str();
 
 //if (row!=currentRow())
     {
@@ -523,7 +536,7 @@ bool is_null=false;
     QPen txtpen=pen;
     txtpen.setColor(selected&&!(currentcell && hasFocus())?colorGroup().highlightedText():colorGroup().text());
     p->setPen(txtpen);
-    p->drawText(2,3,columnWidth(col)-7,rowHeight(row),f,txt);
+    p->drawText(2,0,columnWidth(col)-7,rowHeight(row),f,txt);
 
     p->setPen(pen);
 }
@@ -531,7 +544,7 @@ bool is_null=false;
 
 void hk_kdesimplegrid::paint_combocell(QPainter* p,int row, int col, const QRect& /*cr*/,bool selected,const QColorGroup &/*cg*/)
 {
-    if (p_grid->gridcolumn(col)->column()==NULL) return;
+    if (!p_grid->gridcolumn(col)||p_grid->gridcolumn(col)->column()==NULL) return;
     Qt::AlignmentFlags f;
     bool currentcell=currentRow()==row && currentColumn()==col;
     switch (p_grid->gridcolumn(col)->alignment())
@@ -549,7 +562,7 @@ void hk_kdesimplegrid::paint_combocell(QPainter* p,int row, int col, const QRect
         ((unsigned int)row==datasource()->row_position()||
         ((unsigned int)row==datasource()->max_rows()&&datasource()->mode()==hk_datasource::mode_insertrow)) )
     {
-        txt=QString::fromLocal8Bit (p_grid->gridcolumn(col)->value_at(row).c_str());
+        txt=QString::fromUtf8 (l2u(p_grid->gridcolumn(col)->value_at(row)).c_str());
     }
     else
     {
@@ -560,7 +573,7 @@ void hk_kdesimplegrid::paint_combocell(QPainter* p,int row, int col, const QRect
                 txt="";
         }
         else
-            txt=QString::fromLocal8Bit (p_grid->gridcolumn(col)->value_at(row).c_str());
+            txt=QString::fromUtf8 (l2u(p_grid->gridcolumn(col)->value_at(row)).c_str());
     }
     QPen txtpen=p->pen();
 
@@ -593,7 +606,7 @@ void hk_kdesimplegrid::paint_boolcell(QPainter* painter,int row, int col, const
             if (p_grid->gridcolumn(col)->column()->is_nullvalue_at(row)) draw=2;
 	    else
 	    if (p_grid->gridcolumn(col)->column()->asbool_at(row)) draw=1;
-	}    
+	}
     }
     switch (draw)
     {
@@ -610,7 +623,7 @@ void hk_kdesimplegrid::paint_boolcell(QPainter* painter,int row, int col, const
         qDrawPlainRect(painter,left+2,top+2,square-4,square-4,nullcolor,0,&brush);
             break;
 	    }
-   default:;	        
+   default:;
    }
 }
 
@@ -628,7 +641,7 @@ QWidget* hk_kdesimplegrid::createEditor(int row, int col,bool ) const
 #ifdef HK_DEBUG
 //cout <<"hk_kdesimplegrid::createEditor"<<endl;
 #endif
-    if (p_grid->gridcolumn(col)->column()==NULL )   return 0;
+    if (!p_grid->gridcolumn(col)||p_grid->gridcolumn(col)->column()==NULL )   return 0;
     if ( (isReadOnly() || isRowReadOnly( row ) || isColumnReadOnly( col )
         ||p_grid->gridcolumn(col)->is_readonly()||p_grid->gridcolumn(col)->column()->is_readonly())
         &&p_grid->gridcolumn(col)->columntype()== hk_dsgridcolumn::columnbool)return 0;
@@ -648,16 +661,12 @@ QWidget* hk_kdesimplegrid::createEditor(int row, int col,bool ) const
         }
         case hk_dsgridcolumn::columncombo:
         {
-            /*if(isReadOnly() || isRowReadOnly( row ) || isColumnReadOnly( col )
-                ||p_grid->gridcolumn(col)->is_readonly()||p_grid->gridcolumn(col)->column()->is_readonly())
-            {
-                e=create_lineeditor(row,col);
-                break;
-            }*/
-            hk_kdecombobox* l = new hk_kdecombobox( viewport());
+            hk_kdecombobox* l = new hk_kdecombobox( viewport(),dynamic_cast<hk_form*>(p_presentation));
             p_combobox_created=true;
             e=l;
             hk_dsgridcolumn* c=p_grid->gridcolumn(col);
+            if (c)
+            {
             l->set_columnname(c->columnname());
             l->set_viewcolumnname(c->viewcolumnname());
             l->set_listcolumnname(c->listcolumnname());
@@ -668,7 +677,8 @@ QWidget* hk_kdesimplegrid::createEditor(int row, int col,bool ) const
             l->set_readonly((isReadOnly() || isRowReadOnly( row ) || isColumnReadOnly( col )||p_grid->gridcolumn(col)->is_readonly()));
             l->set_font(p_grid->hk_dsgrid::font());
             l->set_gridcolumn(p_grid->gridcolumn(col));
-
+            //l->set_on_select_action(c->on_select_action());
+            }
 
             if (p_grid->presentation())
                 l->set_listdatasource(p_grid->presentation()->get_datasource(c->listdatasourcename()));
@@ -682,19 +692,24 @@ QWidget* hk_kdesimplegrid::createEditor(int row, int col,bool ) const
                     if (ds)ds->enable();
                 }
             }
-            l->set_datasource(p_grid->datasource());
+            if (p_presentation)
+              l->set_presentationdatasource(p_grid->presentationdatasource());
+            else
+              l->set_datasource(p_grid->datasource());
             if (l->lineEdit())l->lineEdit()->selectAll();
             break;
         }
         default:
 	{
-	hk_column* c=p_grid->gridcolumn(col)->column();
+	hk_column* c=p_grid->gridcolumn(col)?p_grid->gridcolumn(col)->column():NULL;
 	if (c)
 	{
 	 if (c->columntype()==hk_column::memocolumn)
 	 {
     hk_kdememo* l = new hk_kdememo( viewport());
     l->setPaletteBackgroundColor(paletteBackgroundColor());
+    if (p_grid->gridcolumn(col))
+    {
     l->set_alignment(p_grid->gridcolumn(col)->alignment());
     l->set_numberformat(p_grid->gridcolumn(col)->use_numberseparator(),p_grid->gridcolumn(col)->commadigits());
     l->set_datasource(p_grid->datasource());
@@ -704,7 +719,7 @@ QWidget* hk_kdesimplegrid::createEditor(int row, int col,bool ) const
     l->set_readonly((isReadOnly() || isRowReadOnly( row ) || isColumnReadOnly( col )||p_grid->gridcolumn(col)->is_readonly()));
     l->selectAll();
     l->set_gridcolumn(p_grid->gridcolumn(col));
-
+    }
     e=l;
 
 	 }
@@ -713,7 +728,7 @@ QWidget* hk_kdesimplegrid::createEditor(int row, int col,bool ) const
 	if (!e)e=create_lineeditor(row,col);
 	}
     }
-    
+
     return e;
 
 }
@@ -724,6 +739,8 @@ QWidget* hk_kdesimplegrid::create_lineeditor(int row, int col) const
     hk_kdelineedit* l = new hk_kdelineedit( viewport());
     l->setFrame( FALSE );
     l->setPaletteBackgroundColor(paletteBackgroundColor());
+    if (p_grid->gridcolumn(col))
+    {
     l->set_alignment(p_grid->gridcolumn(col)->alignment());
     l->set_numberformat(p_grid->gridcolumn(col)->use_numberseparator(),p_grid->gridcolumn(col)->commadigits());
     l->set_datasource(p_grid->datasource());
@@ -734,6 +751,7 @@ QWidget* hk_kdesimplegrid::create_lineeditor(int row, int col) const
     l->set_readonly((isReadOnly() || isRowReadOnly( row ) || isColumnReadOnly( col )||p_grid->gridcolumn(col)->is_readonly()));
     l->selectAll();
     l->set_gridcolumn(p_grid->gridcolumn(col));
+    }
     return l;
 
 }
@@ -758,7 +776,7 @@ void    hk_kdesimplegrid::nextcell()
     }
     else if ( currentRow() <= numRows() - 1)
     {
-        if   (datasource()->mode()==hk_datasource::mode_insertrow) datasource()->store_changed_data();
+        if   (datasource()->mode()==hk_datasource::mode_insertrow&&datasource()->check_store_changed_data()) datasource()->store_changed_data();
         setCurrentCell( currentRow() + 1,0  );
     }
     clearSelection(true);
@@ -792,7 +810,7 @@ void hk_kdesimplegrid::row_changed(int row,int col)
    if (!datasource()->is_enabled()) return;
    if (p_grid->gridcolumn(p_currentcolumn))
     p_grid->gridcolumn(p_currentcolumn)->action_on_loosefocus();
-    
+
     clear_vertical_header();
     bool result=true;
     if (datasource()!=NULL)
@@ -811,14 +829,15 @@ void hk_kdesimplegrid::row_changed(int row,int col)
      paint_vertical_header();
      return;
     }
-    endEdit(p_currentrow,p_currentcolumn,true,false);   
-    
+    endEdit(p_currentrow,p_currentcolumn,true,false);
+
 
     p_currentrow=row;
     p_currentcolumn=col;
     paint_vertical_header();
     set_statustext();
-    p_grid->gridcolumn(currentColumn())->action_on_getfocus();;
+    if (p_grid->gridcolumn(currentColumn()))
+      p_grid->gridcolumn(currentColumn())->action_on_getfocus();;
 //clearSelection(true);
 #ifdef HK_DEBUG
     hkdebug("hk_kdesimplegrid::row_changed ENDE");
@@ -845,7 +864,7 @@ void hk_kdesimplegrid::set_statustext(void)
         {
             status+=i18n("readwrite");
             status+=i18n(" Column: ");
-            if (p_grid->gridcolumn(currentColumn())->column()!=NULL)
+            if (p_grid->gridcolumn(currentColumn())&&p_grid->gridcolumn(currentColumn())->column()!=NULL)
                 status+=((p_grid->gridcolumn(currentColumn())->column()->is_readonly()||
                     p_grid->gridcolumn(currentColumn())->is_readonly()
                     )?
@@ -1005,7 +1024,8 @@ void hk_kdesimplegrid::keyPressEvent(QKeyEvent* e)
             }
 	    case Key_Z :
 	    {
-                hk_column* c=p_grid->gridcolumn(currentColumn())->column();
+                hk_column* c=p_grid->gridcolumn(currentColumn())?
+                               p_grid->gridcolumn(currentColumn())->column():NULL;
                 if (c)
 		{
 		  if (c->has_changed())
@@ -1019,7 +1039,8 @@ void hk_kdesimplegrid::keyPressEvent(QKeyEvent* e)
             }
 	    case Key_0:
 	    {
-		    hk_column* c=p_grid->gridcolumn(currentColumn())->column();
+                hk_column* c=p_grid->gridcolumn(currentColumn())?
+                               p_grid->gridcolumn(currentColumn())->column():NULL;
     		    if (c) c->set_asnullvalue();
 	    }
 	    default:;
@@ -1070,7 +1091,7 @@ bool hk_kdesimplegrid::key_pressevent_navigation(QKeyEvent* e)
             {
                 if (currentRow()<(signed)datasource()->max_rows()-1)datasource()->goto_next();
                 else
-                if (currentRow()==(signed)datasource()->max_rows())
+                if (currentRow()==(signed)datasource()->max_rows() &&datasource()->check_store_changed_data())
                 {
                     datasource()->store_changed_data();
                 }
@@ -1090,7 +1111,7 @@ bool hk_kdesimplegrid::key_pressevent_navigation(QKeyEvent* e)
                 break;
             case Key_Down: if(datasource()!=0)
             {
-                if (currentRow()==(signed)datasource()->max_rows())
+                if (currentRow()==(signed)datasource()->max_rows()&&datasource()->check_store_changed_data())
                 {
                     datasource()->store_changed_data();
                     datasource()->setmode_insertrow();
@@ -1122,21 +1143,37 @@ void hk_kdesimplegrid::show_contextmenu(int , int , const QPoint& pos)
     hkdebug("hk_kdesimplegrid::show_contextmenu");
 #endif
     if (datasource()==NULL)return;
+    if (presentation()&&presentation()->mode()==hk_presentation::designmode) return;
     QPopupMenu* popup=new QPopupMenu(this);
-    int id[8];
-    
+    int id[15];
+
     if (runtime_only()) id[4]=-99;
     else
       id[ 4 ] = popup->insertItem( i18n( "Define columns" ) );
-    
+
     id[ 5 ] = popup->insertItem( i18n( "Find" ) );
     popup->insertSeparator();
     id[ 3 ] = popup->insertItem( i18n( "Delete row" ) );
-    hk_column* c=p_grid->gridcolumn(currentColumn())->column();
+                hk_column* c=p_grid->gridcolumn(currentColumn())?
+                               p_grid->gridcolumn(currentColumn())->column():NULL;
     if (c  && !c->is_readonly()&&!c->is_notnull())
     {
         id[ 6 ] = popup->insertItem( i18n( "set 'NULL' value" ),CTRL+Key_0 );
     }
+    if (c  && !c->is_readonly() && (c->columntype()==hk_column::binarycolumn||c->columntype()==hk_column::memocolumn))
+    {
+        id[ 7 ] = popup->insertItem( i18n( "Load from file" ));
+    }
+    if (c  &&  (c->columntype()==hk_column::binarycolumn||c->columntype()==hk_column::memocolumn))
+    {
+        id[ 8 ] = popup->insertItem( i18n( "Save to file" ) );
+    }
+    popup->insertSeparator();
+    id[ 9 ] = popup->insertItem( i18n( "Copy" ),CTRL+Key_C );
+    if (c  && !c->is_readonly()&&!c->is_notnull())
+    {
+    id[ 10 ] = popup->insertItem( i18n( "Paste" ),CTRL+Key_V );
+    }
     int r = popup->exec( pos );
 
     if (r==id[3]&&datasource()!=NULL)datasource()->delete_actualrow();
@@ -1145,9 +1182,26 @@ void hk_kdesimplegrid::show_contextmenu(int , int , const QPoint& pos)
         show_gridcolumndialog();
     }
     else if (id[5]==r)p_grid->find_clicked();
-    else if (id[6]==r)
-    if (c) c->set_asnullvalue();
+    else if (id[6]==r && c) c->set_asnullvalue();
+    else if (id[7]==r && c)
+    	{
+    	  QString s=KFileDialog::getOpenFileName(":bin",QString::null,this);
+    	  if (!s.isEmpty()) c->load_from_file(u2l(s.utf8().data()));
+    	}
+    else if (id[8]==r && c)
+    	{
+    	  QString s=KFileDialog::getSaveFileName(":bin",QString::null,this);
+    	  if (!s.isEmpty()) c->save_to_file(u2l(s.utf8().data()));
+    	}
+    else if (id[9]==r && c)
+    {
+     copy();
+    }
 
+    else if (id[10]==r && c)
+    {
+     paste();
+    }
         delete popup;
     return;
 }
@@ -1190,6 +1244,7 @@ bool hk_kdesimplegrid::eventFilter( QObject *o, QEvent *e )
     }
 
     bool ok=false;
+
 //work around for a neverending event in case the user just presses a button
     if (e->type()==QEvent::KeyPress
         && o->inherits("hk_kdecombobox")
@@ -1271,10 +1326,14 @@ void hk_kdesimplegrid::contentsDropEvent(QDropEvent* event)
 void hk_kdesimplegrid::sortColumn( int col, bool ascending, bool /*wholeRows*/)
 {
     if (!datasource()) return;
+    if (!datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_SQL_ORDER_BY)) return ;
     if (!datasource()->is_enabled()) return;
+    if (p_grid->gridcolumn(col))
+    {
     hk_string colname = defaultidentifierdelimiter+p_grid->gridcolumn(col)->columnname()+defaultidentifierdelimiter;
     if (!ascending) colname+=" DESC ";
     datasource()->set_temporarysorting(colname);
+    }
     datasource()->disable();
     datasource()->set_use_temporarysorting(true);
     datasource()->enable();
@@ -1444,11 +1503,11 @@ void hk_kdesimplegrid::print_frame(QPainter& painter,QPaintDeviceMetrics& metric
     painter.drawText(leftborder,metrics.height()-bottomborder/2,metrics.width()-leftborder-rightborder,bottomborder,Qt::AlignRight,pgnr);
     hk_datetime dt;
     dt.set_now();
-    painter.drawText(leftborder,metrics.height()-bottomborder/2,metrics.width()-leftborder-rightborder,bottomborder,Qt::AlignLeft,QString::fromLocal8Bit(dt.datetime_asstring().c_str()));
-    QString tablename=(datasource()->type()==hk_datasource::ds_query?i18n("Query: "):i18n("Table: "))+QString::fromLocal8Bit(datasource()->name().c_str());
+    painter.drawText(leftborder,metrics.height()-bottomborder/2,metrics.width()-leftborder-rightborder,bottomborder,Qt::AlignLeft,QString::fromUtf8(l2u(dt.datetime_asstring()).c_str()));
+    QString tablename=(datasource()->type()==hk_datasource::ds_query?i18n("Query: "):i18n("Table: "))+QString::fromUtf8(l2u(datasource()->name()).c_str());
     painter.drawText(leftborder,topborder/2,metrics.width()-leftborder-rightborder,topborder,Qt::AlignRight,tablename);
 
-    QString databasename=i18n("Database: ")+QString::fromLocal8Bit(datasource()->database()->name().c_str());
+    QString databasename=i18n("Database: ")+QString::fromUtf8(l2u(datasource()->database()->name()).c_str());
     painter.drawText(leftborder,topborder/2,metrics.width()-leftborder-rightborder,topborder,Qt::AlignLeft,databasename);
 
 }
@@ -1471,11 +1530,14 @@ int  hk_kdesimplegrid::print_header(QPainter& painter,QPaintDeviceMetrics&metric
         painter.fillRect(0,0,x2,y2,colorGroup().brush(QColorGroup::Button));
         painter.drawLine( x2, 0, x2, y2 );
         painter.drawLine( 0, y2, x2, y2 );
+        if (p_grid->gridcolumn(col))
+        {
         painter.drawText(2,3,w-7,
             rowheight-3,Qt::AlignLeft
-            ,QString::fromLocal8Bit (p_grid->gridcolumn(col)->displayname().size()==0?
-            p_grid->gridcolumn(col)->columnname().c_str():
-        p_grid->gridcolumn(col)->displayname().c_str()));
+            ,QString::fromUtf8 (p_grid->gridcolumn(col)->displayname().size()==0?
+            l2u(p_grid->gridcolumn(col)->columnname()).c_str():
+        l2u(p_grid->gridcolumn(col)->displayname()).c_str()));
+        }
         painter.translate(-colpos-leftborder+horizontal.offset,-topborder);
     }
     //cerr <<endl<<endl<<endl;
@@ -1485,8 +1547,9 @@ int  hk_kdesimplegrid::print_header(QPainter& painter,QPaintDeviceMetrics&metric
 
 QString hk_kdesimplegrid::marked_text(void)
 {
+  if (!p_grid->gridcolumn(currentColumn())) return "";
   if (numSelections()==0)
-    return QString::fromLocal8Bit(p_grid->gridcolumn(currentColumn())->value_at(currentRow()).c_str());
+    return QString::fromUtf8(l2u(p_grid->gridcolumn(currentColumn())->value_at(currentRow())).c_str());
 
   QTableSelection s=selection(0);
   QString result;
@@ -1499,7 +1562,7 @@ QString hk_kdesimplegrid::marked_text(void)
     d=replace_all("\t",d,"\\t");
     d=replace_all("\n",d,"\\n");
 
-      result+=QString::fromLocal8Bit(d.c_str());
+      result+=QString::fromUtf8(l2u(d).c_str());
       if (c!=s.rightCol()) result+="\t";
     }
    if (r<s.bottomRow()) result+="\n";
@@ -1510,7 +1573,7 @@ QString hk_kdesimplegrid::marked_text(void)
 
 void hk_kdesimplegrid::paste_tsv(const QString& txt)
 {//txt contains the whole clipboard or drag data
- hk_string t=txt.local8Bit().data();
+ hk_string t=u2l(txt.utf8().data());
  if (t.size()==0) return;
  //hk_column* c=p_grid->gridcolumn(currentColumn())->column();
  int maxrow=-1;
@@ -1542,7 +1605,8 @@ void hk_kdesimplegrid::paste_tsv(const QString& txt)
      value=replace_all("\\t",value,"\t");
      value=replace_all("\\n",value,"\n");
      value=replace_all("&bs;",value,"\\");
-     p_grid->gridcolumn(currentColumn())->column()->set_asstring(value);
+     if (p_grid->gridcolumn(currentColumn()))
+       p_grid->gridcolumn(currentColumn())->column()->set_asstring(value);
       value="";
       updateCell(currentRow(),currentColumn());
       if (c=="\t")
@@ -1554,7 +1618,7 @@ void hk_kdesimplegrid::paste_tsv(const QString& txt)
 	   {
         	countcol=0;
 		++countrow;
-	 	datasource()->store_changed_data();
+	 	if(datasource()->check_store_changed_data())datasource()->store_changed_data();
                 if (maxrow>-1&&currentRow()+1>maxrow)return;
 	 	setCurrentCell(currentRow()+1,startcol);
 		while (txtposition<t.size()&&c.assign(1,t[txtposition])!="\n") ++txtposition;
@@ -1566,7 +1630,7 @@ void hk_kdesimplegrid::paste_tsv(const QString& txt)
       { //c=="\n" or EOF
         countcol=0;
 	++countrow;
-	 datasource()->store_changed_data();
+	 if(datasource()->check_store_changed_data())datasource()->store_changed_data();
 	 if (maxrow>-1&&currentRow()+1>maxrow)return;
 	 if (txtposition!=t.size()) setCurrentCell(currentRow()+1,startcol);
       }
@@ -1580,13 +1644,22 @@ void hk_kdesimplegrid::paste_tsv(const QString& txt)
 
 
 void hk_kdesimplegrid::slot_mouse_clicked(void)
-{  
+{
    if (p_presentation && p_presentation->mode()==hk_presentation::viewmode
        )
-   {    
+   {
+          cerr<<"vor action_on_click"<<endl;
           p_grid->action_on_click();
-	  p_grid->gridcolumn(currentColumn())->action_on_click();
-   }	  
+          cerr<<"nach action_on_click"<<endl;
+	  if (numCols()>0)
+	  {
+	            cerr<<"vor gridcolumn"<<endl;
+
+	   if (p_grid->gridcolumn(currentColumn()))
+	      p_grid->gridcolumn(currentColumn())->action_on_click();
+	            cerr<<"nach gridcolumn"<<endl;
+	  }
+   }
 }
 
 void hk_kdesimplegrid::slot_mouse_doubleclicked(void)
@@ -1595,6 +1668,7 @@ void hk_kdesimplegrid::slot_mouse_doubleclicked(void)
        )
    {
           p_grid->action_on_doubleclick();
+  	  if (numCols()>0 && p_grid->gridcolumn(currentColumn()))
   	  p_grid->gridcolumn(currentColumn())->action_on_doubleclick();
 
    }
@@ -1642,7 +1716,8 @@ void hk_kdesimplegrid::paste(void)
 void hk_kdesimplegrid::cut(void)
 {
                 copy();
-                hk_column* c=p_grid->gridcolumn(currentColumn())->column();
+                hk_column* c=p_grid->gridcolumn(currentColumn())?
+                		p_grid->gridcolumn(currentColumn())->column():NULL;
                 if (c)
                 {
 		 if (numSelections()==0)
@@ -1658,7 +1733,8 @@ void hk_kdesimplegrid::cut(void)
 			datasource()->goto_row(r);
    			for (int c=s.leftCol();c<=s.rightCol();++c)
     			{
-      				p_grid->gridcolumn(c)->column()->asstring("");
+      				if (p_grid->gridcolumn(c))
+      				  p_grid->gridcolumn(c)->column()->asstring("");
                     		updateCell(r,c);
     			}
 			}
@@ -1703,13 +1779,14 @@ p_hk_kdesimplegridprivate->autoresizeverticalheader=false;
 
 void hk_kdesimplegrid::slot_content_moving(int /*x*/,int y)
 {
+if (numRows()==0)return;
 int begin=rowAt(y);
 int end=rowAt(y+QTable::height());
 if (end<begin||end>numRows()) end=numRows();
 if (end+500>numRows()) end=numRows();
 if (end<numRows()+100) end+=100;
 
-cerr <<"slot_content_moving b="<<begin<<" e="<<end<<endl;
+//cerr <<"slot_content_moving b="<<begin<<" e="<<end<<endl;
  for (int i=begin;i<=end;++i)
    {
      if (rowHeight(i)!=p_grid->rowheight())
@@ -1728,14 +1805,14 @@ hk_kdegrid* hk_kdesimplegrid::kdegrid() const
 
 void  hk_kdesimplegrid::widget_specific_tooltip_changed(void)
 {
- QToolTip::add(this,QString::fromLocal8Bit (tooltip().c_str()));
+ QToolTip::add(this,QString::fromUtf8 (l2u(tooltip()).c_str()));
 }
 
 
 void hk_kdesimplegrid::clear_vertical_header(void)
 {
    if (datasource() &&!datasource()->is_readonly()&&!p_grid->is_readonly())
-   
+
      verticalHeader()->setLabel(datasource()->max_rows(),"*");
    QString r;
     p_currentrow==datasource()->max_rows()?r="*":r.setNum(p_currentrow+1);
