@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.70 $
+//$Revision: 1.73 $
 
 #include "hk_kdesimplereport.h"
 #include "hk_kdereportsection.h"
@@ -34,12 +34,6 @@
 #include <qclipboard.h>
 #include <qcolor.h>
 
-#ifdef HAVE_SSTREAM
-#include <sstream>
-#else
-#include <strstream.h>
-#endif
-
 const int headerheight=20;
 class hk_kdesimplereportprivate
 {
@@ -166,17 +160,25 @@ void hk_kdesimplereport::set_reportpartwidget(hk_kdereportpartwidget* w)
 {
 
   p_private->p_reportpartwidget=w;
-    if (p_private->p_property) 
+    if (p_private->p_property)
       {
        delete p_private->p_property;
        p_private->p_property=NULL;
-      } 
-  
+      }
+
   show_property();
 }
 
 
 
+hk_kdereportpartwidget* hk_kdesimplereport::reportpartwidget() const
+{
+return p_private->p_reportpartwidget;
+
+}
+
+
+
 void hk_kdesimplereport::set_kdereport(hk_kdereport* k)
 {
 #ifdef HK_DEBUG
@@ -185,12 +187,12 @@ void hk_kdesimplereport::set_kdereport(hk_kdereport* k)
     p_private->p_kdereport=k;
     if (p_private->p_kdereport)
     {
-    if (p_private->p_property) 
+    if (p_private->p_property)
       {
        delete p_private->p_property;
        p_private->p_property=NULL;
-      } 
-      
+      }
+
     show_property();
     p_private->p_deleteaction=new KAction(i18n("&Delete"),Key_Delete,this,SLOT(delete_widgets()),p_private->p_kdereport->actionCollection(),"deleteclicked");
     p_private->p_copyaction= new KAction(i18n("&Copy"),CTRL+Key_C,this,SLOT(copy_widgets()),p_private->p_kdereport->actionCollection(),"copy");
@@ -239,7 +241,7 @@ void hk_kdesimplereport::set_kdereport(hk_kdereport* k)
     delete p_private->p_alignrightaction;
     delete p_private->p_aligntopaction;
     delete p_private->p_alignbottomaction;
-    
+
     p_private->p_deleteaction=NULL;
     p_private->p_copyaction=NULL;
     p_private->p_pasteaction=NULL;
@@ -256,7 +258,7 @@ void hk_kdesimplereport::set_kdereport(hk_kdereport* k)
     p_private->p_alignrightaction=NULL;
     p_private->p_aligntopaction=NULL;
     p_private->p_alignbottomaction=NULL;
-    
+
     }
 }
 
@@ -359,10 +361,10 @@ bool hk_kdesimplereport::reporteventFilter(QObject* object,QEvent* event)
 // activate the section on a mousepressevent
                 if (!s && widget) return QWidget::eventFilter(object,event);
                 p_private->p_originalposition=mapFromGlobal(((QMouseEvent*)event)->globalPos());
-		
+
 		if (snap2gridx()>0&&!(((QMouseEvent*)event)->state() & ControlButton))
 		p_private->p_originalposition.setX((p_private->p_originalposition.x()/snap2gridx())*snap2gridx());
-		
+
 		if (snap2gridy()>0&&!(((QMouseEvent*)event)->state() & ControlButton))
 		p_private->p_originalposition.setY((p_private->p_originalposition.y()/snap2gridy())*snap2gridy());
                 return true;
@@ -385,13 +387,13 @@ bool hk_kdesimplereport::reporteventFilter(QObject* object,QEvent* event)
             {
 //move object
                 QPoint newpos=mapFromGlobal(((QMouseEvent*)event)->globalPos());
-		
+
 		if (snap2gridx()>0&&!(((QMouseEvent*)event)->state() & ControlButton))
 		newpos.setX((newpos.x()/snap2gridx())*snap2gridx());
-		
+
 		if (snap2gridy()>0&&!(((QMouseEvent*)event)->state() & ControlButton))
 		newpos.setY((newpos.y()/snap2gridy())*snap2gridy());
-		
+
                 QPoint difference=p_private->p_originalposition-newpos;
 		QPoint buf=p_private->p_originalposition;
                 p_private->p_originalposition=newpos;
@@ -604,7 +606,7 @@ void hk_kdesimplereport::before_source_vanishes(void)
     if (p_private->p_autoclose && !p_private->p_sourcevanishflag)
     {
         if (parentWidget()!=NULL)
-        {   
+        {
             doemit=true;
         }
     }
@@ -620,14 +622,14 @@ void hk_kdesimplereport::before_source_vanishes(void)
        hk_kdereport* k=p_private->p_kdereport;
        set_kdereport(NULL);
        k->close();
-      } 
+      }
     else
         if (p_private->p_reportpartwidget)
       {
        hk_kdereportpartwidget* k=p_private->p_reportpartwidget;
        set_reportpartwidget(NULL);
        k->close();
-      } 
+      }
     else p->close();
    close();
 
@@ -647,7 +649,7 @@ void hk_kdesimplereport::database_has_vanished(void)
     if (p_private->p_autoclose && !p_private->p_sourcevanishflag)
     {
         if (parentWidget()!=NULL)
-        {   
+        {
             doemit=true;
         }
     }
@@ -659,13 +661,13 @@ void hk_kdesimplereport::database_has_vanished(void)
       {hk_kdereport* k=p_private->p_kdereport;
        set_kdereport(NULL);
        k->close();
-      } 
+      }
     else
      if (p_private->p_reportpartwidget)
       {hk_kdereportpartwidget* k=p_private->p_reportpartwidget;
        set_reportpartwidget(NULL);
        k->close();
-      } 
+      }
     else p->close();
    close();
  }
@@ -766,14 +768,14 @@ void hk_kdesimplereport::widget_specific_modechanges(enum_mode s)
             it++;
         }
         if (p_private->p_focus!=NULL) p_private->p_focus->hide();
-        if(p_private->p_property!=NULL) 
+        if(p_private->p_property!=NULL)
 	  {
 	       if (p_private->p_propertydock)
 	       {
                  if (p_private->p_propertydock->mayBeHide())
 		    p_private->p_propertydock->changeHideShowState();
 		 //p_private->p_propertydock->hide();
-	       }	 
+	       }
                else
 	       p_private->p_property->hide();
 	  }
@@ -799,7 +801,7 @@ void hk_kdesimplereport::keyPressEvent ( QKeyEvent * event )
 //        break;
         case Key_Delete:   delete_widgets();
         break;
-   
+
    case Key_Left:
             if (p_private->p_focus &&p_private->p_focus->widget())
             {
@@ -966,7 +968,7 @@ void hk_kdesimplereport::set_sections(void)
     p_private->p_reportlayout->addWidget(section);
     section->show();
     section->header()->show();
-    
+
     section=dynamic_cast<hk_kdereportsection*>(report_header());
     section->header()->setMinimumHeight(headerheight);
     p_private->p_reportlayout->addWidget(section->header());
@@ -1041,7 +1043,7 @@ void hk_kdesimplereport::set_sections(void)
     k=static_cast <hk_kdereportsection*>(report_footer());
     k->set_displaystring(i18n("Reportfooter"));
     k->show();
-    
+
 }
 
 
@@ -1380,7 +1382,7 @@ void hk_kdesimplereport::show_property(void)
     if (mode()!=hk_presentation::designmode)return;
     bool newproperty=false;
     if (p_private->p_property==NULL)
-    {   
+    {
          p_private->p_property=new hk_kdereportproperty(this,0,false);
 	 p_private->p_property->set_object(this);
          if (p_private->p_kdereport)
@@ -1402,17 +1404,17 @@ void hk_kdesimplereport::show_property(void)
        newproperty=true;
 
     }
-    
+
     if (p_private->p_property!=NULL)
-    {   
+    {
      if (p_private->p_propertydock)
         {
 	  //p_private->p_propertydock->makeDockVisible();
 	     if (p_private->p_propertydock->mayBeShow())
 	     p_private->p_propertydock->changeHideShowState();
           //p_private->p_propertydock->show();
-	}  
-     
+	}
+
      else
      p_private->p_property->show();
      //qApp->processEvents();
@@ -1455,11 +1457,7 @@ void hk_kdesimplereport::copy_widgets(void)
     if (!p_private->p_focus || !p_private->p_focus->widget()) return;
     QStoredDrag* p_drag = new QStoredDrag("application/x-hk_kdesimplereportcopy");
     hk_string cpyinfo;
-#ifdef HAVE_SSTREAM
-    stringstream stream;
-#else
-    strstream stream;
-#endif
+    STRINGSTREAM stream;
 
     list<hk_kdeformfocus*>::iterator it=p_private->p_multiplefocus.begin();
     while (it!=p_private->p_multiplefocus.end())
@@ -1495,7 +1493,7 @@ void hk_kdesimplereport::paste_widgets(void)
     hk_kdereportsection* rs=dynamic_cast<hk_kdereportsection*>((p_private->p_focussection?p_private->p_focussection:datasection()));
     if (!rs)
     {
-        show_warningmessage(i18n("Error while paste action: No reportsection!!!").local8Bit().data());
+        show_warningmessage(u2l(i18n("Error while paste action: No reportsection!!!").utf8().data()));
         return;
     }
     while (get_tagvalue(definition,"REPORTOBJECT",value,i))
@@ -1694,7 +1692,7 @@ hk_kdeformfocus* hk_kdesimplereport::focus(void)
 return p_private->p_focus;
 }
 
-hk_kdereport* hk_kdesimplereport::kdereport(void)
+hk_kdereport* hk_kdesimplereport::kdereport(void) 
 {
 return p_private->p_kdereport;
 }
@@ -1724,7 +1722,7 @@ if (dv)
 if (!runtime_only())
    {
       if (kdereport())kdereport()->set_mode(hk_presentation::designmode);
-      if (p_private->p_reportpartwidget) 
+      if (p_private->p_reportpartwidget)
          p_private->p_reportpartwidget->set_mode(hk_presentation::designmode);
       if (p_private->p_property)
 	    {
