@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -21,12 +21,16 @@ Q_OBJECT
 public:
 hk_kdesubform(hk_kdesimpleform*);
 virtual ~hk_kdesubform();
+virtual void show_widget(void);
+virtual void hide_widget(void);
+virtual void close_widget(void);
 
 protected:
 bool widget_specific_coordinates(uint px,uint py,uint pwidth,uint pheight);
+	virtual void widget_specific_enabled_changed(void);
 void resizeEvent ( QResizeEvent * event );
 void moveEvent ( QMoveEvent * event);
-virtual void	presentationmode_changed(void);
+virtual bool	presentationmode_changed(void);
 
 private:
 void reposition(void);
