@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.38 $
+//$Revision: 1.39 $
 
 #include "hk_kdetable.h"
 #include <hk_datasource.h>
@@ -137,12 +137,12 @@ void hk_kdetable::set_caption(void)
     {
         
 	QString n=i18n("Table - ");
-        n+=QString::fromLocal8Bit(d->name().c_str());
+        n+=QString::fromUtf8(l2u(d->name()).c_str());
         n+=" (";
         hk_string driver=d->database()->name();
-        n+=QString::fromLocal8Bit(driver.c_str());
+        n+=QString::fromUtf8(l2u(driver).c_str());
         n+=")";
-        setCaption(QString::fromLocal8Bit(d->database()->connection()->drivername().c_str())+" "+n);
+        setCaption(QString::fromUtf8(l2u(d->database()->connection()->drivername()).c_str())+" "+n);
 	KMdiChildView* v=dynamic_cast<KMdiChildView*>(parent());
         if (v) v->setCaption(n);
     }
