@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of knoda -Knorr's Datenbank.
 // This file may be distributed and/or modified under the terms of the
 // GNU General Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.32 $
+//$Revision: 1.46 $
 #include "knodamaindockwindow.h"
 #include "hk_kdedblistview.h"
 #include "hk_kdecsvimportdialog.h"
@@ -22,6 +22,7 @@
 #include "hk_kdeformpartwidget.h"
 #include "hk_kdereportpartwidget.h"
 #include "hk_kdenewdatabase.h"
+#include "hk_kdedblistview.h"
 
 #include <hk_connection.h>
 #include <hk_drivermanager.h>
@@ -36,6 +37,8 @@
 #include <klocale.h>
 #include <kparts/genericfactory.h>
 #include <kiconloader.h>
+#include <kconfig.h>
+#include <kapplication.h>
 
 knodamaindockwindow::knodamaindockwindow(
         struct_commandlinefields* commandline,
@@ -45,18 +48,18 @@ knodamaindockwindow::knodamaindockwindow(
   if (p_listview)
   connect(p_listview,SIGNAL(currentChanged(QListViewItem*)),this,SLOT(slot_selection_changed()));
   clipboarddata_has_changed();
-  
+
   if (!dbname.isEmpty()&& p_databasecombobox)
    {
       int c=p_databasecombobox->count();
       int count=0;
-      bool found=false;      
+      bool found=false;
       while (count<c && !found)
       {
        QString s=p_databasecombobox->text(count);
        if (!s.isEmpty())
         {
-	   if (s==dbname) 
+	   if (s==dbname)
 	   {
 	    p_databasecombobox->setCurrentItem(count);
 	    slot_database_selected(count);
@@ -65,18 +68,23 @@ knodamaindockwindow::knodamaindockwindow(
 	}
        ++count;
       }
+     if (!found)
+      {
+        p_databasecombobox->insertItem(dbname);
+	p_databasecombobox->setCurrentItem(count);
+      }
    if (!form.isEmpty())
    {
    slot_viewmode_form(form);
-   
+
    }
-      
+
    }
    else
    {
      if (p_database)
      {//automatically start "Autoform" when --strongruntime is set
-       if (p_database->form_exists(autoform.local8Bit().data()))
+       if (p_database->form_exists(u2l(autoform.utf8().data())))
        slot_viewmode_form(autoform);
      }
 
@@ -85,9 +93,9 @@ knodamaindockwindow::knodamaindockwindow(
   if (commandline)
   {
     if (commandline->form.size()>0)
-      slot_viewmode_form(QString::fromLocal8Bit(commandline->form.c_str()));
+      slot_viewmode_form(QString::fromUtf8(l2u(commandline->form).c_str()));
   }
-}	
+}
 
 knodamaindockwindow::~knodamaindockwindow()
 {
@@ -96,7 +104,7 @@ knodamaindockwindow::~knodamaindockwindow()
 void knodamaindockwindow::slot_childClosed(QWidget* w)
 {
  cerr <<"slot_childClosed(QWidget* w)"<<endl;
- if (!w) 
+ if (!w)
  {
    cerr<<"knodamaindockwindow::slot_childClosed\nWARNING! w==NULL"<<endl;
    return;
@@ -110,23 +118,23 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
  v->activate();
  closeWindow(v);
 }
-  
+
  void knodamaindockwindow::slot_childClosed(KMdiChildView* /*c*/)
  {
   cerr <<"knodamaindockwindow::slot_childClosed(KMdiChildView* c)"<<endl;
-   
-   
-   
-   
+
+
+
+
   cerr <<"knodamaindockwindow::slot_childClosed(KMdiChildView* c) ENDE"<<endl;
  }
-  
+
 
   void knodamaindockwindow::slot_new_database(void)
   {
-    if (!p_connection->server_supports(hk_connection::SUPPORTS_NEW_DATABASE)) 
+    if (!p_connection->server_supports(hk_connection::SUPPORTS_NEW_DATABASE))
         return;
-        hk_string r=hk_kdenewdatabase::show_dialog(p_connection->server_supports(hk_connection::SUPPORTS_LOCAL_FILEFORMAT));
+        hk_string r=hk_kdenewdatabase::show_dialog(p_connection->drivername(),p_connection->server_supports(hk_connection::SUPPORTS_LOCAL_FILEFORMAT));
 	r=trim(r);
         if (r.size()>0)
         {
@@ -137,22 +145,28 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
 	    set_databases();
         }
   }
-  
+
   void knodamaindockwindow::slot_delete_database(const QString& t)
   {
-    if (!p_connection->server_supports(hk_connection::SUPPORTS_DELETE_DATABASE)) 
+    if (!p_connection->server_supports(hk_connection::SUPPORTS_DELETE_DATABASE))
         return;
-    if (p_database && p_database->name()==t.local8Bit().data()) 
-        p_database=NULL;	
-    if (p_connection->delete_database(t.local8Bit().data()))
+    if (p_database && p_database->name()==u2l(t.utf8().data()))
+        p_database=NULL;
+    if (p_connection->delete_database(u2l(t.utf8().data())))
     {
     set_databases();
+    slot_selection_changed();
     }
   }
-  
-  
+
+
   void knodamaindockwindow::slot_new_table(void)
   {
+   if (!p_connection->server_supports(hk_connection::SUPPORTS_NEW_TABLE))
+   {
+     show_warningmessage(hk_translate("Driver does not support creating new tables"));
+     return;
+   }
    hk_kdetablepartwidget* o=new_table();
    hk_datasource* d=p_database->new_table();
    if (o)
@@ -161,33 +175,52 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
    o->set_designmode();
    }
   }
-  
+
   void knodamaindockwindow::slot_delete_table(const QString& t)
   {
-   p_database->delete_table(t.local8Bit().data());
+   p_database->delete_table(u2l(t.utf8().data()));
 
   }
-  
+
   void knodamaindockwindow::slot_designmode_table(const QString& t)
   {
-   
+    hk_kdetablepartwidget* w=find_existing_table(u2l(t.utf8().data()));
+    if (w)
+    {
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(w->parent());
+      if (view)
+	 view->activate();
+    if (w->mode()!=hk_presentation::designmode)w->set_designmode();
+    return;
+    }
+
    hk_kdetablepartwidget* o=new_table();
    hk_datasource* d=p_database->new_table();
-   if (d)d->set_name(t.local8Bit().data());
+   if (d)d->set_name(u2l(t.utf8().data()));
    if (o)
    {
    o->set_datasource(d);
    o->set_designmode();
    }
   }
- 
-  
+
+
   void knodamaindockwindow::slot_viewmode_table(const QString& t)
   {
-   
+    
+    hk_kdetablepartwidget* w=find_existing_table(u2l(t.utf8().data()));
+    if (w)
+    {
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(w->parent());
+      if (view)
+	 view->activate();
+    if (w->mode()!=hk_presentation::viewmode)w->set_viewmode();
+    return;
+    }
+
    hk_kdetablepartwidget* o=new_table();
    hk_datasource* d=p_database->new_table();
-   if (d)d->set_name(t.local8Bit().data());
+   if (d)d->set_name(u2l(t.utf8().data()));
    if (o)
    {
    o->set_datasource(d);
@@ -195,8 +228,8 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
    }
   }
 
-  
-  
+
+
   void knodamaindockwindow::slot_new_query(void)
   {
    hk_kdequerypartwidget* o=new_query(false);
@@ -207,17 +240,27 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
    o->set_designmode();
    }
   }
-  
+
   void knodamaindockwindow::slot_delete_query(const QString& t)
   {
-     p_database->delete_file(t.local8Bit().data(),ft_query);
+     p_database->delete_file(u2l(t.utf8().data()),ft_query);
   }
-  
+
   void knodamaindockwindow::slot_designmode_query(const QString&t)
   {
+    hk_kdequerypartwidget* w=find_existing_query(u2l(t.utf8().data()));
+    if (w)
+    {
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(w->parent());
+      if (view)
+	 view->activate();
+    if (w->mode()!=hk_presentation::designmode)w->set_designmode();
+    return;
+    }
+   
    hk_kdequerypartwidget* o=new_query(false);
    hk_datasource* d=p_database->new_resultquery();
-   if (d)d->set_name(t.local8Bit().data());
+   if (d)d->set_name(u2l(t.utf8().data()));
    if (o)
    {
    o->set_datasource(d);
@@ -227,9 +270,19 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
 }
   void knodamaindockwindow::slot_viewmode_query(const QString&t)
   {
+    hk_kdequerypartwidget* w=find_existing_query(u2l(t.utf8().data()));
+    if (w)
+    {
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(w->parent());
+      if (view)
+	 view->activate();
+    if (w->mode()!=hk_presentation::viewmode)w->set_viewmode();
+    return;
+    }
+
    hk_kdequerypartwidget* o=new_query(false);
    hk_datasource* d=p_database->new_resultquery();
-   if (d)d->set_name(t.local8Bit().data());
+   if (d)d->set_name(u2l(t.utf8().data()));
    if (o)
    {
    o->set_datasource(d);
@@ -238,17 +291,22 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
    }
 }
 
-  
-  
-  
-  
-  
-  
-  
-  
-  
+
+
+
+
+
+
+
+
+
     void knodamaindockwindow::slot_new_view(void)
   {
+   if (!p_connection->server_supports(hk_connection::SUPPORTS_VIEWS))
+   {
+     show_warningmessage(hk_translate("Driver does not support creating new views"));
+     return;
+   }
    hk_kdequerypartwidget* o=new_query(true);
    hk_datasource* d=p_database->new_view();
    if (o)
@@ -257,19 +315,29 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
    o->set_designmode();
    }
   }
-  
-  
+
+
   void knodamaindockwindow::slot_delete_view(const QString& t)
   {
-     p_database->delete_view(t.local8Bit().data());
+     p_database->delete_view(u2l(t.utf8().data()));
   }
-  
-  
+
+
   void knodamaindockwindow::slot_designmode_view(const QString&t)
   {
+    hk_kdequerypartwidget* w=find_existing_view(u2l(t.utf8().data()));
+    if (w)
+    {
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(w->parent());
+      if (view)
+	 view->activate();
+    if (w->mode()!=hk_presentation::designmode)w->set_designmode();
+    return;
+    }
+   
    hk_kdequerypartwidget* o=new_query(true);
    hk_datasource* d=p_database->new_view();
-   if (d)d->set_name(t.local8Bit().data());
+   if (d)d->set_name(u2l(t.utf8().data()));
    if (o)
    {
    o->set_datasource(d);
@@ -277,12 +345,23 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
    o->set_designmode();
    }
 }
-  
+
   void knodamaindockwindow::slot_viewmode_view(const QString&t)
   {
+    hk_kdequerypartwidget* w=find_existing_view(u2l(t.utf8().data()));
+    if (w)
+    {
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(w->parent());
+      if (view)
+	 view->activate();
+    if (w->mode()!=hk_presentation::viewmode)w->set_viewmode();
+    return;
+    }
+   
+   
    hk_kdequerypartwidget* o=new_query(true);
    hk_datasource* d=p_database->new_view();
-   if (d)d->set_name(t.local8Bit().data());
+   if (d)d->set_name(u2l(t.utf8().data()));
    if (o)
    {
    o->set_datasource(d);
@@ -292,21 +371,21 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
 }
 
 
-  
-  
-  
-  
-  
-  
-  
-  
-  
-  
-  
-  
+
+
+
+
+
+
+
+
+
+
+
+
   void knodamaindockwindow::slot_new_form(void)
   {
-    if (!p_database) return; 
+    if (!p_database) return;
     hk_kdeformpartwidget* w=new_form();
     if (w)
     {
@@ -314,92 +393,139 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
     w->set_designmode();
     }
  }
-  
+
   void knodamaindockwindow::slot_delete_form(const QString& t)
   {
-      p_database->delete_file(t.local8Bit().data(),ft_form);
+      p_database->delete_file(u2l(t.utf8().data()),ft_form);
   }
-  
+
   void knodamaindockwindow::slot_designmode_form(const QString& t)
  {
-    if (!p_database) return; 
-    hk_kdeformpartwidget* w=new_form();
+    if (!p_database) return;
+    hk_kdeformpartwidget* w=find_existing_form(u2l(t.utf8().data()));
+    if (w)
+    {
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(w->parent());
+      if (view)
+	 view->activate();
+    if (w->mode()!=hk_form::designmode)w->set_designmode();
+    return;
+    }
+    
+    w=new_form();
     if (!w)return;
     w->set_database(p_database);
-    w->load_form(t.local8Bit().data());
+    w->load_form(u2l(t.utf8().data()));
     w->set_designmode();
 }
+  
+  
+  
+  
   void knodamaindockwindow::slot_viewmode_form(const QString& t)
  {
-    if (!p_database) return; 
-    hk_kdeformpartwidget* w=new_form();
+    if (!p_database) return;
+    hk_kdeformpartwidget* w=find_existing_form(u2l(t.utf8().data()));
+    if (w)
+    {
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(w->parent());
+      if (view)
+	 view->activate();
+    if (w->mode()!=hk_form::viewmode)w->set_viewmode();
+    return;
+    }
+    
+    w=new_form();
     if (!w)return;
     w->set_database(p_database);
-    w->load_form(t.local8Bit().data());
+    w->load_form(u2l(t.utf8().data()));
     w->set_viewmode();
 }
 
   void knodamaindockwindow::slot_new_report(void)
   {
-    if (!p_database) return; 
+    if (!p_database) return;
     hk_kdereportpartwidget* w=new_report();
     if (!w)return;
     w->set_database(p_database);
     w->set_designmode();
   }
-  
+
   void knodamaindockwindow::slot_delete_report(const QString& t)
   {
-      p_database->delete_file(t.local8Bit().data(),ft_report);
+      p_database->delete_file(u2l(t.utf8().data()),ft_report);
 
   }
-  
-  
+
+
   void knodamaindockwindow::slot_designmode_report(const QString&t)
   {
-    if (!p_database) return; 
-     hk_kdereportpartwidget* w=new_report();
+    if (!p_database) return;
+    hk_kdereportpartwidget* w=find_existing_report(u2l(t.utf8().data()));
+    if (w)
+    {
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(w->parent());
+      if (view)
+	 view->activate();
+    if (w->mode()!=hk_report::designmode)w->set_designmode();
+    return;
+    }
+     
+     
+     w=new_report();
     if (!w)return;
      w->set_database(p_database);
-     w->load_report(t.local8Bit().data());
+     w->load_report(u2l(t.utf8().data()));
      w->set_designmode();
-  
+
   }
-  
+
   void knodamaindockwindow::slot_viewmode_report(const QString& t)
   {
-     hk_kdereportpartwidget* w=new_report();
+    if (!p_database) return;
+    hk_kdereportpartwidget* w=find_existing_report(u2l(t.utf8().data()));
+    if (w)
+    {
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(w->parent());
+      if (view)
+	 view->activate();
+    if (w->mode()!=hk_report::viewmode)w->set_viewmode();
+    return;
+    }
+     
+     
+    w=new_report();
     if (!w)return;
      w->set_database(p_database);
-     w->load_report(t.local8Bit().data());
+     w->load_report(u2l(t.utf8().data()));
      w->set_viewmode();
 
   }
 
-  
-  
-  
-  
+
+
+
+
   hk_kdetablepartwidget* knodamaindockwindow::new_table(void)
   {
-  
+
    KMdiChildView* dock=new KMdiChildView(i18n("Table"),(mdiMode()==KMdi::ToplevelMode)?0L:this);
    (new QHBoxLayout(dock))->setAutoAdd(true);
-    
+
     KLibFactory* p_factory= KLibLoader::self()->factory( "libhk_kdetablepart" );
     KParts::ReadWritePart* p_part=(KParts::ReadWritePart*) p_factory->create (dock, "hk_kdetablepart", "KParts::ReadWritePart");
     if (!p_part)
     {
      show_warningmessage(hk_translate("Fatal error! Table part could not be loaded!\nThis is a installation error. Check your installation!\
- Did you install knoda into the correct directory? Program will exit now...")); 
+ Did you install knoda into the correct directory? Program will exit now..."));
      exit(1);
-    } 
+    }
      hk_kdetablepartwidget* table = (hk_kdetablepartwidget*)p_part->widget();
-     if (!table) 
+     if (!table)
       {
         show_warningmessage(hk_translate("Warning! Tablepartwiget could not be created!"));
 	return NULL;
-      
+
       }
       KIconLoader* loader=KGlobal::iconLoader();
       loader->addAppDir("hk_kdeclasses");
@@ -411,31 +537,33 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
    connect(dock,SIGNAL(childWindowCloseRequest(KMdiChildView*))
           ,this,SLOT(slot_childClosed(KMdiChildView*)));
    addWindow(dock);
+   dock->setFirstFocusableChildWidget(p_part->widget());
+   dock->setLastFocusableChildWidget(p_part->widget());
    return table;
-  
+
   }
-  
-  
-  
+
+
+
   hk_kdequerypartwidget* knodamaindockwindow::new_query(bool as_view)
   {
    KMdiChildView* dock=new KMdiChildView(i18n("Query"),(mdiMode()==KMdi::ToplevelMode)?0L:this);
    (new QHBoxLayout(dock))->setAutoAdd(true);
-    
+
     KLibFactory* p_factory= KLibLoader::self()->factory( "libhk_kdequerypart" );
     KParts::ReadWritePart* p_part=(KParts::ReadWritePart*) p_factory->create (dock, "hk_kdequerypart", "KParts::ReadWritePart");
     if (!p_part)
     {
      show_warningmessage(hk_translate("Fatal error! Query part could not be loaded!\nThis is a installation error. Check your installation!\
- Did you install knoda into the correct directory? Program will exit now...")); 
+ Did you install knoda into the correct directory? Program will exit now..."));
      exit(1);
-    } 
+    }
      hk_kdequerypartwidget* query = (hk_kdequerypartwidget*)p_part->widget();
-     if (!query) 
+     if (!query)
       {
         show_warningmessage(hk_translate("Warning! Querypartwiget could not be created!"));
 	return NULL;
-      
+
       }
       KIconLoader* loader=KGlobal::iconLoader();
       loader->addAppDir("hk_kdeclasses");
@@ -449,27 +577,27 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
    addWindow(dock);
    return query;
   }
-  
-  
+
+
     hk_kdeformpartwidget* knodamaindockwindow::new_form(void)
   {
    KMdiChildView* dock=new KMdiChildView(i18n("Form"),(mdiMode()==KMdi::ToplevelMode)?0L:this);
    (new QHBoxLayout(dock))->setAutoAdd(true);
-    
+
     KLibFactory* p_factory= KLibLoader::self()->factory( "libhk_kdeformpart" );
     KParts::ReadWritePart* p_part=(KParts::ReadWritePart*) p_factory->create (dock, "hk_kdeformpart", "KParts::ReadWritePart");
     if (!p_part)
     {
      show_warningmessage(hk_translate("Fatal error! Form part could not be loaded!\nThis is a installation error. Check your installation!\
- Did you install knoda into the correct directory? Program will exit now...")); 
+ Did you install knoda into the correct directory? Program will exit now..."));
      exit(1);
-    } 
+    }
      hk_kdeformpartwidget* form = (hk_kdeformpartwidget*)p_part->widget();
-     if (!form) 
+     if (!form)
       {
         show_warningmessage(hk_translate("Warning! Formpartwiget could not be created!"));
 	return NULL;
-      
+
       }
       KIconLoader* loader=KGlobal::iconLoader();
       loader->addAppDir("hk_kdeclasses");
@@ -478,31 +606,34 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
      p_partmanager->addPart(p_part);
    connect(form,SIGNAL(signal_closed(QWidget*))
           ,this,SLOT(slot_childClosed(QWidget*)));
+   connect(form,SIGNAL(signal_raise_form(const hk_string&))
+          ,this,SLOT(slot_raise_form(const hk_string&)));
    connect(dock,SIGNAL(childWindowCloseRequest(KMdiChildView*))
           ,this,SLOT(slot_childClosed(KMdiChildView*)));
    addWindow(dock);
+   
    return form;
   }
-  
+
   hk_kdereportpartwidget* knodamaindockwindow::new_report(void)
   {
    KMdiChildView* dock=new KMdiChildView(i18n("Report"),(mdiMode()==KMdi::ToplevelMode)?0L:this);
    (new QHBoxLayout(dock))->setAutoAdd(true);
-    
+
     KLibFactory* p_factory= KLibLoader::self()->factory( "libhk_kdereportpart" );
     KParts::ReadWritePart* p_part=(KParts::ReadWritePart*) p_factory->create (dock, "hk_kdereportpart", "KParts::ReadWritePart");
     if (!p_part)
     {
      show_warningmessage(hk_translate("Fatal error! Report part could not be loaded!\nThis is a installation error. Check your installation!\
- Did you install knoda into the correct directory? Program will exit now...")); 
+ Did you install knoda into the correct directory? Program will exit now..."));
      exit(1);
-    } 
+    }
      hk_kdereportpartwidget* report = (hk_kdereportpartwidget*)p_part->widget();
-     if (!report) 
+     if (!report)
       {
         show_warningmessage(hk_translate("Warning! Reportpartwiget could not be created!"));
 	return NULL;
-      
+
       }
       KIconLoader* loader=KGlobal::iconLoader();
       loader->addAppDir("hk_kdeclasses");
@@ -513,10 +644,12 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
           ,this,SLOT(slot_childClosed(QWidget*)));
    connect(dock,SIGNAL(childWindowCloseRequest(KMdiChildView*))
           ,this,SLOT(slot_childClosed(KMdiChildView*)));
+   connect(report,SIGNAL(signal_raise_form(const hk_string&))
+          ,this,SLOT(slot_raise_form(const hk_string&)));
    addWindow(dock);
    return report;
   }
-  
+
 
 void knodamaindockwindow::rename_clicked()
 {
@@ -541,10 +674,10 @@ if (newname.size()==0) return;
        f=ft_report;
 
 
-    if (!p_database->rename_file(p_listview->currentItem()->text(0).local8Bit().data()
+    if (!p_database->rename_file(u2l(p_listview->currentItem()->text(0).utf8().data())
     ,newname,f))
     show_warningmessage(hk_translate("Could not rename object!"));
-    
+
 }
 
 void knodamaindockwindow::importcsv_clicked()
@@ -609,23 +742,23 @@ void knodamaindockwindow::clipboarddata_has_changed(void)
 }
 
 void knodamaindockwindow::slot_selection_changed(void)
-{  
+{
  if (!p_connection) return;
  p_newaction->setEnabled(!runtime_only()
  && p_database&& p_database->name().size()>0&&p_listview && (p_listview->is_databaseitem()&&p_connection->server_supports(hk_connection::SUPPORTS_NEW_DATABASE)
- ||p_listview->is_tableitem(true)&&p_connection->server_supports(hk_connection::SUPPORTS_NEW_TABLE) ||p_listview->is_viewitem(true)&&p_connection->server_supports(hk_connection::SUPPORTS_NEW_VIEW) 
+ ||p_listview->is_tableitem(true)&&p_connection->server_supports(hk_connection::SUPPORTS_NEW_TABLE) ||p_listview->is_viewitem(true)&&p_connection->server_supports(hk_connection::SUPPORTS_NEW_VIEW)
  ||p_listview->is_queryitem(true)||p_listview->is_formitem(true)||p_listview->is_reportitem(true)
  ));
  if (newbutton)newbutton->setEnabled(p_newaction->isEnabled());
  bool e=!runtime_only() && p_database&& p_database->name().size()>0;
  p_newdatabaseaction->setEnabled(!runtime_only()&&p_connection->server_supports(hk_connection::SUPPORTS_NEW_DATABASE));
  p_newtableaction->setEnabled(e&&p_connection->server_supports(hk_connection::SUPPORTS_NEW_TABLE));
- p_newqueryaction->setEnabled(e);
+ p_newqueryaction->setEnabled(e&&p_connection->server_supports(hk_connection::SUPPORTS_SQL));
  p_newviewaction->setEnabled(e&&p_connection->server_supports(hk_connection::SUPPORTS_NEW_VIEW));
  p_newformaction->setEnabled(e);
  p_newreportaction->setEnabled(e);
 
- p_alteraction->setEnabled(p_listview&&!p_listview->is_headeritem() &&!runtime_only()); 
+ p_alteraction->setEnabled(p_listview&&!p_listview->is_headeritem() &&!runtime_only());
  if (alterbutton)alterbutton->setEnabled(p_alteraction->isEnabled());
  p_startaction->setEnabled(p_listview &&!p_listview->is_headeritem());
  if (startbutton)startbutton->setEnabled(p_startaction->isEnabled());
@@ -637,20 +770,19 @@ p_deleteaction->setEnabled(p_listview &&(!p_listview->is_headeritem()
  p_renameaction->setEnabled(
     p_listview &&(p_listview->is_databaseitem() && p_connection->server_supports(hk_connection::SUPPORTS_RENAME_DATABASE)
     ||p_listview->is_tableitem() && p_connection->server_supports(hk_connection::SUPPORTS_RENAME_TABLE)
-    ||(p_listview->is_queryitem()||p_listview->is_formitem() ||p_listview->is_reportitem() 
+    ||(p_listview->is_queryitem()||p_listview->is_formitem() ||p_listview->is_reportitem()
     )&&!runtime_only()
-    
+
     )
  );
- p_exportaction->setEnabled(p_listview &&(p_listview->is_tableitem()
- 					||p_listview->is_queryitem()
-					||p_listview->is_viewitem()));
- p_exportcsvaction->setEnabled(p_listview &&(p_listview->is_tableitem()||p_listview->is_queryitem()||p_listview->is_viewitem()));
- p_exportxmlaction->setEnabled(p_listview &&(p_listview->is_tableitem()||p_listview->is_queryitem()||p_listview->is_viewitem()));
+ p_exportaction->setEnabled(p_listview );
+ p_exportcsvaction->setEnabled(p_listview && !runtime_only());
+ p_exportxmlaction->setEnabled(p_listview && !runtime_only());
  p_importaction->setEnabled(!runtime_only());
  p_importcsvaction->setEnabled(!runtime_only());
  p_databasesettingaction->setEnabled(p_database&&!runtime_only());
- p_passwordaction->setEnabled(p_listview &&(p_listview->database()!=NULL));
+ p_passwordaction->setEnabled(p_listview &&(p_listview->database()!=NULL)
+    &&p_connection->server_needs(hk_connection::NEEDS_PASSWORD));
  clipboarddata_has_changed();
 }
 
@@ -667,7 +799,7 @@ QPopupMenu * popup=(QPopupMenu *) factory()->container("popup", this);
 void knodamaindockwindow::databasesettings_clicked(void)
 {
 hk_kdedatabasesetting* setting=new hk_kdedatabasesetting(p_database);
- if (setting->exec()==QDialog::Accepted) 
+ if (setting->exec()==QDialog::Accepted)
     {
       if (p_listview)p_listview->reload_lists();
     }
@@ -675,11 +807,11 @@ hk_kdedatabasesetting* setting=new hk_kdedatabasesetting(p_database);
 delete setting;
 }
 
-void knodamaindockwindow::objecthandler_clicked(void) 
+void knodamaindockwindow::objecthandler_clicked(void)
 {
   hk_kdeobjecthandler* h=new hk_kdeobjecthandler(p_database);
   h->exec();
- 
+
   delete h;
 }
 
@@ -692,16 +824,27 @@ void knodamaindockwindow::newwindow_clicked(void)
 
 
 
-void knodamaindockwindow::show_drivers()
+void knodamaindockwindow::show_drivers(KPopupMenu* menu,enum_function f)
 {
-  KPopupMenu* menu= p_newconnectionaction->popupMenu();
+   if (!menu) return;
   menu->clear();
     vector<hk_string>* drv=hk_drivermanager::driverlist();
     vector<hk_string>::iterator it;
     int di=0;
     for(it=drv->begin();it!=drv->end();it++)
     {
-        menu->insertItem(QString::fromLocal8Bit((*it).c_str()),this,SLOT(driver_selected(int)),0,di);
+        switch (f)
+	{
+	 case f_connect:
+	                menu->insertItem(QString::fromUtf8(l2u((*it)).c_str()),this,SLOT(driver_selected(int)),0,di);
+	 		break;
+	 case f_exportdb:
+	                menu->insertItem(QString::fromUtf8(l2u((*it)).c_str()),this,SLOT(exportdbdriver_selected(int)),0,di);
+	 		break;
+	 case f_importdb:
+	                menu->insertItem(QString::fromUtf8(l2u((*it)).c_str()),this,SLOT(importdbdriver_selected(int)),0,di);
+	 		break;
+	}
         di++;
     }
 
@@ -709,109 +852,32 @@ void knodamaindockwindow::show_drivers()
 }
 
 
+void knodamaindockwindow::show_drivers()
+{
+  KPopupMenu* menu= p_newconnectionaction->popupMenu();
+   show_drivers(menu,f_connect);
+}
+
+void knodamaindockwindow::show_exportdbdrivers()
+{
+ KPopupMenu* menu= p_exportdatabaseaction->popupMenu();
+   show_drivers(menu,f_exportdb);
+
+}
+
+void knodamaindockwindow::show_importdbdrivers()
+{
+ KPopupMenu* menu= p_importdatabaseaction->popupMenu();
+   show_drivers(menu,f_importdb);
+
+}
+
 
 void knodamaindockwindow::settings_clicked()
 {
     hk_kdepreferencesdialog* p_dialog= new hk_kdepreferencesdialog(0,0,true);
-    p_dialog->timefield->setText(QString::fromLocal8Bit(hk_class::defaulttimeformat().c_str())),
-    p_dialog->datefield->setText(QString::fromLocal8Bit(hk_class::defaultdateformat().c_str())),
-    p_dialog->datetimefield->setText(QString::fromLocal8Bit(hk_class::defaultdatetimeformat().c_str()));
-    p_dialog->localefield->setText(QString::fromLocal8Bit(hk_class::locale().c_str()));
-    p_dialog->printcommandfield->setText(QString::fromLocal8Bit(hk_report::printcommand().c_str()));
-    p_dialog->driverpathfield->setText(QString::fromLocal8Bit(hk_drivermanager::path().c_str()));
-    p_dialog->bepedanticfield->setCurrentItem(hk_class::showpedantic()?0:1);
-    p_dialog->maximizedfield->setCurrentItem(hk_visible::open_maximized_windows()?0:1);
-    p_dialog->fontfield->setEditText(QString::fromLocal8Bit(hk_font::defaultfontname().c_str()));
-    p_dialog->fontsizefield->setValue(hk_font::defaultfontsize());
-    p_dialog->precisionfield->setValue(hk_dsdatavisible::defaultprecision());
-    p_dialog->separatorfield->setCurrentItem(hk_dsdatavisible::defaultuse_numberseparator()?0:1);
-    p_dialog->sizetypefield->setCurrentItem(hk_presentation::defaultsizetype()==hk_presentation::relative?0:1);
-    p_dialog->measurefield->setCurrentItem(hk_class::measuresystem()==hk_class::cm?0:1);
-    p_dialog->snap2gridxfield->setValue(hk_presentation::snap2gridx());
-    p_dialog->snap2gridyfield->setValue(hk_presentation::snap2gridy());
-    vector<hk_string>* drv=hk_drivermanager::driverlist();
-    vector<hk_string>::iterator it;
-    int di=0;
-    for(it=drv->begin();it!=drv->end();it++)
-    {
-        p_dialog->defaultdriverfield->insertItem(QString::fromLocal8Bit((*it).c_str()));
-        if ((*it)==hk_class::defaultdriver())
-            p_dialog->defaultdriverfield->setCurrentItem(di);
-        di++;
-    }
-
-    list<hk_string>* encodelist =hk_report::fontencodinglist();
-    p_dialog->encodingfield->clear();
-    list<hk_string>::iterator eit=encodelist->begin();
-    int i=0;
-    while (eit!=encodelist->end())
-    {
-        p_dialog->encodingfield->insertItem(QString::fromLocal8Bit((*eit).c_str()));
-        if ((*eit)==hk_report::fontencodingstring()) p_dialog->encodingfield->setCurrentItem(i);
-        eit++;
-        i++;
-    }
-
-    switch (hk_visible::defaulttextalignment())
-    {
-        case hk_visible::aligncenter: i=1;break;
-        case hk_visible::alignright: i=2;break;
-        default: i=0;
-    }
-    p_dialog->textalignmentfield->setCurrentItem(i);
-
-    switch (hk_visible::defaultnumberalignment())
-    {
-        case hk_visible::aligncenter: i=1;break;
-        case hk_visible::alignright: i=2;break;
-        default: i=0;
-    }
-    p_dialog->numberalignmentfield->setCurrentItem(i);
-
-    int res=p_dialog->exec();
-
-    if (res==QDialog::Accepted)
-    {
-        hk_class::set_defaultdatetimeformat(
-            p_dialog->timefield->text().local8Bit().data(),
-            p_dialog->datefield->text().local8Bit().data(),
-            p_dialog->datetimefield->text().local8Bit().data()
-            );
-	 hk_class::set_locale(p_dialog->localefield->text().local8Bit().data());
-        hk_class::set_showpedantic( p_dialog->bepedanticfield->currentItem()==0);
-        hk_visible::set_open_maximized_windows(p_dialog->maximizedfield->currentItem()==0);
-        hk_report::set_fontencoding(p_dialog->encodingfield->currentText().local8Bit().data());
-        hk_report::set_printcommand(p_dialog->printcommandfield->text().local8Bit().data());
-        hk_drivermanager::set_path(p_dialog->driverpathfield->text().local8Bit().data());
-        hk_font::set_defaultfont(p_dialog->fontfield->currentText().local8Bit().data(),p_dialog->fontsizefield->value());
-	hk_presentation::set_snap2gridx(p_dialog->snap2gridxfield->value());
-	hk_presentation::set_snap2gridy(p_dialog->snap2gridyfield->value());
-        hk_visible::alignmenttype a=hk_visible::alignleft;
-        switch (p_dialog->textalignmentfield->currentItem())
-        {
-            case 1: a=hk_visible::aligncenter;break;
-            case 2: a=hk_visible::alignright;break;
-            default:;
-        }
-        hk_visible::set_defaulttextalignment(a);
-    hk_presentation::set_defaultsizetype(p_dialog->sizetypefield->currentItem()==0?hk_presentation::relative:hk_presentation::absolute);
-    hk_class::set_measuresystem(p_dialog->measurefield->currentItem()==0?hk_class::cm:hk_class::inch);
-
-        a=hk_visible::alignleft;
-        switch (p_dialog->numberalignmentfield->currentItem())
-        {
-            case 1: a=hk_visible::aligncenter;break;
-            case 2: a=hk_visible::alignright;break;
-            default:;
-        }
-        hk_visible::set_defaultnumberalignment(a);
-        hk_dsdatavisible::set_defaultnumberformat(p_dialog->separatorfield->currentItem()==0,p_dialog->precisionfield->value());
-        hk_class::set_defaultdriver(p_dialog->defaultdriverfield->currentText().local8Bit().data());
-
-        hk_class::save_preferences();
-        
-    }
-
+    //int res=
+    p_dialog->exec();
     delete p_dialog;
 
 }
@@ -819,17 +885,118 @@ void knodamaindockwindow::settings_clicked()
 
 void knodamaindockwindow::setCaption(const QString& c)
 {
-  
+
   if (p_connection)
     {
         hk_string s=p_connection->drivername()+" "+p_connection->user()+"@"+p_connection->host()+":"+ulongint2string(p_connection->tcp_port());
-        knodamaindockwindowbase::setCaption(QString::fromLocal8Bit(s.c_str()));
-  
+        knodamaindockwindowbase::setCaption(QString::fromUtf8(l2u(s).c_str()));
+
     }
     else knodamaindockwindowbase::setCaption(c);
 
-  
+
 
 }
 
 
+hk_kdeformpartwidget* knodamaindockwindow::find_existing_form(const hk_string& n)
+{
+    if (!p_database) return NULL;
+    hk_kdeformpartwidget* w = NULL;
+        QWidget* sf=dynamic_cast<QWidget*>
+            (p_database->existing_form(n));
+        while (sf!=NULL && w==NULL)
+        {
+            sf=sf->parentWidget();
+	    hk_form* f=dynamic_cast<hk_form*>(sf);
+	    if (f && f->is_subform())sf=NULL;
+            w= dynamic_cast <hk_kdeformpartwidget*> (sf);
+        }
+    return w;
+}
+
+
+hk_kdereportpartwidget* knodamaindockwindow::find_existing_report(const hk_string& n)
+{
+    if (!p_database) return NULL;
+    hk_kdereportpartwidget* w = NULL;
+        QWidget* sf=dynamic_cast<QWidget*>
+            (p_database->existing_report(n));
+
+        while (sf!=NULL && w==NULL)
+        {
+            sf=sf->parentWidget();
+	    hk_report* r=dynamic_cast<hk_report*>(sf);
+	    if (r && r->is_subreport())sf=NULL;
+            w= dynamic_cast <hk_kdereportpartwidget*> (sf);
+        }
+    return w;
+}
+
+hk_kdetablepartwidget* knodamaindockwindow::find_existing_table(const hk_string& n)
+{
+if (!m_pDocumentViews) return NULL;
+hk_kdetablepartwidget* w = NULL;
+KMdiChildView* c=m_pDocumentViews->first();
+while (c)
+ { 
+  QWidget* wid=c->focusedChildWidget();
+  while (wid)
+  {
+  w=dynamic_cast<hk_kdetablepartwidget*>(wid);
+  if (w &&  w->datasource() && w->datasource()->name()==n) return w;
+  wid=wid->parentWidget();
+  }
+  c=m_pDocumentViews->next();
+ }
+return NULL;
+}
+
+
+hk_kdequerypartwidget* knodamaindockwindow::find_existing_query(const hk_string& n)
+{
+if (!m_pDocumentViews) return NULL;
+hk_kdequerypartwidget* w = NULL;
+KMdiChildView* c=m_pDocumentViews->first();
+while (c)
+ { 
+  QWidget* wid=c->focusedChildWidget();
+  while (wid)
+  {
+  w=dynamic_cast<hk_kdequerypartwidget*>(wid);
+  if (w &&  w->datasource() && w->datasource()->type()==hk_data::ds_query&& w->datasource()->name()==n) return w;
+  wid=wid->parentWidget();
+  }
+  c=m_pDocumentViews->next();
+ }
+return NULL;
+}
+
+hk_kdequerypartwidget* knodamaindockwindow::find_existing_view(const hk_string& n)
+{
+if (!m_pDocumentViews) return NULL;
+hk_kdequerypartwidget* w = NULL;
+KMdiChildView* c=m_pDocumentViews->first();
+while (c)
+ { 
+  QWidget* wid=c->focusedChildWidget();
+  while (wid)
+  {
+  w=dynamic_cast<hk_kdequerypartwidget*>(wid);
+  if (w &&  w->datasource() && w->datasource()->type()==hk_data::ds_view&& w->datasource()->name()==n) return w;
+  wid=wid->parentWidget();
+  }
+  c=m_pDocumentViews->next();
+ }
+return NULL;
+}
+
+
+void knodamaindockwindow::slot_raise_form(const hk_string& fo)
+{
+  hk_kdeformpartwidget* f=find_existing_form(fo);
+  if (!f) return;
+      KMdiChildView* view= dynamic_cast<KMdiChildView*>(f->parent());
+      if (view)
+	 view->activate();
+}
