@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of knoda -Knorr's Datenbank.
 // This file may be distributed and/or modified under the terms of the
 // GNU General Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.17 $
+//$Revision: 1.23 $
 #ifndef KNODAMAINDOCKWINDOWBASE_H
 #define KNODAMAINDOCKWINDOWBASE_H
 #include <kdockwidget.h>
@@ -18,22 +18,27 @@
 #include <hk_string.h>
 #include <qstring.h>
 
- 
+
 const QString autoform="Autoform";
 
- 
+
  typedef class struct_commands
 {
  public:
  bool p_showlistwindow;
+ bool p_load_connection;
+ bool p_classic;
  struct_commands()
  {
    p_showlistwindow=true;
+   p_load_connection=false;
+   p_classic=false;
  }
 };
 
 
 class knodamaindockwindowbaseprivate;
+class knodamaindockwindow;
 class hk_kdedblistview;
 class hk_connection;
 class hk_database;
@@ -55,7 +60,7 @@ public slots:
 void slot_database_selected(int);
  virtual void slot_new_database(void){}
  virtual void slot_delete_database(const QString&){}
- 
+
  virtual void slot_new_table(void){}
  virtual void slot_delete_table(const QString&){}
  virtual void slot_designmode_table(const QString&){}
@@ -94,19 +99,25 @@ virtual void objecthandler_clicked(void) {}
 virtual void slot_listbox_popup(QListViewItem*,const QPoint&){}
 virtual void settings_clicked(void){}
 virtual void show_drivers(){}
+virtual void show_exportdbdrivers(){}
+virtual void show_importdbdrivers(){}
 virtual void slot_closewindow();
 void slot_activate_closeaction();
 void set_databases(void);
 void driver_selected(int);
+void exportdbdriver_selected(int);
+void importdbdriver_selected(int);
 void slot_disconnect(void);
 void slot_open_localdatabase();
+void slot_load_connection();
+void slot_store_connection();
+void slot_referentialintegrity();
+	void designer_deleted(void);
 
- 
- 
 protected:
 virtual void closeEvent(QCloseEvent*);
 
-KWidgetAction*    p_databaseaction; 
+KWidgetAction*    p_databaseaction;
 KComboBox*        p_databasecombobox;
 KAction*          p_closeaction;
 KAction*          p_quitaction;
@@ -138,14 +149,21 @@ KAction* p_renameaction;
 KActionMenu* p_exportaction;
 KAction* p_exportcsvaction;
 KAction* p_exportxmlaction;
+KActionMenu* p_exportdatabaseaction;
 KActionMenu* p_importaction;
 KAction* p_importcsvaction;
+KActionMenu* p_importdatabaseaction;
 KAction* p_passwordaction;
 KAction* p_databasesettingaction;
 KAction* p_objecthandleraction;
 KAction* p_newwindowaction;
 KAction* p_settingsaction;
 KAction* p_openlocaldbaction;
+KAction* p_referentialintegrityaction;
+
+KAction* p_loadconnection;
+KAction* p_storeconnection;
+
 QToolButton* newbutton;
 QToolButton* alterbutton;
 QToolButton* startbutton;
@@ -158,6 +176,7 @@ KParts::PartManager* p_partmanager;
 
 private:
 void internal_set_database(const hk_string&);
+knodamaindockwindow* internal_new_dockwindow(void);
 knodamaindockwindowbaseprivate* p_private;
 };
 
