@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of knoda -Knorr's Datenbank.
 // This file may be distributed and/or modified under the terms of the
 // GNU General Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.20 $
+//$Revision: 1.24 $
 #ifndef KNODAMAINWINDOWBASE_H
 #define KNODAMAINWINDOWBASE_H
 
@@ -35,22 +35,22 @@ class QPopupMenu;
 class QProgressDialog;
 class hk_kdeschemadialog;
 class KMainWindow;
+class KPopupMenu;
 class hk_kdeform;
 class hk_kdereport;
 class hk_kdetable;
 class hk_kdequery;
-class hk_kdeworkspace;
+class hk_kdedbdesignerwindow;
 
 class knodamainwindowbase : public QWidget ,public hk_dsvisible
 {
     Q_OBJECT
 
         public:
-        knodamainwindowbase( KMainWindow* parent = 0, hk_kdeworkspace* ws=0,const char* name = 0, WFlags fl = 0,const QString& database="",const QString& form="" );
+        knodamainwindowbase( KMainWindow* parent = 0,const char* name = 0, WFlags fl = 0,const QString& database="",const QString& form="" );
         virtual    ~knodamainwindowbase();
         void set_connection(hk_connection* c);
         hk_connection* connection(void) {return p_connection;}
-	hk_kdeworkspace* workspace() {return p_workspace;}
         hk_listbox* itemslist;
         QLabel* TextLabel1;
         QLabel* TextLabel1_2;
@@ -90,6 +90,13 @@ class knodamainwindowbase : public QWidget ,public hk_dsvisible
         virtual void objecthandler_clicked(void);
 	virtual void slot_open_localdatabase(void);
 	hk_database* database(){return p_database;}
+virtual void show_exportdbdrivers();
+virtual void show_importdbdrivers();
+void exportdbdriver_selected(int);
+void importdbdriver_selected(int);
+void slot_store_connection();
+void slot_referentialintegrity();
+	void designer_deleted(void);
     protected:
         QHBoxLayout* knodamainwindowbaseLayout;
         QGridLayout* Layout8;
@@ -101,6 +108,8 @@ class knodamainwindowbase : public QWidget ,public hk_dsvisible
         virtual void        list_changes(listtype type);
 	bool eventFilter(QObject*,QEvent*);
     private:
+ enum enum_function{f_exportdb,f_importdb};
+ void show_drivers(KPopupMenu* menu, enum_function);
         void open_autoform();
         void set_buttons();
         void set_databasebuttons();
@@ -144,12 +153,16 @@ class knodamainwindowbase : public QWidget ,public hk_dsvisible
         KAction* p_objecthandleraction;
         KAction* p_passwordaction;
 	KAction* p_openlocaldbaction;
+KActionMenu* p_importdatabaseaction;
+KActionMenu* p_exportdatabaseaction;
+KAction* p_storeconnection;
+KAction* p_referentialintegrityaction;
         QPopupMenu* p_popup;
         QString p_selecteddb;
         QString p_selectedform;
 
         KMainWindow* p_parent;
-	hk_kdeworkspace* p_workspace;
+hk_kdedbdesignerwindow* p_designer;
 };
 
 
