@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of knoda -Knorr's Datenbank.
 // This file may be distributed and/or modified under the terms of the
 // GNU General Public License version 2 as published by the Free Software
@@ -15,6 +15,7 @@
 #include <kcmdlineargs.h>
 #include <qlistbox.h>
 #include <qdialog.h>
+#include <qlistbox.h>
 #include "hk_kdemessages.h"
 #include "hk_kdegrid.h"
 #include "knodawin.h"
@@ -23,6 +24,7 @@
 #include "hk_kdedriverselect.h"
 #include <klocale.h>
 #include <kconfig.h>
+#include <kurl.h>
 #include <kmimetype.h>
 #include <unistd.h>
 #include <sys/types.h>
@@ -53,9 +55,9 @@ int main(int argc,char** argv)
 {
         umask(0077);
 
-    KAboutData aboutData("knoda", 
+    KAboutData aboutData("knoda",
     I18N_NOOP("knoda"),
-        VERSION, I18N_NOOP("knoda is a database management system"), 
+        VERSION, I18N_NOOP("knoda is a database management system"),
 	KAboutData::License_GPL,
         "(c) 2000-2005 Horst Knorr",0,"http://www.knoda.org","hk_classes@knoda.org");
     aboutData.addAuthor("Horst Knorr",I18N_NOOP("Author"), "hk_classes@knoda.org","http://www.knoda.org");
@@ -79,9 +81,9 @@ int main(int argc,char** argv)
     bool classic= args->isSet("classic");
     if (mdi) classic=true;
     mdi=false;
-    bool nolistwindow=args->isSet("strongruntime"); 
+    bool nolistwindow=args->isSet("strongruntime");
     bool runtime=args->isSet("runtime");
-    bool printsql=args->isSet("print-sql"); 
+    bool printsql=args->isSet("print-sql");
     if (db) database=args->getOption("b");
     if (f) form=args->getOption("f");
     if (d)  driver = args->getOption("d");
@@ -89,22 +91,26 @@ int main(int argc,char** argv)
     if (args->count()>0 && !db)
       {
         db=true;
-	database=args->arg(0);
+	database=args->arg(0);      }
+    KMimeType::Ptr ptr = KMimeType::findByURL(database);
+    QString mimename = ptr.data()->name(); cerr <<"mimetype="<<mimename<<endl;
+     if (mimename=="application/octet-stream")
+      {
+        ptr=KMimeType::findByFileContent(database);
+	mimename = ptr.data()->name();
       }
-    KMimeType::Ptr ptr = KMimeType::findByFileContent(database);
-    QString mimename = ptr.data()->name();
-    if (mimename=="application/x-hk_classes-sqlite3")
-    {
-      driver="sqlite3";
-      d=true;
-    }  
-    else
-    if (mimename=="application/x-hk_classes-sqlite2")
-    {
-     driver="sqlite2";
-     d=true;
-    } 
-    
+   cerr <<"used mimetype="<<mimename<<endl;
+
+   if (mimename=="application/x-hk_connection")
+   {
+   commands.p_load_connection=true;
+   driver="X";
+   }
+
+
+    if (driver=="")driver=mimetype2driver(u2l(mimename.utf8().data()));
+    d=driver.size()>0;
+
     if (!d&&(db||f))
     {
         cerr <<i18n("Please specifiy a database driver!")<<endl;
@@ -123,26 +129,19 @@ int main(int argc,char** argv)
     if (args->isSet("debug")) hk_class::set_generaldebug(true);
 #endif
     set_kdestandarddialogs();
-    parameters p;
-    p.driver=driver;
-    p.database=database;
-    p.form=form;
-    p.runtime=runtime;
-    p.classic_mdi=mdi;
-    p.classic=classic;
-    if (nolistwindow)p.runtime=true;
     struct_commandlinefields cp;
     cp.driver=driver;
-    cp.database=database.local8Bit().data();
-    cp.form=form.local8Bit().data();
+    cp.database=u2l(database.utf8().data());
+    cp.form=u2l(form.utf8().data());
     cp.runtime_only=runtime;
     if (nolistwindow)cp.runtime_only=true;
     commands.p_showlistwindow=!nolistwindow;
+    commands.p_classic=classic;
     cp.p_guicommands=&commands;
     int result=0;
-    if (p.classic_mdi || p.classic)
-    {      
-    knodaprogram* widget=new knodaprogram(0,0,0,&p);
+    if (classic)
+    {
+    knodaprogram* widget=new knodaprogram(0,0,0,&cp);
     widget->show();
     if (driver.size()>0) widget->connect_clicked();
     result=anwendung.exec();
@@ -151,18 +150,27 @@ int main(int argc,char** argv)
     delete widget;
     }
     else
-    {
-      knodamaindockwindow* w=new knodamaindockwindow(&cp);
-      w->show();
+    {  hk_drivermanager dr;// needed as a dummy to initialize the driverlist path
       if (driver.size()==0)
       {
-        hk_kdedriverselect* select=new hk_kdedriverselect(w);
+        hk_kdedriverselect* select=new hk_kdedriverselect();
 	if (select->exec()==QDialog::Accepted)
 	{
-	   w->set_drivername(select->driverlist->currentText().local8Bit().data());
-	}
-        delete select;
+	   if (select->driver_selected())
+	   cp.driver=u2l(select->driverlist->currentText().utf8().data());
+	   else
+	   {
+             commands.p_load_connection=true;
+             cp.driver="X";
+             cp.database=u2l(select->selected_file().utf8().data());
+
+	   }
+  	}else result=select->driverlist->count();
+      delete select;
       }
+      if (result>0) return 1;
+      knodamaindockwindow* w=new knodamaindockwindow(&cp);
+      w->show();
     result=anwendung.exec();
     anwendung.config()->sync();
     }
